#include "pch.h"
#include "translations.h"
#include "options.h"


lang translations::current_language = lang::English;

const languageInfo* translations::get_languages(size_t* languages_number) {
	if(languages_number) {
		*languages_number = languages.size();
	}
	return languages.data();
}

void translations::set_current_language(const char* short_name) 
{
	for(int i = 0; i < (int)lang::Max; i++) {
		if(!strcmp(short_name, languages[(lang)i].short_name)) {
			current_language = (lang) i;
			return;
		}
	}
	printf("Unknown language \"%s\"\n", short_name);
}

const languageInfo* translations::get_current_language()
{
	if(!TextArray::contains(current_language))
	{
		current_language = lang::English;
	}
	return &languages[current_language];
}

const char* translations::get_translation(Msg id)
{
	if(!TextArray::contains(id))
		return "!Missing MsgId!";
	
	// Current language assumed in bounds at this point
	auto text = Translations.Get(id, current_language);

	// Fallback to english if available
	if (text == nullptr)
		text = Translations.Get(id, lang::English);
	if (text == nullptr)
		text = "!Missing English text!";

	return text;
}

void translations::get_glyph_range(ImVector<ImWchar>* ranges)
{
	ImFontGlyphRangesBuilder builder;

	for(int i = 0; i < (int)Msg::Max; i++) {
		const char* translation = get_translation((Msg)i);
		if(translation)
		{
			builder.AddText(translation); 
		}
	}

	builder.AddRanges(ImGui::GetIO().Fonts->GetGlyphRangesDefault());
	builder.BuildRanges(ranges);
}

const InitializedArray<
		lang,
		languageInfo,
		(int)lang::Max
	>  translations::languages =
{
	{ lang::Arabic, {"ar", "Arabic" } },
	{ lang::Czech, {"cs", "Czech" } },
	{ lang::Danish, {"da", "Danish" } },
	{ lang::German, {"de", "German" } },
	{ lang::Greek, {"el", "Greek" } },
	{ lang::English, {"en", "English" } },
	{ lang::Spanish, {"es", "Spanish" } },
	{ lang::Finnish, {"fi", "Finnish" } },
	{ lang::French, {"fr", "French" } },
	{ lang::Hebrew, {"he", "Hebrew" } },
	{ lang::Hungarian, {"hu", "Hungarian" } },
	{ lang::Italian, {"it", "Italian" } },
	{ lang::Japanese, {"ja", "Japanese" } },
	{ lang::Korean, {"ko", "Korean" } },
	{ lang::Norwegian, {"nb", "Norwegian" } },
	{ lang::Dutch, {"nl", "Dutch" } },
	{ lang::Polish, {"pl", "Polish" } },
	{ lang::BrazilianPortuguese, {"pt_BR", "Brazilian Portuguese" } },
	{ lang::Portuguese, {"pt_PT", "Portuguese" } },
	{ lang::Russian, {"ru", "Russian" } },
	{ lang::Swedish, {"sv", "Swedish" } },
	{ lang::Turkish, {"tr", "Turkish" } },
	{ lang::SimplifiedChinese, {"zh_CN", "Simplified Chinese" } },
	{ lang::TraditionalChinese, {"zh_TW", "Traditional Chinese" } },
};

const TextArray translations::Translations =
{
	{
		Msg::STRING101,
		{
			{ lang::Arabic, "Replay Awarded" },
			{ lang::Czech, "Ocenění novým míčkem" },
			{ lang::Danish, "Ekstraspil" },
			{ lang::German, "Wiederholung gewonnen" },
			{ lang::Greek, "Κερδίσατε επανάληψη" },
			{ lang::English, "Replay Awarded" },
			{ lang::Spanish, "Premiado con otra partida" },
			{ lang::Finnish, "Uusinta myönnetty" },
			{ lang::French, "Nouvelle partie gagnée !" },
			{ lang::Hebrew, "Replay Awarded" },
			{ lang::Hungarian, "Jutalomjáték" },
			{ lang::Italian, "Altra partita vinta" },
			{ lang::Japanese, "リプレイ獲得!" },
			{ lang::Korean, "보너스 게임" },
			{ lang::Norwegian, "Vunnet nytt spill" },
			{ lang::Dutch, "Replay toegekend" },
			{ lang::Polish, "Powtórzenie gry" },
			{ lang::BrazilianPortuguese, "Ganhou repetição!" },
			{ lang::Portuguese, "Concedida bola extra" },
			{ lang::Russian, "Выдан Реплей" },
			{ lang::Swedish, "Fortsätt spela om kulan rinner" },
			{ lang::Turkish, "Yeniden Oynama Ödülü" },
			{ lang::SimplifiedChinese, "奖励重玩" },
			{ lang::TraditionalChinese, "贈獎：再玩一次" },
		},
	},
	{
		Msg::STRING102,
		{
			{ lang::Arabic, "Ball Locked" },
			{ lang::Czech, "Míček uzamčen" },
			{ lang::Danish, "Kuglen er låst" },
			{ lang::German, "Kugel gesperrt" },
			{ lang::Greek, "Η μπίλια κλειδώθηκε" },
			{ lang::English, "Ball Locked" },
			{ lang::Spanish, "Bola bloqueada" },
			{ lang::Finnish, "Pallo lukittu" },
			{ lang::French, "Bille bloquée" },
			{ lang::Hebrew, "Ball Locked" },
			{ lang::Hungarian, "Zárolt golyó" },
			{ lang::Italian, "Pallina bloccata" },
			{ lang::Japanese, "ボールがロックされた!" },
			{ lang::Korean, "구슬이 갇힘" },
			{ lang::Norwegian, "Låst ball" },
			{ lang::Dutch, "Ball Locked" },
			{ lang::Polish, "Kulka zablokowana" },
			{ lang::BrazilianPortuguese, "Bola presa" },
			{ lang::Portuguese, "Bola bloqueada" },
			{ lang::Russian, "Шарик Заблокирован" },
			{ lang::Swedish, "Kulan låst" },
			{ lang::Turkish, "Top Kilitli" },
			{ lang::SimplifiedChinese, "锁定的球" },
			{ lang::TraditionalChinese, "鎖定彈珠" },
		},
	},
	{
		Msg::STRING103,
		{
			{ lang::Arabic, "Center Post\n%ld" },
			{ lang::Czech, "Centrální místo\n%ld" },
			{ lang::Danish, "Midterpost\n%ld" },
			{ lang::German, "Mittelpfosten\n%ld" },
			{ lang::Greek, "Κεντρικός στύλος\n%ld" },
			{ lang::English, "Center Post\n%ld" },
			{ lang::Spanish, "Poste central\n%ld" },
			{ lang::Finnish, "Keskitolppa\n%ld" },
			{ lang::French, "Cabestan\n%ld" },
			{ lang::Hebrew, "Center Post\n%ld" },
			{ lang::Hungarian, "Középoszlop\n%ld" },
			{ lang::Italian, "Corpo di guardia principale\n%ld" },
			{ lang::Japanese, "センター ポスト\n%ld" },
			{ lang::Korean, "중앙 고지\n%ld" },
			{ lang::Norwegian, "Midtstolpe\n%ld" },
			{ lang::Dutch, "Center Post\n%ld" },
			{ lang::Polish, "Centralny słupek\n%ld" },
			{ lang::BrazilianPortuguese, "Ativou pino central\n%ld" },
			{ lang::Portuguese, "Poste central\n%ld" },
			{ lang::Russian, "Центральный Ограничитель %ld" },
			{ lang::Swedish, "Mittstolpe\n%ld" },
			{ lang::Turkish, "Merkez Direk\n%ld" },
			{ lang::SimplifiedChinese, "中央立柱\n%ld" },
			{ lang::TraditionalChinese, "中央郵局\n%ld" },
		},
	},
	{
		Msg::STRING104,
		{
			{ lang::Arabic, "Bonus Awarded\n%ld" },
			{ lang::Czech, "Ocenění bonusem\n%ld" },
			{ lang::Danish, "Bonus tildelt\n%ld" },
			{ lang::German, "Bonus gewonnen\n%ld" },
			{ lang::Greek, "Απονομή μπόνους\n%ld" },
			{ lang::English, "Bonus Awarded\n%ld" },
			{ lang::Spanish, "Bonificación\n%ld" },
			{ lang::Finnish, "Bonus\n%ld" },
			{ lang::French, "Bonus obtenu\n%ld" },
			{ lang::Hebrew, "Bonus Awarded\n%ld" },
			{ lang::Hungarian, "Bónusz\n%ld" },
			{ lang::Italian, "Bonus vinto\n%ld" },
			{ lang::Japanese, "ボーナス\n%ld" },
			{ lang::Korean, "보너스!\n%ld" },
			{ lang::Norwegian, "Vunnet bonus\n%ld" },
			{ lang::Dutch, "Bonus toegekend\n%ld" },
			{ lang::Polish, "Premia przyznana\n%ld" },
			{ lang::BrazilianPortuguese, "Ganhou bônus!\n%ld" },
			{ lang::Portuguese, "Premiado com um bónus\n%ld" },
			{ lang::Russian, "Выдан Бонус\n%ld" },
			{ lang::Swedish, "Bonus\n%ld" },
			{ lang::Turkish, "Ödül Verildi\n%ld" },
			{ lang::SimplifiedChinese, "奖分\n%ld" },
			{ lang::TraditionalChinese, "您得到額外加分\n%ld" },
		},
	},
	{
		Msg::STRING105,
		{
			{ lang::Arabic, "Bonus Activated" },
			{ lang::Czech, "Bonus aktivován" },
			{ lang::Danish, "Bonus slået til" },
			{ lang::German, "Bonus aktiviert" },
			{ lang::Greek, "Ενεργοποίηση μπόνους" },
			{ lang::English, "Bonus Activated" },
			{ lang::Spanish, "Bonificación activada" },
			{ lang::Finnish, "Bonus aktivoitu" },
			{ lang::French, "Bonus activé" },
			{ lang::Hebrew, "Bonus Activated" },
			{ lang::Hungarian, "Bónusz kijátszva" },
			{ lang::Italian, "Bonus attivato" },
			{ lang::Japanese, "ボーナス スタート!" },
			{ lang::Korean, "보너스 기회" },
			{ lang::Norwegian, "Bonus på" },
			{ lang::Dutch, "Bonus geactiveerd" },
			{ lang::Polish, "Premia aktywna" },
			{ lang::BrazilianPortuguese, "Bônus ativado" },
			{ lang::Portuguese, "Bónus activado" },
			{ lang::Russian, "Бонус Активирован" },
			{ lang::Swedish, "Bonus på" },
			{ lang::Turkish, "Ödül Etkin" },
			{ lang::SimplifiedChinese, "奖分" },
			{ lang::TraditionalChinese, "啟動加分" },
		},
	},
	{
		Msg::STRING106,
		{
			{ lang::Arabic, "Weapons Upgraded" },
			{ lang::Czech, "Vylepšení zbraní" },
			{ lang::Danish, "Våben er opgraderet" },
			{ lang::German, "Systeme verbessert" },
			{ lang::Greek, "Τα όπλα αναβαθμίστηκαν" },
			{ lang::English, "Weapons Upgraded" },
			{ lang::Spanish, "Armas actualizadas" },
			{ lang::Finnish, "Aseistus uusittu" },
			{ lang::French, "Armes renforcées" },
			{ lang::Hebrew, "Weapons Upgraded" },
			{ lang::Hungarian, "Fegyverek korszerűsítve" },
			{ lang::Italian, "Armi potenziate" },
			{ lang::Japanese, "武器をアップグレード!" },
			{ lang::Korean, "무기 보강" },
			{ lang::Norwegian, "Våpen oppgradert" },
			{ lang::Dutch, "Wapens opgewaardeerd" },
			{ lang::Polish, "Modernizacja broni" },
			{ lang::BrazilianPortuguese, "Armas atualizadas" },
			{ lang::Portuguese, "Armas reforçadas" },
			{ lang::Russian, "Вооружение Улучшено" },
			{ lang::Swedish, "Vapen uppgraderas" },
			{ lang::Turkish, "Silahlar Yenilendi" },
			{ lang::SimplifiedChinese, "武器已升级" },
			{ lang::TraditionalChinese, "武器升級" },
		},
	},
	{
		Msg::STRING107,
		{
			{ lang::Arabic, "Engine Upgraded" },
			{ lang::Czech, "Vylepšení motoru" },
			{ lang::Danish, "Maskine er opgraderet" },
			{ lang::German, "Antrieb verbessert" },
			{ lang::Greek, "Ο κινητήρας αναβαθμίστηκε" },
			{ lang::English, "Engine Upgraded" },
			{ lang::Spanish, "Motor actualizado" },
			{ lang::Finnish, "Moottori uusittu" },
			{ lang::French, "Moteur renforcé" },
			{ lang::Hebrew, "Engine Upgraded" },
			{ lang::Hungarian, "Motor korszerűsítve" },
			{ lang::Italian, "Motore potenziato" },
			{ lang::Japanese, "エンジンをアップ\nグレード!" },
			{ lang::Korean, "엔진 강화" },
			{ lang::Norwegian, "Motor oppgradert" },
			{ lang::Dutch, "Motor opgewaardeerd" },
			{ lang::Polish, "Modernizacja silnika" },
			{ lang::BrazilianPortuguese, "Mecanismo atualizado" },
			{ lang::Portuguese, "Motor reforçado" },
			{ lang::Russian, "Двигатель Улучшен" },
			{ lang::Swedish, "Motorn uppgraderas" },
			{ lang::Turkish, "Motor Yenilendi" },
			{ lang::SimplifiedChinese, "引擎已升级" },
			{ lang::TraditionalChinese, "引擎升級" },
		},
	},
	{
		Msg::STRING108,
		{
			{ lang::Arabic, "Bonus up 1 Million" },
			{ lang::Czech, "Bonus navršení do 1 miliónu" },
			{ lang::Danish, "Bonus forhøjet med 1 million" },
			{ lang::German, "1 Million Bonus" },
			{ lang::Greek, "Μπόνους 1 εκατομμύριο" },
			{ lang::English, "Bonus up 1 Million" },
			{ lang::Spanish, "Bonificación de 1 millón" },
			{ lang::Finnish, "Lisäbonus: 1 000 000" },
			{ lang::French, "Bonus augmenté de 1 million" },
			{ lang::Hebrew, "Bonus up 1 Million" },
			{ lang::Hungarian, "Egymilliós bónusz" },
			{ lang::Italian, "Bonus aumentato a un milione" },
			{ lang::Japanese, "ボーナス アップ 1,000,000" },
			{ lang::Korean, "1백만점 보너스" },
			{ lang::Norwegian, "Bonus opp 1 million" },
			{ lang::Dutch, "1 miljoen extra bonuspunten" },
			{ lang::Polish, "Premia - 1 milion" },
			{ lang::BrazilianPortuguese, "Bônus acrescido de 1 milhão" },
			{ lang::Portuguese, "Bónus aumentado em 1 milhão" },
			{ lang::Russian, "Бонус Увеличен на 1 Миллион" },
			{ lang::Swedish, "1 miljon högre bonus" },
			{ lang::Turkish, "1 Milyon üzeri ödülü" },
			{ lang::SimplifiedChinese, "奖分到一百万" },
			{ lang::TraditionalChinese, "加分達到一百萬" },
		},
	},
	{
		Msg::STRING109,
		{
			{ lang::Arabic, "Extra Ball Available\n%ld" },
			{ lang::Czech, "Možnost míčku navíc\n%ld" },
			{ lang::Danish, "Ekstra kugle\n%ld" },
			{ lang::German, "Extrakugel verfügbar\n%ld" },
			{ lang::Greek, "Πρόσθετη μπίλια διαθέσιμη\n%ld" },
			{ lang::English, "Extra Ball Available\n%ld" },
			{ lang::Spanish, "Bola extra disponible\n%ld" },
			{ lang::Finnish, "Lisäpallo saatavana\n%ld" },
			{ lang::French, "Bille supplémentaire disponible\n%ld" },
			{ lang::Hebrew, "Extra Ball Available\n%ld" },
			{ lang::Hungarian, "Extra golyó ajánlat\n%ld" },
			{ lang::Italian, "Altra pallina disponibile\n%ld" },
			{ lang::Japanese, "エキストラ ボール\nライト点灯 %ld" },
			{ lang::Korean, "남아 있는 보너스 구슬\n%ld" },
			{ lang::Norwegian, "Ekstra ball tilgjengelig\n%ld" },
			{ lang::Dutch, "Extra bal beschikbaar\n%ld" },
			{ lang::Polish, "Dostępna dodatkowa kulka\n%ld" },
			{ lang::BrazilianPortuguese, "Bola extra disponível\n%ld" },
			{ lang::Portuguese, "Bola extra disponível\n%ld" },
			{ lang::Russian, "Доступен Экстра Шарик %ld" },
			{ lang::Swedish, "Möjlighet till extraboll\n%ld" },
			{ lang::Turkish, "Ek Top Var\n%ld" },
			{ lang::SimplifiedChinese, "可用加分球\n%ld" },
			{ lang::TraditionalChinese, "其他可用的彈珠\n%ld" },
		},
	},
	{
		Msg::STRING110,
		{
			{ lang::Arabic, "Extra Ball" },
			{ lang::Czech, "Míček navíc" },
			{ lang::Danish, "Ekstra kugle" },
			{ lang::German, "Extrakugel" },
			{ lang::Greek, "Πρόσθετη μπίλια" },
			{ lang::English, "Extra Ball" },
			{ lang::Spanish, "Bola extra" },
			{ lang::Finnish, "Lisäpallo" },
			{ lang::French, "Bille supplémentaire" },
			{ lang::Hebrew, "Extra Ball" },
			{ lang::Hungarian, "Extra golyó" },
			{ lang::Italian, "Altra pallina vinta" },
			{ lang::Japanese, "エクストラ ボール" },
			{ lang::Korean, "보너스 구슬" },
			{ lang::Norwegian, "Ekstra ball" },
			{ lang::Dutch, "Extra bal" },
			{ lang::Polish, "Dodatkowa kulka" },
			{ lang::BrazilianPortuguese, "Bola extra" },
			{ lang::Portuguese, "Bola extra" },
			{ lang::Russian, "Экстра Шарик" },
			{ lang::Swedish, "Extraboll" },
			{ lang::Turkish, "Ek Top" },
			{ lang::SimplifiedChinese, "加分球" },
			{ lang::TraditionalChinese, "額外的彈珠" },
		},
	},
	{
		Msg::STRING111,
		{
			{ lang::Arabic, "Reflex Shot Award\n%ld" },
			{ lang::Czech, "Ocenění za rychlou trefu\n%ld" },
			{ lang::Danish, "Gentagelsesbonus\n%ld" },
			{ lang::German, "Reflexschuss gewonnen\n%ld" },
			{ lang::Greek, "Βράβευση γρήγορων αντανακλαστικών\n%ld" },
			{ lang::English, "Reflex Shot Award\n%ld" },
			{ lang::Spanish, "Premio de tiro devuelto\n%ld" },
			{ lang::Finnish, "Refleksilyönti\n%ld" },
			{ lang::French, "Prix pour tir de réflexe\n%ld" },
			{ lang::Hebrew, "Reflex Shot Award\n%ld" },
			{ lang::Hungarian, "Gyorstüzelési jutalom\n%ld" },
			{ lang::Italian, "Colpo veloce concesso\n%ld" },
			{ lang::Japanese, "リフレックス ショット %ld" },
			{ lang::Korean, "연속 맞히기 보너스\n%ld" },
			{ lang::Norwegian, "Pris for refleksskudd\n%ld" },
			{ lang::Dutch, "Reflexschot toegekend\n%ld" },
			{ lang::Polish, "Nagroda za odbity strzał\n%ld" },
			{ lang::BrazilianPortuguese, "Ganhou supertiro\n%ld" },
			{ lang::Portuguese, "Prémio de tiro de reflexo\n%ld" },
			{ lang::Russian, "Рефлекторный Запуск\n%ld" },
			{ lang::Swedish, "Bonus för reflexskott\n%ld" },
			{ lang::Turkish, "Refleks Atış Ödülü\n%ld" },
			{ lang::SimplifiedChinese, "反射射中奖励\n%ld" },
			{ lang::TraditionalChinese, "來回彈射中獎\n%ld" },
		},
	},
	{
		Msg::STRING112,
		{
			{ lang::Arabic, "Final Battle Won" },
			{ lang::Czech, "Závěrečná bitva vyhrána!" },
			{ lang::Danish, "Du har vundet det endelige slag" },
			{ lang::German, "Finale gewonnen" },
			{ lang::Greek, "Η τελική μάχη κερδήθηκε" },
			{ lang::English, "Final Battle Won" },
			{ lang::Spanish, "Ganó la batalla final" },
			{ lang::Finnish, "Ratkaiseva taistelu voitettu" },
			{ lang::French, "Bataille finale gagnée" },
			{ lang::Hebrew, "Final Battle Won" },
			{ lang::Hungarian, "A végső csata eldőlt" },
			{ lang::Italian, "Battaglia finale vinta" },
			{ lang::Japanese, "最終バトル勝利!" },
			{ lang::Korean, "최종 승리" },
			{ lang::Norwegian, "Vant siste slag" },
			{ lang::Dutch, "Finalegevecht gewonnen" },
			{ lang::Polish, "Ostateczne zwycięstwo" },
			{ lang::BrazilianPortuguese, "Batalha final vencida" },
			{ lang::Portuguese, "Ganhou a batalha final" },
			{ lang::Russian, "Финальная Битва Выиграна" },
			{ lang::Swedish, "Slutstriden vunnen" },
			{ lang::Turkish, "Son Savaş Kazanıldı" },
			{ lang::SimplifiedChinese, "决战胜利" },
			{ lang::TraditionalChinese, "贏得最後勝利" },
		},
	},
	{
		Msg::STRING113,
		{
			{ lang::Arabic, "Hyperspace Bonus\n%ld" },
			{ lang::Czech, "Hyperprostorový bonus\n%ld" },
			{ lang::Danish, "Hyperspacebonus tildelt\n%ld" },
			{ lang::German, "Hyperspace-Bonus\n%ld" },
			{ lang::Greek, "Μπόνους υπερδιαστήματος\n%ld" },
			{ lang::English, "Hyperspace Bonus\n%ld" },
			{ lang::Spanish, "Bonificación hiperespacio\n%ld" },
			{ lang::Finnish, "Hyperavaruusbonus\n%ld" },
			{ lang::French, "Bonus de l'hyper-espace\n%ld" },
			{ lang::Hebrew, "Hyperspace Bonus\n%ld" },
			{ lang::Hungarian, "Hipertér bónusz\n%ld" },
			{ lang::Italian, "Bonus iperspaziale vinto\n%ld" },
			{ lang::Japanese, "ハイパースペース\nボーナス %ld" },
			{ lang::Korean, "하이퍼스페이스 보너스\n%ld" },
			{ lang::Norwegian, "Hyperrombonus\n%ld" },
			{ lang::Dutch, "Hyperspacebonus\n%ld" },
			{ lang::Polish, "Premia hiperprzestrzeni\n%ld" },
			{ lang::BrazilianPortuguese, "Bônus do hiperespaço!\n%ld" },
			{ lang::Portuguese, "Bónus hiperespaço\n%ld" },
			{ lang::Russian, "Бонус за Гипер Пространство %ld" },
			{ lang::Swedish, "Hyperspace-bonus\n%ld" },
			{ lang::Turkish, "Uzay Boşluğu Ödülü\n%ld" },
			{ lang::SimplifiedChinese, "超空间奖分\n%ld" },
			{ lang::TraditionalChinese, "超空間紅利\n%ld" },
		},
	},
	{
		Msg::STRING114,
		{
			{ lang::Arabic, "Hyperspace Bonus Available" },
			{ lang::Czech, "Možnost hyperprostorového bonusu" },
			{ lang::Danish, "Hyperspacebonus tilgængelig" },
			{ lang::German, "Hyperspace-Bonus verfügbar" },
			{ lang::Greek, "Το μπόνους υπερδιαστήματος είναι διαθέσιμο" },
			{ lang::English, "Hyperspace Bonus Available" },
			{ lang::Spanish, "Bonificación hiperespacio disponible" },
			{ lang::Finnish, "Hyperavaruusbonus saatavana" },
			{ lang::French, "Bonus de l'hyper-espace activé" },
			{ lang::Hebrew, "Hyperspace Bonus Available" },
			{ lang::Hungarian, "Hipertér bónusz ajánlat" },
			{ lang::Italian, "Bonus iperspaziale disponibile" },
			{ lang::Japanese, "ハイパースペース ボーナス" },
			{ lang::Korean, "하이퍼스페이스 보너스 기회" },
			{ lang::Norwegian, "Hyperrombonus tilgjengelig" },
			{ lang::Dutch, "Hyperspacebonus beschikbaar" },
			{ lang::Polish, "Dostępna premia hiperprzestrzeni" },
			{ lang::BrazilianPortuguese, "Bônus disponível no hiperespaço" },
			{ lang::Portuguese, "Bónus hiperespaço disponível" },
			{ lang::Russian, "Доступен Гипер Пространственный Бонус" },
			{ lang::Swedish, "Möjlighet till hyperspace-bonus" },
			{ lang::Turkish, "Uzay Boşluğu Ödülü Var" },
			{ lang::SimplifiedChinese, "可用超空间奖分" },
			{ lang::TraditionalChinese, "可用的超空間紅利" },
		},
	},
	{
		Msg::STRING115,
		{
			{ lang::Arabic, "Jackpot Awarded\n%ld" },
			{ lang::Czech, "Ocenění jackpotem\n%ld" },
			{ lang::Danish, "Jackpot tildelt\n%ld" },
			{ lang::German, "Jackpot gewonnen\n%ld" },
			{ lang::Greek, "Σύνολο κερδισμένων βραβεύσεων\n%ld" },
			{ lang::English, "Jackpot Awarded\n%ld" },
			{ lang::Spanish, "Premiado con Jackpot\n%ld" },
			{ lang::Finnish, "Jackpot\n%ld" },
			{ lang::French, "Jackpot\n%ld" },
			{ lang::Hebrew, "Jackpot Awarded\n%ld" },
			{ lang::Hungarian, "Jackpot\n%ld" },
			{ lang::Italian, "Monte premi vinto\n%ld" },
			{ lang::Japanese, "ジャックポット獲得!\n%ld" },
			{ lang::Korean, "잭팟\n%ld" },
			{ lang::Norwegian, "Jackpot\n%ld" },
			{ lang::Dutch, "Jackpot toegekend\n%ld" },
			{ lang::Polish, "Pula nagród przyznana\n%ld" },
			{ lang::BrazilianPortuguese, "Ganhou superprêmio!!\n%ld" },
			{ lang::Portuguese, "Prémio jackpot\n%ld" },
			{ lang::Russian, "Выдан Джекпот\n%ld" },
			{ lang::Swedish, "Jackpot\n%ld" },
			{ lang::Turkish, "İkramiye Verildi\n%ld" },
			{ lang::SimplifiedChinese, "中头奖了\n%ld" },
			{ lang::TraditionalChinese, "您中了幸運大獎\n%ld" },
		},
	},
	{
		Msg::STRING116,
		{
			{ lang::Arabic, "Jackpot Activated" },
			{ lang::Czech, "Jackpot aktivován" },
			{ lang::Danish, "Jackpot slået til" },
			{ lang::German, "Jackpot aktivierts" },
			{ lang::Greek, "Ενεργοποίηση συνόλου  βραβεύσεων" },
			{ lang::English, "Jackpot Activated" },
			{ lang::Spanish, "Jackpot activado" },
			{ lang::Finnish, "Jackpot aktivoitu" },
			{ lang::French, "Jackpot activé" },
			{ lang::Hebrew, "Jackpot Activated" },
			{ lang::Hungarian, "Jackpot kijátszva" },
			{ lang::Italian, "Monte premi attivato" },
			{ lang::Japanese, "ジャック\nポット スタート!" },
			{ lang::Korean, "잭팟 기회" },
			{ lang::Norwegian, "Jackpot aktivert" },
			{ lang::Dutch, "Jackpot geactiveerd" },
			{ lang::Polish, "Pula nagród aktywna" },
			{ lang::BrazilianPortuguese, "Superprêmio ativado" },
			{ lang::Portuguese, "Jackpot Activado" },
			{ lang::Russian, "Джекпот Активирован" },
			{ lang::Swedish, "Jackpot på" },
			{ lang::Turkish, "İkramiye Etkin" },
			{ lang::SimplifiedChinese, "启动头奖" },
			{ lang::TraditionalChinese, "啟動幸運大獎" },
		},
	},
	{
		Msg::STRING117,
		{
			{ lang::Arabic, "Multiball" },
			{ lang::Czech, "Více míčků" },
			{ lang::Danish, "Flere kugler" },
			{ lang::German, "Multiball" },
			{ lang::Greek, "Πολλές μπίλιες" },
			{ lang::English, "Multiball" },
			{ lang::Spanish, "Multibola" },
			{ lang::Finnish, "Monipallo" },
			{ lang::French, "Billes multiples" },
			{ lang::Hebrew, "Multiball" },
			{ lang::Hungarian, "Golyóözön" },
			{ lang::Italian, "Più palline" },
			{ lang::Japanese, "マルチボール" },
			{ lang::Korean, "둘 이상의 구슬" },
			{ lang::Norwegian, "Multiball" },
			{ lang::Dutch, "Multibal" },
			{ lang::Polish, "Kilka kulek" },
			{ lang::BrazilianPortuguese, "Multibola" },
			{ lang::Portuguese, "Multibola" },
			{ lang::Russian, "Мультиболл" },
			{ lang::Swedish, "Multiball" },
			{ lang::Turkish, "Çok Top" },
			{ lang::SimplifiedChinese, "多个球" },
			{ lang::TraditionalChinese, "多重彈珠" },
		},
	},
	{
		Msg::STRING118,
		{
			{ lang::Arabic, "Ramp Bonus Awarded" },
			{ lang::Czech, "Ocenění bonusem rampy" },
			{ lang::Danish, "Rampebonus tildelt" },
			{ lang::German, "Rampenbonus gewonnen" },
			{ lang::Greek, "Απονομή μπόνους ράμπας" },
			{ lang::English, "Ramp Bonus Awarded" },
			{ lang::Spanish, "Bonificación de rampa concedida" },
			{ lang::Finnish, "Ramppibonus saatu" },
			{ lang::French, "Bonus de rampe" },
			{ lang::Hebrew, "Ramp Bonus Awarded" },
			{ lang::Hungarian, "Rámpa bónusz" },
			{ lang::Italian, "Bonus sulla rampa vinto" },
			{ lang::Japanese, "ランプ ボーナス獲得!" },
			{ lang::Korean, "발사대 보너스" },
			{ lang::Norwegian, "Rampebonus" },
			{ lang::Dutch, "Hellingbonus toegekend" },
			{ lang::Polish, "Premia pomostu przyznana" },
			{ lang::BrazilianPortuguese, "Ganhou bônus da rampa" },
			{ lang::Portuguese, "Bónus de rampa concedido" },
			{ lang::Russian, "Выдан Бонус За Рампу" },
			{ lang::Swedish, "Rampbonus" },
			{ lang::Turkish, "Pist Ödülü Verildi" },
			{ lang::SimplifiedChinese, "坡道奖分" },
			{ lang::TraditionalChinese, "超級額外加分" },
		},
	},
	{
		Msg::STRING119,
		{
			{ lang::Arabic, "Light Added" },
			{ lang::Czech, "Odlehčení" },
			{ lang::Danish, "Lys tilføjet" },
			{ lang::German, "Licht ein" },
			{ lang::Greek, "Ενεργοποιημένα φώτα" },
			{ lang::English, "Light Added" },
			{ lang::Spanish, "Luz agregada" },
			{ lang::Finnish, "Valot kytketty" },
			{ lang::French, "Lumière en plus" },
			{ lang::Hebrew, "Light Added" },
			{ lang::Hungarian, "Fények bekapcsolva" },
			{ lang::Italian, "Luci attivate" },
			{ lang::Japanese, "ライト追加" },
			{ lang::Korean, "라이트 추가" },
			{ lang::Norwegian, "Lagt til lys" },
			{ lang::Dutch, "Lampje toegevoegd" },
			{ lang::Polish, "Światełko dodane" },
			{ lang::BrazilianPortuguese, "Luz adicionada" },
			{ lang::Portuguese, "Luz adicionada" },
			{ lang::Russian, "Добавлен Свет" },
			{ lang::Swedish, "Extra lampa" },
			{ lang::Turkish, "Işık Eklendi" },
			{ lang::SimplifiedChinese, "增加灯光" },
			{ lang::TraditionalChinese, "新增光線" },
		},
	},
	{
		Msg::STRING120,
		{
			{ lang::Arabic, "Ramp Bonus On" },
			{ lang::Czech, "Bonus rampy zapnut" },
			{ lang::Danish, "Rampebonus slået til" },
			{ lang::German, "Rampenbonus ein" },
			{ lang::Greek, "Ενεργοποίηση μπόνους ράμπας" },
			{ lang::English, "Ramp Bonus On" },
			{ lang::Spanish, "Bonificación de rampa activada" },
			{ lang::Finnish, "Ramppibonus saatavana" },
			{ lang::French, "Bonus de rampe actif" },
			{ lang::Hebrew, "Ramp Bonus On" },
			{ lang::Hungarian, "Rámpa bónusz kijátszva" },
			{ lang::Italian, "Bonus sulla rampa attivato" },
			{ lang::Japanese, "ランプ ボーナス オン" },
			{ lang::Korean, "발사대 보너스 설정" },
			{ lang::Norwegian, "Rampebonus på" },
			{ lang::Dutch, "Hellingbonus geactiveerd" },
			{ lang::Polish, "Premia pomostu włączona" },
			{ lang::BrazilianPortuguese, "Bônus da rampa ativado" },
			{ lang::Portuguese, "Bónus de rampa activado" },
			{ lang::Russian, "Бонус за Рампу Включен" },
			{ lang::Swedish, "Rampbonus på" },
			{ lang::Turkish, "Pist Ödülü Var" },
			{ lang::SimplifiedChinese, "已设好坡道奖分" },
			{ lang::TraditionalChinese, "超級加分開啟" },
		},
	},
	{
		Msg::STRING121,
		{
			{ lang::Arabic, "Light Reset Off" },
			{ lang::Czech, "Zrušení odlehčení vypnuto" },
			{ lang::Danish, "Nulstilling af lys slået fra" },
			{ lang::German, "Licht deaktiviert" },
			{ lang::Greek, "Απενεργοποιημένα φώτα" },
			{ lang::English, "Light Reset Off" },
			{ lang::Spanish, "Restauración de luz desactivada" },
			{ lang::Finnish, "Valot kytketty pois" },
			{ lang::French, "Lumière désactivée" },
			{ lang::Hebrew, "Light Reset Off" },
			{ lang::Hungarian, "Fények kikapcsolva" },
			{ lang::Italian, "Luci disattivate" },
			{ lang::Japanese, "ライト リセット オフ" },
			{ lang::Korean, "라이트 재설정 해제" },
			{ lang::Norwegian, "Tilbakestillingslys av" },
			{ lang::Dutch, "Beginwaarden lampjes uitgeschakeld" },
			{ lang::Polish, "Światełko wyłączone" },
			{ lang::BrazilianPortuguese, "Luz de inicialização apagada" },
			{ lang::Portuguese, "Bónus de rampa desactivado" },
			{ lang::Russian, "Сброс Света Выключен" },
			{ lang::Swedish, "Lampor återställs ej" },
			{ lang::Turkish, "Işık Sıfırlama Kapalı" },
			{ lang::SimplifiedChinese, "关闭灯光复位" },
			{ lang::TraditionalChinese, "關閉光線重設" },
		},
	},
	{
		Msg::STRING122,
		{
			{ lang::Arabic, "Skill Shot\n%ld" },
			{ lang::Czech, "Střela dovednosti\n%ld" },
			{ lang::Danish, "Præcisionsskud\n%ld" },
			{ lang::German, "Extradurchlauf\n%ld" },
			{ lang::Greek, "Βολή επιδεξιότητας\n%ld" },
			{ lang::English, "Skill Shot\n%ld" },
			{ lang::Spanish, "Tiro hábil\n%ld" },
			{ lang::Finnish, "Taitolyönti\n%ld" },
			{ lang::French, "Tir d'adresse\n%ld" },
			{ lang::Hebrew, "Skill Shot\n%ld" },
			{ lang::Hungarian, "Célba lövés\n%ld" },
			{ lang::Italian, "Bel colpo!\n%ld" },
			{ lang::Japanese, "スキル ショット!\n%ld" },
			{ lang::Korean, "쏘기 기술 점수\n%ld" },
			{ lang::Norwegian, "Dyktighetsskudd\n%ld" },
			{ lang::Dutch, "Bekwaamheidsbal\n%ld" },
			{ lang::Polish, "Strzał zręcznościowy\n%ld" },
			{ lang::BrazilianPortuguese, "Jogada de habilidade\n%ld" },
			{ lang::Portuguese, "Tiro hábil\n%ld" },
			{ lang::Russian, "Умелый Запуск\n%ld" },
			{ lang::Swedish, "Bonus för skickligt skott\n%ld" },
			{ lang::Turkish, "Beceri Atışı\n%ld" },
			{ lang::SimplifiedChinese, "高技能发射\n%ld" },
			{ lang::TraditionalChinese, "技術重點\n%ld" },
		},
	},
	{
		Msg::STRING123,
		{
			{ lang::Arabic, "Game Paused\nF3 to Resume" },
			{ lang::Czech, "Hra pozastavena. Pokračujte klávesou F3." },
			{ lang::Danish, "Spillet afbrudt\ntryk på F3 for at fortsætte" },
			{ lang::German, "Spiel angehalten\nWeiter mit F3." },
			{ lang::Greek, "Η παρτίδα διακόπηκε\nF3 για συνέχιση" },
			{ lang::English, "Game Paused\nF3 to Resume" },
			{ lang::Spanish, "Juego pausado\nF3 para reanudar" },
			{ lang::Finnish, "Peli keskeytetty\nPaina F3" },
			{ lang::French, "Partie suspendue\nF3=Reprise" },
			{ lang::Hebrew, "Game Paused\nF3 to Resume" },
			{ lang::Hungarian, "Felfüggesztve\nF3 - folytatás" },
			{ lang::Italian, "Partita interrotta\nF3 per riprendere" },
			{ lang::Japanese, "ゲーム一時停止中\nF3 キーで再開" },
			{ lang::Korean, "게임 일시 중지됨\n계속하려면 <F3> 키" },
			{ lang::Norwegian, "Pause\nF3 for å fortsette" },
			{ lang::Dutch, "Spel is onderbroken\nF3 hervat het spel" },
			{ lang::Polish, "Gra wstrzymana.\nF3 wznawia grę." },
			{ lang::BrazilianPortuguese, "Jogo em pausa\nF3 para continuar" },
			{ lang::Portuguese, "Jogo suspenso\nF3 para continuar" },
			{ lang::Russian, "Игра Приостановлена\nF3 чтобы Продолжить" },
			{ lang::Swedish, "Paus\nF3=Fortsätt" },
			{ lang::Turkish, "Oyun Duraklatıldı\nDevam Etmek için F3'e basın" },
			{ lang::SimplifiedChinese, "游戏暂停\nF3 继续" },
			{ lang::TraditionalChinese, "遊戲暫停\n按 F3 恢復" },
		},
	},
	{
		Msg::STRING124,
		{
			{ lang::Arabic, "Continue Play" },
			{ lang::Czech, "Pokračování hry" },
			{ lang::Danish, "Fortsæt spillet" },
			{ lang::German, "Spiel fortgesetzt" },
			{ lang::Greek, "Συνέχιση του παιχνιδιού" },
			{ lang::English, "Continue Play" },
			{ lang::Spanish, "Continuar jugando" },
			{ lang::Finnish, "Jatka pelaamista" },
			{ lang::French, "Continuer" },
			{ lang::Hebrew, "Continue Play" },
			{ lang::Hungarian, "A játék folytatása" },
			{ lang::Italian, "Continua il gioco" },
			{ lang::Japanese, "プレー続行" },
			{ lang::Korean, "게임 계속 진행" },
			{ lang::Norwegian, "Fortsett spillet" },
			{ lang::Dutch, "Doorgaan met spel" },
			{ lang::Polish, "Kontynuuj grę" },
			{ lang::BrazilianPortuguese, "Continuar a jogar" },
			{ lang::Portuguese, "Continuar o jogo" },
			{ lang::Russian, "Игра Продолжена" },
			{ lang::Swedish, "Fortsätt" },
			{ lang::Turkish, "Oynamaya Devam" },
			{ lang::SimplifiedChinese, "继续玩" },
			{ lang::TraditionalChinese, "連續執行" },
		},
	},
	{
		Msg::STRING125,
		{
			{ lang::Arabic, "F2 Starts New Game" },
			{ lang::Czech, "Stisknutím klávesy F2 zahájíte novou hru." },
			{ lang::Danish, "F2 starter nyt spil" },
			{ lang::German, "F2: Neues Spiel starten" },
			{ lang::Greek, "F2 για να ξεκινήσετε μια νέα παρτίδα" },
			{ lang::English, "F2 Starts New Game" },
			{ lang::Spanish, "F2 inicia un nuevo juego" },
			{ lang::Finnish, "F2: Uusi peli" },
			{ lang::French, "F2 Nouvelle partie" },
			{ lang::Hebrew, "F2 Starts New Game" },
			{ lang::Hungarian, "F2 új játékot kezd" },
			{ lang::Italian, "F2 per iniziare una nuova partita" },
			{ lang::Japanese, "F2 キーで新ゲーム開始" },
			{ lang::Korean, "<F2> 키로 새 게임 시작" },
			{ lang::Norwegian, "F2 starter et nytt spill" },
			{ lang::Dutch, "F2 start een nieuw spel" },
			{ lang::Polish, "F2 rozpoczyna nową grę." },
			{ lang::BrazilianPortuguese, "F2 começa um novo jogo" },
			{ lang::Portuguese, "F2 inicia um novo jogo" },
			{ lang::Russian, "F2 Начинает Новую Игру" },
			{ lang::Swedish, "F2=Nytt spel" },
			{ lang::Turkish, "F2 Yeni Oyun Başlatır" },
			{ lang::SimplifiedChinese, "F2 开局" },
			{ lang::TraditionalChinese, "F2 開始新遊戲" },
		},
	},
	{
		Msg::STRING126,
		{
			{ lang::Arabic, "Careful..." },
			{ lang::Czech, "Opatrně..." },
			{ lang::Danish, "Forsigtig..." },
			{ lang::German, "Vorsicht..." },
			{ lang::Greek, "Προσοχή..." },
			{ lang::English, "Careful..." },
			{ lang::Spanish, "Cuidado..." },
			{ lang::Finnish, "Ole varovainen..." },
			{ lang::French, "Attention..." },
			{ lang::Hebrew, "Careful..." },
			{ lang::Hungarian, "Óvatosabban..." },
			{ lang::Italian, "Attenzione..." },
			{ lang::Japanese, "注意..." },
			{ lang::Korean, "조심하세요..." },
			{ lang::Norwegian, "Forsiktig..." },
			{ lang::Dutch, "Voorzichtig..." },
			{ lang::Polish, "Ostrożnie..." },
			{ lang::BrazilianPortuguese, "Cuidado..." },
			{ lang::Portuguese, "Cuidado..." },
			{ lang::Russian, "Осторожно..." },
			{ lang::Swedish, "Försiktigt..." },
			{ lang::Turkish, "Dikkat..." },
			{ lang::SimplifiedChinese, "小心..." },
			{ lang::TraditionalChinese, "小心..." },
		},
	},
	{
		Msg::STRING127,
		{
			{ lang::Arabic, "Player 1" },
			{ lang::Czech, "Hráč 1" },
			{ lang::Danish, "Spiller 1" },
			{ lang::German, "Spieler 1" },
			{ lang::Greek, "Παίκτης 1" },
			{ lang::English, "Player 1" },
			{ lang::Spanish, "Jugador 1" },
			{ lang::Finnish, "Pelaaja 1" },
			{ lang::French, "Joueur 1" },
			{ lang::Hebrew, "Player 1" },
			{ lang::Hungarian, "1. játékos" },
			{ lang::Italian, "Giocatore 1" },
			{ lang::Japanese, "プレーヤー 1" },
			{ lang::Korean, "비행사 1" },
			{ lang::Norwegian, "Spiller 1" },
			{ lang::Dutch, "Speler 1" },
			{ lang::Polish, "Gracz 1" },
			{ lang::BrazilianPortuguese, "Jogador 1" },
			{ lang::Portuguese, "Jogador 1" },
			{ lang::Russian, "Игрок  1" },
			{ lang::Swedish, "Spelare 1" },
			{ lang::Turkish, "1. Oyuncu" },
			{ lang::SimplifiedChinese, "玩家 1" },
			{ lang::TraditionalChinese, "玩家 1" },
		},
	},
	{
		Msg::STRING128,
		{
			{ lang::Arabic, "Player 2" },
			{ lang::Czech, "Hráč 2" },
			{ lang::Danish, "Spiller 2" },
			{ lang::German, "Spieler 2" },
			{ lang::Greek, "Παίκτης 2" },
			{ lang::English, "Player 2" },
			{ lang::Spanish, "Jugador 2" },
			{ lang::Finnish, "Pelaaja 2" },
			{ lang::French, "Joueur 2" },
			{ lang::Hebrew, "Player 2" },
			{ lang::Hungarian, "2. játékos" },
			{ lang::Italian, "Giocatore 2" },
			{ lang::Japanese, "プレーヤー 2" },
			{ lang::Korean, "비행사 2" },
			{ lang::Norwegian, "Spiller 2" },
			{ lang::Dutch, "Speler 2" },
			{ lang::Polish, "Gracz 2" },
			{ lang::BrazilianPortuguese, "Jogador 2" },
			{ lang::Portuguese, "Jogador 2" },
			{ lang::Russian, "Игрок  2" },
			{ lang::Swedish, "Spelare 2" },
			{ lang::Turkish, "2. Oyuncu" },
			{ lang::SimplifiedChinese, "玩家 2" },
			{ lang::TraditionalChinese, "玩家 2" },
		},
	},
	{
		Msg::STRING129,
		{
			{ lang::Arabic, "Player 3" },
			{ lang::Czech, "Hráč 3" },
			{ lang::Danish, "Spiller 3" },
			{ lang::German, "Spieler 3" },
			{ lang::Greek, "Παίκτης 3" },
			{ lang::English, "Player 3" },
			{ lang::Spanish, "Jugador 3" },
			{ lang::Finnish, "Pelaaja 3" },
			{ lang::French, "Joueur 3" },
			{ lang::Hebrew, "Player 3" },
			{ lang::Hungarian, "3. játékos" },
			{ lang::Italian, "Giocatore 3" },
			{ lang::Japanese, "プレーヤー 3" },
			{ lang::Korean, "비행사 3" },
			{ lang::Norwegian, "Spiller 3" },
			{ lang::Dutch, "Speler 3" },
			{ lang::Polish, "Gracz 3" },
			{ lang::BrazilianPortuguese, "Jogador 3" },
			{ lang::Portuguese, "Jogador 3" },
			{ lang::Russian, "Игрок  3" },
			{ lang::Swedish, "Spelare 3" },
			{ lang::Turkish, "3. Oyuncu" },
			{ lang::SimplifiedChinese, "玩家 3" },
			{ lang::TraditionalChinese, "玩家 3" },
		},
	},
	{
		Msg::STRING130,
		{
			{ lang::Arabic, "Player 4" },
			{ lang::Czech, "Hráč 4" },
			{ lang::Danish, "Spiller 4" },
			{ lang::German, "Spieler 4" },
			{ lang::Greek, "Παίκτης 4" },
			{ lang::English, "Player 4" },
			{ lang::Spanish, "Jugador 4" },
			{ lang::Finnish, "Pelaaja 4" },
			{ lang::French, "Joueur 4" },
			{ lang::Hebrew, "Player 4" },
			{ lang::Hungarian, "4. játékos" },
			{ lang::Italian, "Giocatore 4" },
			{ lang::Japanese, "プレーヤー 4" },
			{ lang::Korean, "비행사 4" },
			{ lang::Norwegian, "Spiller 4" },
			{ lang::Dutch, "Speler 4" },
			{ lang::Polish, "Gracz 4" },
			{ lang::BrazilianPortuguese, "Jogador 4" },
			{ lang::Portuguese, "Jogador 4" },
			{ lang::Russian, "Игрок  4" },
			{ lang::Swedish, "Spelare 4" },
			{ lang::Turkish, "4. Oyuncu" },
			{ lang::SimplifiedChinese, "玩家 4" },
			{ lang::TraditionalChinese, "玩家 4" },
		},
	},
	{
		Msg::STRING131,
		{
			{ lang::Arabic, "Demo\nPlayer 1" },
			{ lang::Czech, "Demo\nHráč 1" },
			{ lang::Danish, "Demo\nSpiller 1" },
			{ lang::German, "Demo\nSpieler 1" },
			{ lang::Greek, "Δοκιμή\nΠαίκτης 1" },
			{ lang::English, "Demo\nPlayer 1" },
			{ lang::Spanish, "Demostración\nJugador 1" },
			{ lang::Finnish, "Demo\nPelaaja 1" },
			{ lang::French, "Démo\nJoueur 1" },
			{ lang::Hebrew, "Demo\nPlayer 1" },
			{ lang::Hungarian, "Bemutató játék\n1. játékos" },
			{ lang::Italian, "Dimostrazione\nGiocatore 1" },
			{ lang::Japanese, "デモ\nプレーヤー 1" },
			{ lang::Korean, "데모\n비행사 1" },
			{ lang::Norwegian, "Demo\nSpiller 1" },
			{ lang::Dutch, "Demo\nSpeler 1" },
			{ lang::Polish, "Pokaz\nGracz 1" },
			{ lang::BrazilianPortuguese, "Demonstração\nJogador 1" },
			{ lang::Portuguese, "Demonstração \nJogador 1" },
			{ lang::Russian, "Демо\nИгрок 1" },
			{ lang::Swedish, "Demo\nSpelare 1" },
			{ lang::Turkish, "Gösteri\n1. Oyuncu" },
			{ lang::SimplifiedChinese, "演示\n玩家 1" },
			{ lang::TraditionalChinese, "展示\n玩家 1" },
		},
	},
	{
		Msg::STRING132,
		{
			{ lang::Arabic, "Demo\nPlayer 2" },
			{ lang::Czech, "Demo\nHráč 2" },
			{ lang::Danish, "Demo\nSpiller 2" },
			{ lang::German, "Demo\nSpieler 2" },
			{ lang::Greek, "Δοκιμή\nΠαίκτης 2" },
			{ lang::English, "Demo\nPlayer 2" },
			{ lang::Spanish, "Demostración\nJugador 2" },
			{ lang::Finnish, "Demo\nPelaaja 2" },
			{ lang::French, "Démo\nJoueur 2" },
			{ lang::Hebrew, "Demo\nPlayer 2" },
			{ lang::Hungarian, "Bemutató játék\n2. játékos" },
			{ lang::Italian, "Dimostrazione\nGiocatore 2" },
			{ lang::Japanese, "デモ\nプレーヤー 2" },
			{ lang::Korean, "데모\n비행사 2" },
			{ lang::Norwegian, "Demo\nSpiller 2" },
			{ lang::Dutch, "Demo\nSpeler 2" },
			{ lang::Polish, "Pokaz\nGracz 2" },
			{ lang::BrazilianPortuguese, "Demonstração\nJogador 2" },
			{ lang::Portuguese, "Demonstração \nJogador 2" },
			{ lang::Russian, "Демо\nИгрок 2" },
			{ lang::Swedish, "Demo\nSpelare 2" },
			{ lang::Turkish, "Gösteri\n2. Oyuncu" },
			{ lang::SimplifiedChinese, "演示\n玩家 2" },
			{ lang::TraditionalChinese, "展示\n玩家 2" },
		},
	},
	{
		Msg::STRING133,
		{
			{ lang::Arabic, "Demo\nPlayer 3" },
			{ lang::Czech, "Demo\nHráč 3" },
			{ lang::Danish, "Demo\nSpiller 3" },
			{ lang::German, "Demo\nSpieler 3" },
			{ lang::Greek, "Δοκιμή\nΠαίκτης 3" },
			{ lang::English, "Demo\nPlayer 3" },
			{ lang::Spanish, "Demostración\nJugador 3" },
			{ lang::Finnish, "Demo\nPelaaja 3" },
			{ lang::French, "Démo\nJoueur 3" },
			{ lang::Hebrew, "Demo\nPlayer 3" },
			{ lang::Hungarian, "Bemutató játék\n3. játékos" },
			{ lang::Italian, "Dimostrazione\nGiocatore 3" },
			{ lang::Japanese, "デモ\nプレーヤー 3" },
			{ lang::Korean, "데모\n비행사 3" },
			{ lang::Norwegian, "Demo\nSpiller 3" },
			{ lang::Dutch, "Demo\nSpeler 3" },
			{ lang::Polish, "Pokaz\nGracz 3" },
			{ lang::BrazilianPortuguese, "Demonstração\nJogador 3" },
			{ lang::Portuguese, "Demonstração \nJogador 3" },
			{ lang::Russian, "Демо\nИгрок 3" },
			{ lang::Swedish, "Demo\nSpelare 3" },
			{ lang::Turkish, "Gösteri\n3. Oyuncu" },
			{ lang::SimplifiedChinese, "演示\n玩家 3" },
			{ lang::TraditionalChinese, "展示\n玩家 3" },
		},
	},
	{
		Msg::STRING134,
		{
			{ lang::Arabic, "Demo\nPlayer 4" },
			{ lang::Czech, "Demo\nHráč 4" },
			{ lang::Danish, "Demo\nSpiller 4" },
			{ lang::German, "Demo\nSpieler 4" },
			{ lang::Greek, "Δοκιμή\nΠαίκτης 4" },
			{ lang::English, "Demo\nPlayer 4" },
			{ lang::Spanish, "Demostración\nJugador 4" },
			{ lang::Finnish, "Demo\nPelaaja 4" },
			{ lang::French, "Démo\nJoueur 4" },
			{ lang::Hebrew, "Demo\nPlayer 4" },
			{ lang::Hungarian, "Bemutató játék\n4. játékos" },
			{ lang::Italian, "Dimostrazione\nGiocatore 4" },
			{ lang::Japanese, "デモ\nプレーヤー 4" },
			{ lang::Korean, "데모\n비행사 4" },
			{ lang::Norwegian, "Demo\nSpiller 4" },
			{ lang::Dutch, "Demo\nSpeler 4" },
			{ lang::Polish, "Pokaz\nGracz 4" },
			{ lang::BrazilianPortuguese, "Demonstração\nJogador 4" },
			{ lang::Portuguese, "Demonstração \nJogador 4" },
			{ lang::Russian, "Демо\nИгрок 4" },
			{ lang::Swedish, "Demo\nSpelare 4" },
			{ lang::Turkish, "Gösteri\n4. Oyuncu" },
			{ lang::SimplifiedChinese, "演示\n玩家 4" },
			{ lang::TraditionalChinese, "展示\n玩家 4" },
		},
	},
	{
		Msg::STRING135,
		{
			{ lang::Arabic, "انتهت اللعبة" },
			{ lang::Czech, "Konec hry" },
			{ lang::Danish, "Spillet er slut" },
			{ lang::German, "Spiel beendet!" },
			{ lang::Greek, "Τέλος παρτίδας" },
			{ lang::English, "Game Over" },
			{ lang::Spanish, "Juego terminado" },
			{ lang::Finnish, "Peli ohi" },
			{ lang::French, "Partie terminée" },
			{ lang::Hebrew, "Game Over" },
			{ lang::Hungarian, "A játék véget ért" },
			{ lang::Italian, "Fine partita" },
			{ lang::Japanese, "ゲーム オーバー" },
			{ lang::Korean, "게임 끝" },
			{ lang::Norwegian, "Spillet er slutt" },
			{ lang::Dutch, "Het spel is afgelopen" },
			{ lang::Polish, "Koniec gry" },
			{ lang::BrazilianPortuguese, "Fim de jogo" },
			{ lang::Portuguese, "Fim do jogo" },
			{ lang::Russian, "Игра Окончена" },
			{ lang::Swedish, "Spelet är slut" },
			{ lang::Turkish, "Oyun Bitti" },
			{ lang::SimplifiedChinese, "游戏结束" },
			{ lang::TraditionalChinese, "遊戲結束" },
		},
	},
	{
		Msg::STRING136,
		{
			{ lang::Arabic, "TILT!" },
			{ lang::Czech, "KŘACH!" },
			{ lang::Danish, "TILT!" },
			{ lang::German, "TILT!" },
			{ lang::Greek, "Tιλτ!" },
			{ lang::English, "TILT!" },
			{ lang::Spanish, "FALTA" },
			{ lang::Finnish, "TILT!" },
			{ lang::French, "TILT !" },
			{ lang::Hebrew, "TILT!" },
			{ lang::Hungarian, "Asztalba rúgás!" },
			{ lang::Italian, "TILT!" },
			{ lang::Japanese, "TILT!" },
			{ lang::Korean, "반칙!" },
			{ lang::Norwegian, "TILT!" },
			{ lang::Dutch, "TILT!" },
			{ lang::Polish, "TILT!" },
			{ lang::BrazilianPortuguese, "TILT!" },
			{ lang::Portuguese, "TILT!" },
			{ lang::Russian, "TILT!" },
			{ lang::Swedish, "Lutning" },
			{ lang::Turkish, "YATIR!" },
			{ lang::SimplifiedChinese, "TILT!" },
			{ lang::TraditionalChinese, "TILT!" },
		},
	},
	{
		Msg::STRING137,
		{
			{ lang::Arabic, "‏‏يتطلب هذا البرنامج وحدة معالجة مركزية (CPU) 80386 أو أحدث." },
			{ lang::Czech, "Tento program vyžaduje procesor 80386 nebo novější." },
			{ lang::Danish, "Dette program kræver en 80386-processor eller kraftigere." },
			{ lang::German, "Dieses Programm erfordert einen Computer mit 80386-Prozessor oder höher." },
			{ lang::Greek, "Αυτό το πρόγραμμα απαιτεί επεξεργαστή 80386 ή νεότερο." },
			{ lang::English, "This program requires an 80386 or later CPU." },
			{ lang::Spanish, "Para este programa se requiere una CPU 80386 o superior." },
			{ lang::Finnish, "Tämä ohjelma tarvitsee vähintään 80386-suorittimen." },
			{ lang::French, "Ce programme nécessite un microprocesseur 80386 ou ultérieur." },
			{ lang::Hebrew, "‏‏לתוכנית זו דרוש מעבד מסוג 80386 או מעבד מתקדם יותר." },
			{ lang::Hungarian, "A program 80386, vagy annál újabb mikroprocesszort igényel." },
			{ lang::Italian, "Il programma richiede una CPU 80386 o superiore." },
			{ lang::Japanese, "このプログラムには i386 以上の CPU が必要です。" },
			{ lang::Korean, "이 프로그램을 실행하려면 80386 이상의 CPU가 필요합니다." },
			{ lang::Norwegian, "Dette programmet krever en 80386-prosessor eller høyere." },
			{ lang::Dutch, "Voor dit programma is een CPU van het type 80386 of beter noodzakelijk." },
			{ lang::Polish, "Ten program wymaga procesora 80386 lub nowszego." },
			{ lang::BrazilianPortuguese, "Este programa requer uma CPU 80386 ou posterior." },
			{ lang::Portuguese, "Este jogo necessita de um processador 80386 ou mais recente." },
			{ lang::Russian, "Эта программа требует наличия по крайней мере 80386 процессора." },
			{ lang::Swedish, "Programmet kräver en 80386-processor eller högre." },
			{ lang::Turkish, "Bu program 80386 ya da yüksek bir CPU gerektirir." },
			{ lang::SimplifiedChinese, "该程序需要 80386 或更新的 CPU。" },
			{ lang::TraditionalChinese, "本程式需要 80386 或更快的 CPU。" },
		},
	},
	{
		Msg::STRING138,
		{
			{ lang::Arabic, "مطلوب 80386" },
			{ lang::Czech, "Vyžadován procesor 80386" },
			{ lang::Danish, "80386 kræves" },
			{ lang::German, "80386-Prozessor erforderlich" },
			{ lang::Greek, "Απαιτείται 80386" },
			{ lang::English, "80386 Required" },
			{ lang::Spanish, "Se requiere un 80386" },
			{ lang::Finnish, "80386-suoritin tarvitaan" },
			{ lang::French, "80386 nécessaire" },
			{ lang::Hebrew, "‏‏דרוש 80386" },
			{ lang::Hungarian, "80386 processzorra van szükség." },
			{ lang::Italian, "Richiede 80386" },
			{ lang::Japanese, "i386 の CPU が必要です" },
			{ lang::Korean, "80386 이상" },
			{ lang::Norwegian, "80386 kreves" },
			{ lang::Dutch, "80386 noodzakelijk" },
			{ lang::Polish, "Wymagany procesor 80386" },
			{ lang::BrazilianPortuguese, "80386 necessário" },
			{ lang::Portuguese, "É necessário um processador 80386" },
			{ lang::Russian, "Требуется 80386 процессор" },
			{ lang::Swedish, "80386 krävs" },
			{ lang::Turkish, "80386 Gerekli" },
			{ lang::SimplifiedChinese, "需要 80386 CPU" },
			{ lang::TraditionalChinese, "需要 80386" },
		},
	},
	{
		Msg::STRING139,
		{
			{ lang::Arabic, "3D Pinball for Windows - Space Cadet" },
			{ lang::Czech, "3D Pinball pro Windows - Space Cadet" },
			{ lang::Danish, "3D Pinball til Windows - Space Cadet" },
			{ lang::German, "3D-Pinball für Windows - Space Cadet" },
			{ lang::Greek, "Φλίπερ-3Δ για Windows - Space Cadet" },
			{ lang::English, "3D Pinball for Windows - Space Cadet" },
			{ lang::Spanish, "3D Pinball Windows: cadete espacial" },
			{ lang::Finnish, "Windows 3D Pinball - Space Cadet" },
			{ lang::French, "Pinball 3D pour Windows - Cadet de l'Espace" },
			{ lang::Hebrew, "3D Pinball for Windows - Space Cadet" },
			{ lang::Hungarian, "3D flipper - Windows - Space Cadet" },
			{ lang::Italian, "3D Pinball per Windows - Space Cadet" },
			{ lang::Japanese, "Windows 3D ピンボール - Space Cadet" },
			{ lang::Korean, "Windows용 3D 핀볼" },
			{ lang::Norwegian, "3D Pinball for Windows - Romkadett" },
			{ lang::Dutch, "3D Pinball voor Windows, Space Cadet" },
			{ lang::Polish, "3D Pinball dla Windows - Space Cadet" },
			{ lang::BrazilianPortuguese, "Pinball 3D para Windows - Space Cadet" },
			{ lang::Portuguese, "3D Pinball para o Windows - Cadete Espacial" },
			{ lang::Russian, "Пинбол для Windows - Звездный юнга" },
			{ lang::Swedish, "3D Pinball för Windows - Space Cadet" },
			{ lang::Turkish, "Windows için 3D Pinball - Space Cadet" },
			{ lang::SimplifiedChinese, "Windows 三维弹球 - 太空军校生" },
			{ lang::TraditionalChinese, "Windows 立體彈珠台 - 太空軍校生" },
		},
	},
	{
		Msg::STRING140,
		{
			{ lang::Arabic, "‏‏تم تعيين عنصر أو أكثر من عناصر تحكم اللاعب إلى نفس المفتاح،\n للوصول إلى أفضل أداء استخدم مفتاح فريد لكل عنصر تحكم." },
			{ lang::Czech, "Některé klávese je přiřazeno více ovládacích funkcí. Pro\nlepší ovládání použijte pro každou ovládací funkci jinou klávesu." },
			{ lang::Danish, "Et eller flere styreredskaber for spiller er indstillet til den samme tast.\nFor at få den bedste ydeevne skal du bruge en entydig tast til hvert styreredskab." },
			{ lang::German, "Mindestens zwei Bedienelementen wurden dieselbe Taste zugewiesen.\nBessere Ergebnisse erzielen Sie, wenn Sie dem Elementen eindeutige Tasten zuweisen." },
			{ lang::Greek, "Ένα ή περισσότερα από τα στοιχεία ελέγχου του παίκτη έχουν οριστεί στο ίδιο πλήκτρο.\nΓια καλύτερες επιδόσεις χρησιμοποιήστε μοναδικά πλήκτρα για κάθε στοιχείο ελέγχου." },
			{ lang::English, "One or more of the player controls is set to the same key,\nfor best performance use unique keys for each control." },
			{ lang::Spanish, "Hay dos o más controles de jugador asignados a la misma tecla;\npara un funcionamiento correcto, use una tecla diferente para cada control." },
			{ lang::Finnish, "Ainakin kaksi pelaajan ohjainta on määritetty käyttämään samaa näppäintä.\nMääritä ainutkertaiset näppäimet." },
			{ lang::French, "Une ou plusieurs commandes sont affectées à la même touche ;\npour de meilleures performances, n'affectez qu'une seule commande à chaque touche." },
			{ lang::Hebrew, "‏‏מוגדרת יותר מאפשרות בקרת משחק אחת לאותו מקש.\nלקבלת ביצועים מיטביים, השתמש במקשים ייחודיים עבור כל אפשרות בקרה." },
			{ lang::Hungarian, "Két vagy több mozgatóbillentyű azonos. \nVálasszon egyedi billentyűket." },
			{ lang::Italian, "Uno o più controlli giocatore sono impostati sullo stesso tasto.\nSi consiglia di usare un tasto per ogni controllo." },
			{ lang::Japanese, "複数のコントロール設定に同一のキーが設定されています。\nコントロールごとに別のキーを設定してください。" },
			{ lang::Korean, "하나 이상의 게임 진행키에 같은 키가 설정되었습니다.\n최고의 성능을 위해 각 진행키에 다른 키를 사용하십시오." },
			{ lang::Norwegian, "En eller flere spillkontroller er tilordnet samme tast.\nYtelsen blir størst når alle kontrollene er tilordnet hver sin tast." },
			{ lang::Dutch, "Eén of meer spelfuncties zijn ingesteld op dezelfde toets; gebruik unieke toetsen voor de verschillende elementen voor optimale prestaties." },
			{ lang::Polish, "Jedna lub kilka opcji sterujących używa tego samego klawisza.\nNajlepiej jest używać różnych klawiszy dla różnych opcji." },
			{ lang::BrazilianPortuguese, "Um ou mais controles do jogador estão definidos para a mesma tecla.\nPara um melhor desempenho, use teclas exclusivas para cada um dos controles." },
			{ lang::Portuguese, "Um ou mais controlos do jogo estão configurados para a mesma tecla.\npara obter um melhor desempenho use teclas únicas para cada controlo." },
			{ lang::Russian, "Несколько различных элементов управления используют одну и ту же клавишу. \nНазначьте различные клавиши для разных элементов управления." },
			{ lang::Swedish, "En eller flera av spelkontrollerna har samma tangent.\nAnvänd unika tangenter för varje kontroll för bästa prestanda." },
			{ lang::Turkish, "Bir ya da birden çok oyuncu denetimi aynı tuşa atanmış;\nen iyi performansı elde etmek için her denetime farklı tuş atayın." },
			{ lang::SimplifiedChinese, "玩家的一个或多个控制被设成同一个键，\n为获得最佳性能，请对每个控制使用不同的键。" },
			{ lang::TraditionalChinese, "一個或多個玩家的控制設定為相同按鍵。\n若要有最佳效能，每個控制都要使用唯一的按鍵。" },
		},
	},
	{
		Msg::STRING141,
		{
			{ lang::Arabic, "‏‏هل تريد مسح أفضل النتائج؟" },
			{ lang::Czech, "Chcete smazat nejlepší výsledky?" },
			{ lang::Danish, "Ryd pointtavlen?" },
			{ lang::German, "Bestenliste löschen?" },
			{ lang::Greek, "Απαλοιφή βαθμολογιών;" },
			{ lang::English, "Clear High Scores?" },
			{ lang::Spanish, "¿Borrar las máximas puntuaciones?" },
			{ lang::Finnish, "Tyhjennetäänkö parhaat tulokset?" },
			{ lang::French, "Effacer les meilleurs scores ?" },
			{ lang::Hebrew, "‏‏האם לנקות את נתוני הניקוד הגבוה?" },
			{ lang::Hungarian, "Törli a legjobb eredményeket?" },
			{ lang::Italian, "Cancellare i punteggi migliori?" },
			{ lang::Japanese, "ハイスコアをクリアしますか?" },
			{ lang::Korean, "고득점을 지우시겠습니까?" },
			{ lang::Norwegian, "Slette Beste resultater?" },
			{ lang::Dutch, "Topscores wissen?" },
			{ lang::Polish, "Czy wyczyścić najlepsze wyniki?" },
			{ lang::BrazilianPortuguese, "Descartar os recordes?" },
			{ lang::Portuguese, "Limpar recordes?" },
			{ lang::Russian, "Очистить таблицу рекордов?" },
			{ lang::Swedish, "Vill du ta bort poängrekorden?" },
			{ lang::Turkish, "Yüksek Skorlar Silinsin mi?" },
			{ lang::SimplifiedChinese, "清除高分？" },
			{ lang::TraditionalChinese, "清除高分？" },
		},
	},
	{
		Msg::STRING142,
		{
			{ lang::Arabic, "تأكيد" },
			{ lang::Czech, "Potvrdit" },
			{ lang::Danish, "Bekræft" },
			{ lang::German, "Bestätigen" },
			{ lang::Greek, "Επιβεβαίωση" },
			{ lang::English, "Confirm" },
			{ lang::Spanish, "Confirmar" },
			{ lang::Finnish, "Vahvista" },
			{ lang::French, "Confirmer" },
			{ lang::Hebrew, "אישור" },
			{ lang::Hungarian, "Jóváhagyás" },
			{ lang::Italian, "Conferma" },
			{ lang::Japanese, "確認" },
			{ lang::Korean, "확인" },
			{ lang::Norwegian, "Bekreft" },
			{ lang::Dutch, "Bevestigen" },
			{ lang::Polish, "Potwierdzanie" },
			{ lang::BrazilianPortuguese, "Confirmar" },
			{ lang::Portuguese, "Confirmar" },
			{ lang::Russian, "Подтверждение" },
			{ lang::Swedish, "Bekräfta" },
			{ lang::Turkish, "Onayla" },
			{ lang::SimplifiedChinese, "确认" },
			{ lang::TraditionalChinese, "確認" },
		},
	},
	{
		Msg::STRING143,
		{
			{ lang::Arabic, "‏‏WAVEMIX.INF مفقود - يجب أن يكون في دليل pinball!" },
			{ lang::Czech, "Soubor WAVEMIX.INF nebyl nalezen. Soubor musí být ve složce programu Pinball." },
			{ lang::Danish, "Wavemix.inf mangler. Den skal findes i pinball-mappen!" },
			{ lang::German, "Die Datei WAVEMIX.INF fehlt im Verzeichnis PINBALL." },
			{ lang::Greek, "Το αρχείο WAVEMIX.INF λείπει - πρέπει να βρίσκεται στον κατάλογο pinball." },
			{ lang::English, "WAVEMIX.INF is missing - it must be in the pinball directory!" },
			{ lang::Spanish, "Falta WAVEMIX.INF: debe estar en el directorio de Pinball." },
			{ lang::Finnish, "Wavemix.inf-tiedosto puuttuu - Sen on oltava Pinball-hakemistossa." },
			{ lang::French, "WAVEMIX.INF est manquant - Ce fichier devrait être dans le répertoire de Pinball !" },
			{ lang::Hebrew, "‏‏הקובץ WAVEMIX.INF חסר - על קובץ זה להימצא בספריית Pinball!" },
			{ lang::Hungarian, "Nem található a WAVEMIX.INF fájl! A flipper könyvtárában kell lennie!" },
			{ lang::Italian, "WAVEMIX.INF mancante. Copiare questo file nella directory Pinball!" },
			{ lang::Japanese, "WAVEMIX.INF ファイルが見つかりません。このファイルはピンボールのディレクトリになければなりません。" },
			{ lang::Korean, "WAVEMIX.INF가 없습니다. 이 파일은 pinball 디렉터리에 있어야 합니다." },
			{ lang::Norwegian, "Wavemix.inf mangler. Den må være i samme katalogen som Pinball." },
			{ lang::Dutch, "Wavemix.inf ontbreekt. Dit bestand moet in de map Pinball aanwezig zijn." },
			{ lang::Polish, "Brak pliku WAVEMIX.INF - ten plik musi znajdować się w katalogu gry Pinball!" },
			{ lang::BrazilianPortuguese, "WAVEMIX.INF está faltando - precisa estar na pasta Pinball!" },
			{ lang::Portuguese, "Falta o WAVEMIX.INF - este ficheiro tem de estar no directório do Pinball!" },
			{ lang::Russian, "Файл WAVEMIX.INF отсутствует - он должен быть расположен в той же папке, что и сама игра!" },
			{ lang::Swedish, "Filen WAVEMIX.INF saknas - den måste finnas i mappen Pinball." },
			{ lang::Turkish, "WAVEMIX.INF eksik; bu dosyanın pinball dizininde bulunması gerekir!" },
			{ lang::SimplifiedChinese, "找不到 WAVEMIX.INF - 必须在弹球游戏目录中！" },
			{ lang::TraditionalChinese, "遺失 WAVEMIX.INF - 它必須放在彈珠台目錄下！" },
		},
	},
	{
		Msg::STRING144,
		{
			{ lang::Arabic, "‏‏تحذير:" },
			{ lang::Czech, "Upozornění:" },
			{ lang::Danish, "Advarsel:" },
			{ lang::German, "Warnung:" },
			{ lang::Greek, "Προειδοποίηση:" },
			{ lang::English, "Warning:" },
			{ lang::Spanish, "Advertencia:" },
			{ lang::Finnish, "Varoitus:" },
			{ lang::French, "Avertissement :" },
			{ lang::Hebrew, "Warning:" },
			{ lang::Hungarian, "Figyelmeztetés:" },
			{ lang::Italian, "Avviso:" },
			{ lang::Japanese, "警告:" },
			{ lang::Korean, "경고:" },
			{ lang::Norwegian, "Advarsel!" },
			{ lang::Dutch, "Waarschuwing:" },
			{ lang::Polish, "Ostrzeżenie:" },
			{ lang::BrazilianPortuguese, "Aviso:" },
			{ lang::Portuguese, "Aviso:" },
			{ lang::Russian, "ПРЕДУПРЕЖДЕНИЕ:" },
			{ lang::Swedish, "Varning:" },
			{ lang::Turkish, "Uyarı:" },
			{ lang::SimplifiedChinese, "警告：" },
			{ lang::TraditionalChinese, "警告：" },
		},
	},
	{
		Msg::STRING145,
		{
			{ lang::Arabic, "Ship Re-Fueled" },
			{ lang::Czech, "Doplnění paliva lodi" },
			{ lang::Danish, "Skib tanket op" },
			{ lang::German, "Schiff aufgetankt" },
			{ lang::Greek, "Έγινε ανεφοδιασμός καυσίμων" },
			{ lang::English, "Ship Re-Fueled" },
			{ lang::Spanish, "La nave ha repostado" },
			{ lang::Finnish, "Alus tankattu" },
			{ lang::French, "Réapprovisionnement du vaisseau" },
			{ lang::Hebrew, "Ship Re-Fueled" },
			{ lang::Hungarian, "Hajó feltankolva" },
			{ lang::Italian, "Rifornimento navicella eseguito" },
			{ lang::Japanese, "燃料補給完了!" },
			{ lang::Korean, "우주선에 연료 공급" },
			{ lang::Norwegian, "Nybunkret skip" },
			{ lang::Dutch, "Schip bijgetankt" },
			{ lang::Polish, "Paliwo uzupełnione" },
			{ lang::BrazilianPortuguese, "Nave reabastecida" },
			{ lang::Portuguese, "Nave reabastecida" },
			{ lang::Russian, "Корабль Заправлен" },
			{ lang::Swedish, "Skeppet har tankats om" },
			{ lang::Turkish, "Gemiye Yakıt Alındı" },
			{ lang::SimplifiedChinese, "飞船补充燃料" },
			{ lang::TraditionalChinese, "船舶重新加油" },
		},
	},
	{
		Msg::STRING146,
		{
			{ lang::Arabic, "Gravity Well" },
			{ lang::Czech, "Zvýšená gravitace" },
			{ lang::Danish, "Tyngdebrønd" },
			{ lang::German, "Schwerkraftzone" },
			{ lang::Greek, "Βαρυτικό πεδίο" },
			{ lang::English, "Gravity Well" },
			{ lang::Spanish, "Pozo gravitatorio" },
			{ lang::Finnish, "Gravitaatiokuoppa" },
			{ lang::French, "Centre de gravité" },
			{ lang::Hebrew, "Gravity Well" },
			{ lang::Hungarian, "Gravitációs csapda" },
			{ lang::Italian, "Pozzo di gravità" },
			{ lang::Japanese, "グラビティ ウェル" },
			{ lang::Korean, "중력의 중심" },
			{ lang::Norwegian, "Tyngdekraftsbrønn" },
			{ lang::Dutch, "Gravity-put" },
			{ lang::Polish, "Studnia grawitacyjna" },
			{ lang::BrazilianPortuguese, "Poço de gravidade" },
			{ lang::Portuguese, "Centro gravitacional" },
			{ lang::Russian, "Гравитационный Колодец" },
			{ lang::Swedish, "Gravitationshål" },
			{ lang::Turkish, "Yerçekimi Kuyusu" },
			{ lang::SimplifiedChinese, "引力井" },
			{ lang::TraditionalChinese, "重力井" },
		},
	},
	{
		Msg::STRING147,
		{
			{ lang::Arabic, "Time Warp Forward" },
			{ lang::Czech, "Přesun v čase vpřed" },
			{ lang::Danish, "Tidsforskydning fremad" },
			{ lang::German, "Zeitsprung vorwärts" },
			{ lang::Greek, "Χρονοστρέβλωση στο μέλλον" },
			{ lang::English, "Time Warp Forward" },
			{ lang::Spanish, "Salto en el tiempo" },
			{ lang::Finnish, "Aikahyppy tulevaan" },
			{ lang::French, "Avancer dans le temps" },
			{ lang::Hebrew, "Time Warp Forward" },
			{ lang::Hungarian, "Időugrás előre" },
			{ lang::Italian, "Curvatura temporale nel futuro" },
			{ lang::Japanese, "未来へタイム ワープ!" },
			{ lang::Korean, "앞으로 시간 이동" },
			{ lang::Norwegian, "Tidssprang forover" },
			{ lang::Dutch, "Timewarp vooruit" },
			{ lang::Polish, "Zakrzywienie czasu w przód" },
			{ lang::BrazilianPortuguese, "Distorção temporal progressiva" },
			{ lang::Portuguese, "Avançar no Tempo" },
			{ lang::Russian, "Прыжок во Времени Вперед" },
			{ lang::Swedish, "Tidsresa till framtiden" },
			{ lang::Turkish, "Zaman Sıçraması İleri" },
			{ lang::SimplifiedChinese, "时间向前扭曲" },
			{ lang::TraditionalChinese, "時間向前扭曲" },
		},
	},
	{
		Msg::STRING148,
		{
			{ lang::Arabic, "Time Warp Backward" },
			{ lang::Czech, "Přesun v čase zpět" },
			{ lang::Danish, "Tidsforskydning tilbage" },
			{ lang::German, "Zeitsprung rückwärts" },
			{ lang::Greek, "Χρονοστρέβλωση στο παρελθόν" },
			{ lang::English, "Time Warp Backward" },
			{ lang::Spanish, "Retroceso en el tiempo" },
			{ lang::Finnish, "Aikahyppy menneeseen" },
			{ lang::French, "Remonter dans le temps" },
			{ lang::Hebrew, "Time Warp Backward" },
			{ lang::Hungarian, "Időugrás hátra" },
			{ lang::Italian, "Curvatura temporale nel passato" },
			{ lang::Japanese, "過去へタイム ワープ!" },
			{ lang::Korean, "뒤로 시간 이동" },
			{ lang::Norwegian, "Tidssprang bakover" },
			{ lang::Dutch, "Timewarp achteruit" },
			{ lang::Polish, "Zakrzywienie czasu w tył" },
			{ lang::BrazilianPortuguese, "Distorção temporal regressiva" },
			{ lang::Portuguese, "Retroceder no Tempo" },
			{ lang::Russian, "Прыжок во Времени Назад" },
			{ lang::Swedish, "Tidsresa till forntiden" },
			{ lang::Turkish, "Zaman Sıçraması Geri" },
			{ lang::SimplifiedChinese, "时间向后扭曲" },
			{ lang::TraditionalChinese, "時間向後扭曲" },
		},
	},
	{
		Msg::STRING149,
		{
			{ lang::Arabic, "Maelstrom!" },
			{ lang::Czech, "Hvězdný vír!" },
			{ lang::Danish, "Hvirvelstrøm!" },
			{ lang::German, "Strudel!" },
			{ lang::Greek, "Δίνη" },
			{ lang::English, "Maelstrom!" },
			{ lang::Spanish, "¡Vorágine!" },
			{ lang::Finnish, "Maelstrom!" },
			{ lang::French, "Maelström !" },
			{ lang::Hebrew, "Maelstrom!" },
			{ lang::Hungarian, "Maelström!" },
			{ lang::Italian, "Maelstrom!" },
			{ lang::Japanese, "メールストローム!" },
			{ lang::Korean, "대혼란" },
			{ lang::Norwegian, "Malstrøm!" },
			{ lang::Dutch, "Maelstrom!" },
			{ lang::Polish, "Wir!" },
			{ lang::BrazilianPortuguese, "Redemoinho!" },
			{ lang::Portuguese, "Remoinho!" },
			{ lang::Russian, "Водоворот!" },
			{ lang::Swedish, "Maelstrom!" },
			{ lang::Turkish, "Girdap!" },
			{ lang::SimplifiedChinese, "大旋涡！" },
			{ lang::TraditionalChinese, "大動亂！" },
		},
	},
	{
		Msg::STRING150,
		{
			{ lang::Arabic, "Wormhole" },
			{ lang::Czech, "Červí díra" },
			{ lang::Danish, "Ormehul" },
			{ lang::German, "Wurmloch" },
			{ lang::Greek, "Διαστημική σήραγγα" },
			{ lang::English, "Wormhole" },
			{ lang::Spanish, "Túnel espacial" },
			{ lang::Finnish, "Madonreikä" },
			{ lang::French, "Repaire du ver géant" },
			{ lang::Hebrew, "Wormhole" },
			{ lang::Hungarian, "Féreglyuk" },
			{ lang::Italian, "Tunnel spaziale" },
			{ lang::Japanese, "ワームホール!" },
			{ lang::Korean, "웜홀" },
			{ lang::Norwegian, "Ormebol" },
			{ lang::Dutch, "Wormhole" },
			{ lang::Polish, "Tunel czasoprzestrzenny" },
			{ lang::BrazilianPortuguese, "Fenda espacial" },
			{ lang::Portuguese, "Túnel espacial" },
			{ lang::Russian, "Червоточина" },
			{ lang::Swedish, "Maskhål" },
			{ lang::Turkish, "Solucan deliği" },
			{ lang::SimplifiedChinese, "旋涡式星体" },
			{ lang::TraditionalChinese, "蟲孔" },
		},
	},
	{
		Msg::STRING151,
		{
			{ lang::Arabic, "Awaiting Deployment" },
			{ lang::Czech, "Čekání na odpálení" },
			{ lang::Danish, "Afventer affyring" },
			{ lang::German, "Startbereit" },
			{ lang::Greek, "Αναμονή εκτόξευσης" },
			{ lang::English, "Awaiting Deployment" },
			{ lang::Spanish, "Esperando implementación" },
			{ lang::Finnish, "Odotetaan laukaisua" },
			{ lang::French, "Paré au lancement" },
			{ lang::Hebrew, "Awaiting Deployment" },
			{ lang::Hungarian, "Kilövés" },
			{ lang::Italian, "Schieramento" },
			{ lang::Japanese, "発射準備 OK!" },
			{ lang::Korean, "함대 배치 준비" },
			{ lang::Norwegian, "Venter på utstasjonering" },
			{ lang::Dutch, "Klaar voor lancering" },
			{ lang::Polish, "Oczekiwanie na rozstawienie" },
			{ lang::BrazilianPortuguese, "Aguardando lançamento" },
			{ lang::Portuguese, "Pronto para o lançamento" },
			{ lang::Russian, "Ожидание Запуска" },
			{ lang::Swedish, "Skjut iväg kulan!" },
			{ lang::Turkish, "Başlatma Bekleniyor" },
			{ lang::SimplifiedChinese, "等待部署" },
			{ lang::TraditionalChinese, "正在等待調配" },
		},
	},
	{
		Msg::STRING152,
		{
			{ lang::Arabic, "Flags Upgraded" },
			{ lang::Czech, "Vylepšení vlajky" },
			{ lang::Danish, "Flag opgraderet" },
			{ lang::German, "Fahnen erneuert" },
			{ lang::Greek, "Οι σημαίες αναβαθμίστηκαν" },
			{ lang::English, "Flags Upgraded" },
			{ lang::Spanish, "Trampillas actualizadas" },
			{ lang::Finnish, "Liput uusittu" },
			{ lang::French, "Indicateurs mis à jour" },
			{ lang::Hebrew, "Flags Upgraded" },
			{ lang::Hungarian, "Zászlócélok korszerűsítve" },
			{ lang::Italian, "Bandiere aggiornate" },
			{ lang::Japanese, "フラグをアップグレード!" },
			{ lang::Korean, "깃발 업그레이드" },
			{ lang::Norwegian, "Flagg oppgradert" },
			{ lang::Dutch, "Poorten opgewaardeerd" },
			{ lang::Polish, "Modernizacja flag" },
			{ lang::BrazilianPortuguese, "Bandeiras atualizadas" },
			{ lang::Portuguese, "Indicadores actualizados" },
			{ lang::Russian, "Флаги Улучшены" },
			{ lang::Swedish, "Spinners uppgraderas" },
			{ lang::Turkish, "Fırıldaklar Yenilendi" },
			{ lang::SimplifiedChinese, "升级旗帜" },
			{ lang::TraditionalChinese, "旗標升級" },
		},
	},
	{
		Msg::STRING153,
		{
			{ lang::Arabic, "Bonus Hold" },
			{ lang::Czech, "Podržení bonusu" },
			{ lang::Danish, "Bonushold" },
			{ lang::German, "Bonus angehalten" },
			{ lang::Greek, "Διατήρηση μπόνους" },
			{ lang::English, "Bonus Hold" },
			{ lang::Spanish, "Retención de bonificación" },
			{ lang::Finnish, "Bonuksen pito" },
			{ lang::French, "Bonus conservé" },
			{ lang::Hebrew, "Bonus Hold" },
			{ lang::Hungarian, "Bónusz megtartva" },
			{ lang::Italian, "Concessione bonus" },
			{ lang::Japanese, "ボーナス" },
			{ lang::Korean, "추가 보너스 없음" },
			{ lang::Norwegian, "Behold bonus" },
			{ lang::Dutch, "Bonus behouden" },
			{ lang::Polish, "Wstrzymanie premii" },
			{ lang::BrazilianPortuguese, "Bônus adquirido" },
			{ lang::Portuguese, "Retenção de bónus" },
			{ lang::Russian, "Удержание Бонуса" },
			{ lang::Swedish, "Bonus sparas" },
			{ lang::Turkish, "Ödül Beklemede" },
			{ lang::SimplifiedChinese, "保留奖分" },
			{ lang::TraditionalChinese, "保留紅利" },
		},
	},
	{
		Msg::STRING154,
		{
			{ lang::Arabic, "Level One Commendation" },
			{ lang::Czech, "Uznání prvního stupně" },
			{ lang::Danish, "Beskyttelse - niveau 1" },
			{ lang::German, "Belobigung Stufe 1" },
			{ lang::Greek, "Έπαινος πρώτου βαθμού" },
			{ lang::English, "Level One Commendation" },
			{ lang::Spanish, "Felicitación del nivel uno" },
			{ lang::Finnish, "Ensimmäisen tason kunniamerkki" },
			{ lang::French, "Trophée niveau 1" },
			{ lang::Hebrew, "Level One Commendation" },
			{ lang::Hungarian, "Elsőfokú dicséret" },
			{ lang::Italian, "Lode di primo livello" },
			{ lang::Japanese, "レベル 1 叙勲" },
			{ lang::Korean, "1단계 보너스" },
			{ lang::Norwegian, "Medalje for 1. nivå" },
			{ lang::Dutch, "Eervolle vermelding nr. 1" },
			{ lang::Polish, "Awans na poziom pierwszy" },
			{ lang::BrazilianPortuguese, "Fase um concluída" },
			{ lang::Portuguese, "Troféu do nível um" },
			{ lang::Russian, "Благодарность Первого Уровня" },
			{ lang::Swedish, "Befordran till nivå 1" },
			{ lang::Turkish, "1. Düzey Kumanda" },
			{ lang::SimplifiedChinese, "一等奖" },
			{ lang::TraditionalChinese, "第一級獎金" },
		},
	},
	{
		Msg::STRING155,
		{
			{ lang::Arabic, "Level Two Commendation" },
			{ lang::Czech, "Uznání druhého stupně" },
			{ lang::Danish, "Beskyttelse - niveau 2" },
			{ lang::German, "Belobigung Stufe 2" },
			{ lang::Greek, "Έπαινος δευτέρου βαθμού" },
			{ lang::English, "Level Two Commendation" },
			{ lang::Spanish, "Felicitación del nivel dos" },
			{ lang::Finnish, "Toisen tason kunniamerkki" },
			{ lang::French, "Trophée niveau 2" },
			{ lang::Hebrew, "Level Two Commendation" },
			{ lang::Hungarian, "Másodfokú dicséret" },
			{ lang::Italian, "Lode di secondo livello" },
			{ lang::Japanese, "レベル 2 叙勲" },
			{ lang::Korean, "2단계 보너스" },
			{ lang::Norwegian, "Medalje for 2. nivå" },
			{ lang::Dutch, "Eervolle vermelding nr. 2" },
			{ lang::Polish, "Awans na poziom drugi" },
			{ lang::BrazilianPortuguese, "Fase dois concluída" },
			{ lang::Portuguese, "Troféu do nível dois" },
			{ lang::Russian, "Благодарность Второго Уровня" },
			{ lang::Swedish, "Befordran till nivå 2" },
			{ lang::Turkish, "2. Düzey Kumanda" },
			{ lang::SimplifiedChinese, "二等奖" },
			{ lang::TraditionalChinese, "第二級獎金" },
		},
	},
	{
		Msg::STRING156,
		{
			{ lang::Arabic, "Level Three Commendation" },
			{ lang::Czech, "Uznání třetího stupně" },
			{ lang::Danish, "Beskyttelse - niveau 3" },
			{ lang::German, "Belobigung Stufe 3" },
			{ lang::Greek, "Έπαινος τρίτου βαθμού" },
			{ lang::English, "Level Three Commendation" },
			{ lang::Spanish, "Felicitación del nivel tres" },
			{ lang::Finnish, "Kolmannen tason kunniamerkki" },
			{ lang::French, "Trophée niveau 3" },
			{ lang::Hebrew, "Level Three Commendation" },
			{ lang::Hungarian, "Harmadfokú dicséret" },
			{ lang::Italian, "Lode di terzo livello" },
			{ lang::Japanese, "レベル 3 叙勲" },
			{ lang::Korean, "3단계 보너스" },
			{ lang::Norwegian, "Medalje for 3. nivå" },
			{ lang::Dutch, "Eervolle vermelding nr. 3" },
			{ lang::Polish, "Awans na poziom trzeci" },
			{ lang::BrazilianPortuguese, "Fase três concluída" },
			{ lang::Portuguese, "Troféu do nível três" },
			{ lang::Russian, "Благодарность Третьего Уровня" },
			{ lang::Swedish, "Befordran till nivå 3" },
			{ lang::Turkish, "3. Düzey Kumanda" },
			{ lang::SimplifiedChinese, "三等奖" },
			{ lang::TraditionalChinese, "第三級獎金" },
		},
	},
	{
		Msg::STRING157,
		{
			{ lang::Arabic, "Field Multiplier 2x" },
			{ lang::Czech, "Násobení polí (x2)" },
			{ lang::Danish, "Feltmultiplikator 2x" },
			{ lang::German, "Feldmultiplikator 2fach" },
			{ lang::Greek, "Πολλαπλασιαστής πεδίου 2x" },
			{ lang::English, "Field Multiplier 2x" },
			{ lang::Spanish, "Multiplicador x2" },
			{ lang::Finnish, "Kentän moninkertaistus 2x" },
			{ lang::French, "Multiplicateur de champ 2x" },
			{ lang::Hebrew, "Field Multiplier 2x" },
			{ lang::Hungarian, "2x-es szorzó" },
			{ lang::Italian, "Moltiplicatore di campo 2x" },
			{ lang::Japanese, "フィールド マルチプライヤ 2x" },
			{ lang::Korean, "공격 점수 2배" },
			{ lang::Norwegian, "Feltmultiplikator: 2" },
			{ lang::Dutch, "Veldvermenigvuldiging 2x" },
			{ lang::Polish, "Współczynnik pola x2" },
			{ lang::BrazilianPortuguese, "Campo multiplicador 2x" },
			{ lang::Portuguese, "Multiplicador de campo x2" },
			{ lang::Russian, "Множитель Поля 2x" },
			{ lang::Swedish, "Poängen dubbleras" },
			{ lang::Turkish, "Alan Katlayıcısı 2x" },
			{ lang::SimplifiedChinese, "扩大战场 2x" },
			{ lang::TraditionalChinese, "戰場乘數 2x" },
		},
	},
	{
		Msg::STRING158,
		{
			{ lang::Arabic, "Field Multiplier 3x" },
			{ lang::Czech, "Násobení polí (x3)" },
			{ lang::Danish, "Feltmultiplikator 3x" },
			{ lang::German, "Feldmultiplikator 3fach" },
			{ lang::Greek, "Πολλαπλασιαστής πεδίου 3x" },
			{ lang::English, "Field Multiplier 3x" },
			{ lang::Spanish, "Multiplicador x3" },
			{ lang::Finnish, "Kentän moninkertaistus 3x" },
			{ lang::French, "Multiplicateur de champ 3x" },
			{ lang::Hebrew, "Field Multiplier 3x" },
			{ lang::Hungarian, "3x-os szorzó" },
			{ lang::Italian, "Moltiplicatore di campo 3x" },
			{ lang::Japanese, "フィールド マルチプライヤ 3x" },
			{ lang::Korean, "공격 점수 3배" },
			{ lang::Norwegian, "Feltmultiplikator: 3" },
			{ lang::Dutch, "Veldvermenigvuldiging 3x" },
			{ lang::Polish, "Współczynnik pola x3" },
			{ lang::BrazilianPortuguese, "Campo multiplicador 3x" },
			{ lang::Portuguese, "Multiplicador de campo x3" },
			{ lang::Russian, "Множитель Поля 3x" },
			{ lang::Swedish, "Poängen multipliceras\nmed tre" },
			{ lang::Turkish, "Alan Katlayıcısı 3x" },
			{ lang::SimplifiedChinese, "扩大战场 3x" },
			{ lang::TraditionalChinese, "戰場乘數 3x" },
		},
	},
	{
		Msg::STRING159,
		{
			{ lang::Arabic, "Field Multiplier 5x" },
			{ lang::Czech, "Násobení polí (x5)" },
			{ lang::Danish, "Feltmultiplikator 5x" },
			{ lang::German, "Feldmultiplikator 5fach" },
			{ lang::Greek, "Πολλαπλασιαστής πεδίου 5x" },
			{ lang::English, "Field Multiplier 5x" },
			{ lang::Spanish, "Multiplicador x5" },
			{ lang::Finnish, "Kentän moninkertaistus 5x" },
			{ lang::French, "Multiplicateur de champ 5x" },
			{ lang::Hebrew, "Field Multiplier 5x" },
			{ lang::Hungarian, "5x-ös szorzó" },
			{ lang::Italian, "Moltiplicatore di campo 5x" },
			{ lang::Japanese, "フィールド マルチプライヤ 5x" },
			{ lang::Korean, "공격 점수 5배" },
			{ lang::Norwegian, "Feltmultiplikator: 5" },
			{ lang::Dutch, "Veldvermenigvuldiging 5x" },
			{ lang::Polish, "Współczynnik pola x5" },
			{ lang::BrazilianPortuguese, "Campo multiplicador 5x" },
			{ lang::Portuguese, "Multiplicador de campo x5" },
			{ lang::Russian, "Множитель Поля 5x" },
			{ lang::Swedish, "Poängen multipliceras\nmed fem" },
			{ lang::Turkish, "Alan Katlayıcısı 5x" },
			{ lang::SimplifiedChinese, "扩大战场 5x" },
			{ lang::TraditionalChinese, "戰場乘數 5x" },
		},
	},
	{
		Msg::STRING160,
		{
			{ lang::Arabic, "Field Multiplier 10x" },
			{ lang::Czech, "Násobení polí (x10)" },
			{ lang::Danish, "Feltmultiplikator 10x" },
			{ lang::German, "Feldmultiplikator 10fach" },
			{ lang::Greek, "Πολλαπλασιαστής πεδίου 10x" },
			{ lang::English, "Field Multiplier 10x" },
			{ lang::Spanish, "Multiplicador x10" },
			{ lang::Finnish, "Kentän moninkertaistus 10x" },
			{ lang::French, "Multiplicateur de champ 10x" },
			{ lang::Hebrew, "Field Multiplier 10x" },
			{ lang::Hungarian, "10x-es szorzó" },
			{ lang::Italian, "Moltiplicatore di campo 10x" },
			{ lang::Japanese, "フィールド マルチプライヤ 10x" },
			{ lang::Korean, "공격 점수 10배" },
			{ lang::Norwegian, "Feltmultiplikator: 10" },
			{ lang::Dutch, "Veldvermenigvuldiging 10x" },
			{ lang::Polish, "Współczynnik pola x10" },
			{ lang::BrazilianPortuguese, "Campo multiplicador 10x" },
			{ lang::Portuguese, "Multiplicador de campo x10" },
			{ lang::Russian, "Множитель Поля 10x" },
			{ lang::Swedish, "Poängen multipliceras\nmed tio" },
			{ lang::Turkish, "Alan Katlayıcısı 10x" },
			{ lang::SimplifiedChinese, "扩大战场 10x" },
			{ lang::TraditionalChinese, "戰場乘數 10x" },
		},
	},
	{
		Msg::STRING161,
		{
			{ lang::Arabic, "Target Practice" },
			{ lang::Czech, "Nácvik míření" },
			{ lang::Danish, "Måløvelse" },
			{ lang::German, "Zielübungen" },
			{ lang::Greek, "Εξάσκηση βολής" },
			{ lang::English, "Target Practice" },
			{ lang::Spanish, "Prácticas de diana" },
			{ lang::Finnish, "Maalitauluharjoitus" },
			{ lang::French, "Exercices de tir" },
			{ lang::Hebrew, "Target Practice" },
			{ lang::Hungarian, "Lőgyakorlat" },
			{ lang::Italian, "Esercitazione di tiro" },
			{ lang::Japanese, "ターゲット訓練" },
			{ lang::Korean, "사격 연습" },
			{ lang::Norwegian, "Skyteøvelse" },
			{ lang::Dutch, "Schietoefeningen" },
			{ lang::Polish, "Ćwiczenie celności" },
			{ lang::BrazilianPortuguese, "Tiro ao alvo" },
			{ lang::Portuguese, "Tiro ao alvo" },
			{ lang::Russian, "Стрельба по Мишеням" },
			{ lang::Swedish, "Bumper-träning" },
			{ lang::Turkish, "Hedef Talimi" },
			{ lang::SimplifiedChinese, "目标练习" },
			{ lang::TraditionalChinese, "目標練習" },
		},
	},
	{
		Msg::STRING162,
		{
			{ lang::Arabic, "Launch Training" },
			{ lang::Czech, "Nácvik odpálení" },
			{ lang::Danish, "Affyringstræning" },
			{ lang::German, "Startübungen" },
			{ lang::Greek, "Εξάσκηση εκτόξευσης" },
			{ lang::English, "Launch Training" },
			{ lang::Spanish, "Entrenamiento de lanzamiento" },
			{ lang::Finnish, "Lähtöharjoitus" },
			{ lang::French, "Essais de tir" },
			{ lang::Hebrew, "Launch Training" },
			{ lang::Hungarian, "Fellövési gyakorlat" },
			{ lang::Italian, "Esercitazioni di lancio" },
			{ lang::Japanese, "発射訓練" },
			{ lang::Korean, "발사 훈련" },
			{ lang::Norwegian, "Utskytingstrening" },
			{ lang::Dutch, "Lanceertraining" },
			{ lang::Polish, "Trening ładowania" },
			{ lang::BrazilianPortuguese, "Treinamento de lançamento" },
			{ lang::Portuguese, "Iniciar o treino" },
			{ lang::Russian, "Тренировка по Запуску" },
			{ lang::Swedish, "Rampträning" },
			{ lang::Turkish, "Fırlatma Eğitimi" },
			{ lang::SimplifiedChinese, "启动训练" },
			{ lang::TraditionalChinese, "啟動訓練" },
		},
	},
	{
		Msg::STRING163,
		{
			{ lang::Arabic, "Re-Entry Training" },
			{ lang::Czech, "Nácvik návratu" },
			{ lang::Danish, "Gentagelsestræning" },
			{ lang::German, "Landeübungen" },
			{ lang::Greek, "Εξάσκηση επαναφοράς" },
			{ lang::English, "Re-Entry Training" },
			{ lang::Spanish, "Entrenamiento de reentrada" },
			{ lang::Finnish, "Paluuharjoitus" },
			{ lang::French, "Essais de rentrée" },
			{ lang::Hebrew, "Re-Entry Training" },
			{ lang::Hungarian, "Újrabelépési gyakorlat" },
			{ lang::Italian, "Esercitazione di rientro" },
			{ lang::Japanese, "再突入訓練" },
			{ lang::Korean, "재돌입 훈련" },
			{ lang::Norwegian, "Tilbakekomsttrening" },
			{ lang::Dutch, "Terugkeertraining" },
			{ lang::Polish, "Trening ponownego wejścia" },
			{ lang::BrazilianPortuguese, "Treinamento de reentrada" },
			{ lang::Portuguese, "Treino de reentrada" },
			{ lang::Russian, "Тренировка по Возвращению" },
			{ lang::Swedish, "Höghöjdsträning" },
			{ lang::Turkish, "Yeniden Giriş Eğitimi" },
			{ lang::SimplifiedChinese, "重新上场训练" },
			{ lang::TraditionalChinese, "重新輸入訓練" },
		},
	},
	{
		Msg::STRING164,
		{
			{ lang::Arabic, "Science" },
			{ lang::Czech, "Vědecký úkol" },
			{ lang::Danish, "Videnskab" },
			{ lang::German, "Forschung" },
			{ lang::Greek, "Επιστήμη" },
			{ lang::English, "Science" },
			{ lang::Spanish, "Ciencia" },
			{ lang::Finnish, "Tutkimus" },
			{ lang::French, "Science" },
			{ lang::Hebrew, "Science" },
			{ lang::Hungarian, "Tudományos feladat" },
			{ lang::Italian, "Scienza" },
			{ lang::Japanese, "サイエンス" },
			{ lang::Korean, "과학" },
			{ lang::Norwegian, "Vitenskapelig" },
			{ lang::Dutch, "Wetenschap" },
			{ lang::Polish, "Nauka" },
			{ lang::BrazilianPortuguese, "Científica" },
			{ lang::Portuguese, "Ciência" },
			{ lang::Russian, "Наука" },
			{ lang::Swedish, "Vetenskap" },
			{ lang::Turkish, "Bilim" },
			{ lang::SimplifiedChinese, "科学" },
			{ lang::TraditionalChinese, "科學" },
		},
	},
	{
		Msg::STRING165,
		{
			{ lang::Arabic, "Stray Comet" },
			{ lang::Czech, "Bludná kometa" },
			{ lang::Danish, "Løbsk komet" },
			{ lang::German, "Gefährlicher Komet" },
			{ lang::Greek, "Περιπλανώμενος κομήτης" },
			{ lang::English, "Stray Comet" },
			{ lang::Spanish, "Cometa extraviado" },
			{ lang::Finnish, "Komeetta" },
			{ lang::French, "Comète errante" },
			{ lang::Hebrew, "Stray Comet" },
			{ lang::Hungarian, "Kóbor üstökös" },
			{ lang::Italian, "Cometa vagante" },
			{ lang::Japanese, "遊星" },
			{ lang::Korean, "궤도 이탈 혜성" },
			{ lang::Norwegian, "Komet ute av kurs" },
			{ lang::Dutch, "Verdwaalde komeet" },
			{ lang::Polish, "Zabłąkana kometa" },
			{ lang::BrazilianPortuguese, "Cometa perdido" },
			{ lang::Portuguese, "Cometa errante" },
			{ lang::Russian, "Заблудшая Комета" },
			{ lang::Swedish, "Kometsvärm" },
			{ lang::Turkish, "Kuyruklu Yıldız" },
			{ lang::SimplifiedChinese, "离群的彗星" },
			{ lang::TraditionalChinese, "偏離的彗星" },
		},
	},
	{
		Msg::STRING166,
		{
			{ lang::Arabic, "Black Hole" },
			{ lang::Czech, "Černá díra" },
			{ lang::Danish, "Sort hul" },
			{ lang::German, "Schwarzes Loch" },
			{ lang::Greek, "Μαύρη τρύπα" },
			{ lang::English, "Black Hole" },
			{ lang::Spanish, "Agujero negro" },
			{ lang::Finnish, "Musta aukko" },
			{ lang::French, "Trou noir" },
			{ lang::Hebrew, "Black Hole" },
			{ lang::Hungarian, "Fekete lyuk" },
			{ lang::Italian, "Buco nero" },
			{ lang::Japanese, "ブラック ホール!" },
			{ lang::Korean, "블랙홀" },
			{ lang::Norwegian, "Svart hull" },
			{ lang::Dutch, "Zwart gat" },
			{ lang::Polish, "Czarna dziura" },
			{ lang::BrazilianPortuguese, "Buraco negro" },
			{ lang::Portuguese, "Buraco negro" },
			{ lang::Russian, "Черная Дыра" },
			{ lang::Swedish, "Svart hål" },
			{ lang::Turkish, "Kara Delik" },
			{ lang::SimplifiedChinese, "黑洞" },
			{ lang::TraditionalChinese, "黑洞" },
		},
	},
	{
		Msg::STRING167,
		{
			{ lang::Arabic, "Space Radiation" },
			{ lang::Czech, "Vesmírná radiace" },
			{ lang::Danish, "Rumstråling" },
			{ lang::German, "Raumstrahlung" },
			{ lang::Greek, "Διαστημική ακτινοβολία" },
			{ lang::English, "Space Radiation" },
			{ lang::Spanish, "Radiación espacial" },
			{ lang::Finnish, "Kosminen säteily" },
			{ lang::French, "Rayonnement spatial" },
			{ lang::Hebrew, "Space Radiation" },
			{ lang::Hungarian, "Űrsugárzás" },
			{ lang::Italian, "Radiazione spaziale" },
			{ lang::Japanese, "宇宙放射線" },
			{ lang::Korean, "우주 방사선" },
			{ lang::Norwegian, "Romstråling" },
			{ lang::Dutch, "Kosmische straling" },
			{ lang::Polish, "Kosmiczna radiacja" },
			{ lang::BrazilianPortuguese, "Radiação espacial" },
			{ lang::Portuguese, "Radiação espacial" },
			{ lang::Russian, "Космическое Излучение" },
			{ lang::Swedish, "Rymdstrålning" },
			{ lang::Turkish, "Uzay Radyasyonu" },
			{ lang::SimplifiedChinese, "太空辐射" },
			{ lang::TraditionalChinese, "太空輻射" },
		},
	},
	{
		Msg::STRING168,
		{
			{ lang::Arabic, "Bug Hunt" },
			{ lang::Czech, "Honba na vetřelce" },
			{ lang::Danish, "Billejagt" },
			{ lang::German, "Jagdmanöver" },
			{ lang::Greek, "Καταδίωξη ιού" },
			{ lang::English, "Bug Hunt" },
			{ lang::Spanish, "Caza de bichos" },
			{ lang::Finnish, "Ötökkäjahti" },
			{ lang::French, "Chasse aux virus" },
			{ lang::Hebrew, "Bug Hunt" },
			{ lang::Hungarian, "Bogárirtás" },
			{ lang::Italian, "Caccia al virus" },
			{ lang::Japanese, "バグ ハント" },
			{ lang::Korean, "우주 바이러스 퇴치" },
			{ lang::Norwegian, "Gulljakt" },
			{ lang::Dutch, "Bug Hunt" },
			{ lang::Polish, "Polowanie na pluskwy" },
			{ lang::BrazilianPortuguese, "Caçada assassina" },
			{ lang::Portuguese, "Caça aos 'bugs'" },
			{ lang::Russian, "Охота На Жуков" },
			{ lang::Swedish, "Insekter" },
			{ lang::Turkish, "Böcek Avı" },
			{ lang::SimplifiedChinese, "猎虫" },
			{ lang::TraditionalChinese, "搜尋微生物" },
		},
	},
	{
		Msg::STRING169,
		{
			{ lang::Arabic, "Alien Menace" },
			{ lang::Czech, "Vetřelci útočí" },
			{ lang::Danish, "Trusler fra fremmede" },
			{ lang::German, "Fremdbedrohung" },
			{ lang::Greek, "Απειλή εξωγήινων" },
			{ lang::English, "Alien Menace" },
			{ lang::Spanish, "Amenaza exterior" },
			{ lang::Finnish, "Ufojen isku" },
			{ lang::French, "Menace extra-terrestre" },
			{ lang::Hebrew, "Alien Menace" },
			{ lang::Hungarian, "Földönkívüliek támadása" },
			{ lang::Italian, "Pericolo alieni" },
			{ lang::Japanese, "エイリアン襲来!" },
			{ lang::Korean, "외계인 출현" },
			{ lang::Norwegian, "Romtrussel" },
			{ lang::Dutch, "Alien Menace" },
			{ lang::Polish, "Inwazja obcych" },
			{ lang::BrazilianPortuguese, "Ameaça alienígena" },
			{ lang::Portuguese, "Ameaça extraterrestre" },
			{ lang::Russian, "Инопланетная Угроза" },
			{ lang::Swedish, "Pigs in Space" },
			{ lang::Turkish, "Yabancı İstilası" },
			{ lang::SimplifiedChinese, "外星人的威协" },
			{ lang::TraditionalChinese, "異境驚魂" },
		},
	},
	{
		Msg::STRING170,
		{
			{ lang::Arabic, "Rescue" },
			{ lang::Czech, "Záchrana" },
			{ lang::Danish, "Redning" },
			{ lang::German, "Rettungsaktion" },
			{ lang::Greek, "Διάσωση" },
			{ lang::English, "Rescue" },
			{ lang::Spanish, "Rescate" },
			{ lang::Finnish, "Pelastus" },
			{ lang::French, "Sauvetage" },
			{ lang::Hebrew, "Rescue" },
			{ lang::Hungarian, "Mentőakció" },
			{ lang::Italian, "Salvataggio" },
			{ lang::Japanese, "レスキュー" },
			{ lang::Korean, "구출" },
			{ lang::Norwegian, "Redning" },
			{ lang::Dutch, "Rescue" },
			{ lang::Polish, "Misja ratunkowa" },
			{ lang::BrazilianPortuguese, "Salvamento" },
			{ lang::Portuguese, "Salvamento" },
			{ lang::Russian, "Спасение" },
			{ lang::Swedish, "Räddningsaktion" },
			{ lang::Turkish, "Kurtarma" },
			{ lang::SimplifiedChinese, "援助" },
			{ lang::TraditionalChinese, "拯救" },
		},
	},
	{
		Msg::STRING171,
		{
			{ lang::Arabic, "Satellite Retrieval" },
			{ lang::Czech, "Získání satelitu" },
			{ lang::Danish, "Satellitredning" },
			{ lang::German, "Satellitenbergung" },
			{ lang::Greek, "Ανάκτηση δορυφόρου" },
			{ lang::English, "Satellite Retrieval" },
			{ lang::Spanish, "Recuperación de satélites" },
			{ lang::Finnish, "Satelliitin nouto" },
			{ lang::French, "Récupération du satellite" },
			{ lang::Hebrew, "Satellite Retrieval" },
			{ lang::Hungarian, "Műhold befogása" },
			{ lang::Italian, "Recupero satellite" },
			{ lang::Japanese, "サテライト リトリーバル" },
			{ lang::Korean, "위성 되찾기" },
			{ lang::Norwegian, "Satelittgjenvinning" },
			{ lang::Dutch, "Satelliet oppikken" },
			{ lang::Polish, "Przechwycenie satelity" },
			{ lang::BrazilianPortuguese, "Resgate do satélite" },
			{ lang::Portuguese, "Recuperação de satélites" },
			{ lang::Russian, "Поиск Спутника" },
			{ lang::Swedish, "Hämta satellit" },
			{ lang::Turkish, "Uydu Alımı" },
			{ lang::SimplifiedChinese, "卫星收回" },
			{ lang::TraditionalChinese, "人造衛星回收" },
		},
	},
	{
		Msg::STRING172,
		{
			{ lang::Arabic, "Recon" },
			{ lang::Czech, "Průzkum" },
			{ lang::Danish, "Rekognoscering" },
			{ lang::German, "Aufklärung" },
			{ lang::Greek, "Αναγνώριση" },
			{ lang::English, "Recon" },
			{ lang::Spanish, "Reconocimiento" },
			{ lang::Finnish, "Tiedustelu" },
			{ lang::French, "Reconnaissance" },
			{ lang::Hebrew, "Recon" },
			{ lang::Hungarian, "Békekötés" },
			{ lang::Italian, "Riconoscimento" },
			{ lang::Japanese, "偵察" },
			{ lang::Korean, "정찰" },
			{ lang::Norwegian, "Rekognosering" },
			{ lang::Dutch, "Verkenning" },
			{ lang::Polish, "Rekonesans" },
			{ lang::BrazilianPortuguese, "Reconhecimento" },
			{ lang::Portuguese, "Reconhecimento" },
			{ lang::Russian, "Разведка" },
			{ lang::Swedish, "Spaningsuppdrag" },
			{ lang::Turkish, "Recon" },
			{ lang::SimplifiedChinese, "侦察" },
			{ lang::TraditionalChinese, "偵查" },
		},
	},
	{
		Msg::STRING173,
		{
			{ lang::Arabic, "Doomsday Machine" },
			{ lang::Czech, "Stroj zkázy" },
			{ lang::Danish, "Dommedagsmaskine" },
			{ lang::German, "Schwadron" },
			{ lang::Greek, "Συσκευή ολοκληρωτικής καταστροφής" },
			{ lang::English, "Doomsday Machine" },
			{ lang::Spanish, "Máquina catastrófica" },
			{ lang::Finnish, "Helvetinkone" },
			{ lang::French, "Machine de la fin du monde" },
			{ lang::Hebrew, "Doomsday Machine" },
			{ lang::Hungarian, "Halálosztó gép" },
			{ lang::Italian, "Macchina della fine del mondo" },
			{ lang::Japanese, "ドゥームズデイ マシン" },
			{ lang::Korean, "핵무기" },
			{ lang::Norwegian, "Helvetesmaskin" },
			{ lang::Dutch, "Doomsday Machine" },
			{ lang::Polish, "Maszyna zagłady" },
			{ lang::BrazilianPortuguese, "Máquina do Juízo Final" },
			{ lang::Portuguese, "Máquina do fim do mundo" },
			{ lang::Russian, "Машина Судного Дня" },
			{ lang::Swedish, "Domedagsmaskin" },
			{ lang::Turkish, "Kıyamet Makinesi" },
			{ lang::SimplifiedChinese, "世界末日机器" },
			{ lang::TraditionalChinese, "世界末日機" },
		},
	},
	{
		Msg::STRING174,
		{
			{ lang::Arabic, "Cosmic Plague" },
			{ lang::Czech, "Vesmírná epidemie" },
			{ lang::Danish, "Kosmisk pest" },
			{ lang::German, "Kosmische Seuche" },
			{ lang::Greek, "Κοσμική μάστιγα" },
			{ lang::English, "Cosmic Plague" },
			{ lang::Spanish, "Plaga cósmica" },
			{ lang::Finnish, "Kosminen rutto" },
			{ lang::French, "Peste cosmique" },
			{ lang::Hebrew, "Cosmic Plague" },
			{ lang::Hungarian, "Kozmikus pestis" },
			{ lang::Italian, "Peste cosmica" },
			{ lang::Japanese, "宇宙疫病" },
			{ lang::Korean, "우주 재앙" },
			{ lang::Norwegian, "Kosmisk pest" },
			{ lang::Dutch, "Kosmische plaag" },
			{ lang::Polish, "Plaga kosmiczna" },
			{ lang::BrazilianPortuguese, "Peste cósmica" },
			{ lang::Portuguese, "Praga cósmica" },
			{ lang::Russian, "Космическая чума" },
			{ lang::Swedish, "Kosmisk pest" },
			{ lang::Turkish, "Kozmik Veba" },
			{ lang::SimplifiedChinese, "宇宙灾难" },
			{ lang::TraditionalChinese, "宇宙災禍" },
		},
	},
	{
		Msg::STRING175,
		{
			{ lang::Arabic, "Secret" },
			{ lang::Czech, "Tajné" },
			{ lang::Danish, "Hemmelig" },
			{ lang::German, "Geheimnis" },
			{ lang::Greek, "Μυστικό" },
			{ lang::English, "Secret" },
			{ lang::Spanish, "Secreto" },
			{ lang::Finnish, "Salainen" },
			{ lang::French, "Secret" },
			{ lang::Hebrew, "Secret" },
			{ lang::Hungarian, "Titkos" },
			{ lang::Italian, "Segreto" },
			{ lang::Japanese, "シークレット" },
			{ lang::Korean, "비밀" },
			{ lang::Norwegian, "Hemmelighet" },
			{ lang::Dutch, "Geheim" },
			{ lang::Polish, "Tajemnica" },
			{ lang::BrazilianPortuguese, "Segredo" },
			{ lang::Portuguese, "Segredo" },
			{ lang::Russian, "Секрет" },
			{ lang::Swedish, "Hemlighet" },
			{ lang::Turkish, "Gizli" },
			{ lang::SimplifiedChinese, "机密" },
			{ lang::TraditionalChinese, "秘密" },
		},
	},
	{
		Msg::STRING176,
		{
			{ lang::Arabic, "Time Warp" },
			{ lang::Czech, "Přesun v čase" },
			{ lang::Danish, "Tidsforskydning" },
			{ lang::German, "Zeitsprung" },
			{ lang::Greek, "Χρονοστρέβλωση" },
			{ lang::English, "Time Warp" },
			{ lang::Spanish, "Salto en el tiempo" },
			{ lang::Finnish, "Aikahyppy" },
			{ lang::French, "Distorsion du temps" },
			{ lang::Hebrew, "Time Warp" },
			{ lang::Hungarian, "Időugrás" },
			{ lang::Italian, "Curvatura temporale" },
			{ lang::Japanese, "タイム ワープ!" },
			{ lang::Korean, "시간 이동" },
			{ lang::Norwegian, "Tidssprang" },
			{ lang::Dutch, "Time Warp" },
			{ lang::Polish, "Zakrzywienie czasu" },
			{ lang::BrazilianPortuguese, "Distorção temporal" },
			{ lang::Portuguese, "Salto no tempo" },
			{ lang::Russian, "Искривление Времени" },
			{ lang::Swedish, "Tidsresa" },
			{ lang::Turkish, "Zaman Sıçraması" },
			{ lang::SimplifiedChinese, "时间扭曲" },
			{ lang::TraditionalChinese, "時間扭曲" },
		},
	},
	{
		Msg::STRING177,
		{
			{ lang::Arabic, "Maelstrom" },
			{ lang::Czech, "Hvězdný vír" },
			{ lang::Danish, "Hvirvelstrøm" },
			{ lang::German, "Strudel" },
			{ lang::Greek, "Δίνη" },
			{ lang::English, "Maelstrom" },
			{ lang::Spanish, "¡Vorágine!" },
			{ lang::Finnish, "Maelstrom" },
			{ lang::French, "Maelström" },
			{ lang::Hebrew, "Maelstrom" },
			{ lang::Hungarian, "Maelström" },
			{ lang::Italian, "Maelstrom" },
			{ lang::Japanese, "メールストローム" },
			{ lang::Korean, "대혼란" },
			{ lang::Norwegian, "Malstrøm" },
			{ lang::Dutch, "Maelstrom" },
			{ lang::Polish, "Wir" },
			{ lang::BrazilianPortuguese, "Redemoinho" },
			{ lang::Portuguese, "Redemoinho" },
			{ lang::Russian, "Водоворот" },
			{ lang::Swedish, "Maelstrom" },
			{ lang::Turkish, "Girdap" },
			{ lang::SimplifiedChinese, "大旋涡" },
			{ lang::TraditionalChinese, "大動亂" },
		},
	},
	{
		Msg::STRING178,
		{
			{ lang::Arabic, "Mission Accepted\n%ld" },
			{ lang::Czech, "Úkol přijat\n%ld" },
			{ lang::Danish, "Mission accepteret\n%ld" },
			{ lang::German, "Auftrag beginnt\n%ld" },
			{ lang::Greek, "Αποδοχή αποστολής\n%ld" },
			{ lang::English, "Mission Accepted\n%ld" },
			{ lang::Spanish, "Misión aceptada\n%ld" },
			{ lang::Finnish, "Tehtävä hyväksytty\n%ld" },
			{ lang::French, "Mission acceptée\n%ld" },
			{ lang::Hebrew, "Mission Accepted\n%ld" },
			{ lang::Hungarian, "Küldetés elfogadva\n%ld" },
			{ lang::Italian, "Missione accettata\n%ld" },
			{ lang::Japanese, "ミッション確定!\n%ld" },
			{ lang::Korean, "임무 시작\n%ld" },
			{ lang::Norwegian, "Oppdrag godtatt\n%ld" },
			{ lang::Dutch, "Missie aanvaard\n%ld" },
			{ lang::Polish, "Misja przyjęta\n%ld" },
			{ lang::BrazilianPortuguese, "Missão aceita\n%ld" },
			{ lang::Portuguese, "Missão aceite\n%ld" },
			{ lang::Russian, "Миссия Принята\n%ld" },
			{ lang::Swedish, "Uppdraget accepterat\n%ld" },
			{ lang::Turkish, "Görev Kabul Edildi\n%ld" },
			{ lang::SimplifiedChinese, "接受的使命\n%ld" },
			{ lang::TraditionalChinese, "任務接受\n%ld" },
		},
	},
	{
		Msg::STRING179,
		{
			{ lang::Arabic, "Mission Completed\n%ld" },
			{ lang::Czech, "Úkol splněn\n%ld" },
			{ lang::Danish, "Mission fuldført\n%ld" },
			{ lang::German, "Auftrag beendet\n%ld" },
			{ lang::Greek, "Ολοκλήρωση αποστολής\n%ld" },
			{ lang::English, "Mission Completed\n%ld" },
			{ lang::Spanish, "Misión cumplida\n%ld" },
			{ lang::Finnish, "Tehtävä suoritettu\n%ld" },
			{ lang::French, "Mission achevée\n%ld" },
			{ lang::Hebrew, "Mission Completed\n%ld" },
			{ lang::Hungarian, "Küldetés teljesítve\n%ld" },
			{ lang::Italian, "Missione compiuta\n%ld" },
			{ lang::Japanese, "ミッション完了!\n%ld" },
			{ lang::Korean, "임무 완료\n%ld" },
			{ lang::Norwegian, "Oppdrag fullført\n%ld" },
			{ lang::Dutch, "Missie volbracht\n%ld" },
			{ lang::Polish, "Misja ukończona\n%ld" },
			{ lang::BrazilianPortuguese, "Missão cumprida\n%ld" },
			{ lang::Portuguese, "Missão completa\n%ld" },
			{ lang::Russian, "Миссия Завершена\n%ld" },
			{ lang::Swedish, "Uppdraget genomfört\n%ld" },
			{ lang::Turkish, "Görev Tamamlandı\n%ld" },
			{ lang::SimplifiedChinese, "完成的使命\n%ld" },
			{ lang::TraditionalChinese, "任務完成\n%ld" },
		},
	},
	{
		Msg::STRING180,
		{
			{ lang::Arabic, "%s Mission Selected" },
			{ lang::Czech, "Vybrán úkol %s" },
			{ lang::Danish, "%s Mission udvalgt" },
			{ lang::German, "Gewählter Auftrag: %s" },
			{ lang::Greek, "Επιλογή αποστολής %s" },
			{ lang::English, "%s Mission Selected" },
			{ lang::Spanish, "Misión %s seleccionada" },
			{ lang::Finnish, "Tehtävä %s valittu" },
			{ lang::French, "%s Mission sélectionnée" },
			{ lang::Hebrew, "%s Mission Selected" },
			{ lang::Hungarian, "%s - a küldetés kiválasztva" },
			{ lang::Italian, "%s Missione selezionata" },
			{ lang::Japanese, "%s ミッション選択" },
			{ lang::Korean, "%s 임무 선택" },
			{ lang::Norwegian, "%s-oppdrag valgt" },
			{ lang::Dutch, "Geselecteerde missie: %s" },
			{ lang::Polish, "Wybrano misję: %s" },
			{ lang::BrazilianPortuguese, "Missão %s selecionada" },
			{ lang::Portuguese, "%s Missão seleccionada" },
			{ lang::Russian, "Выбрана Миссия %s" },
			{ lang::Swedish, "Uppdrag %s har valts" },
			{ lang::Turkish, "%s Görevi Seçildi" },
			{ lang::SimplifiedChinese, "选定 %s 使命" },
			{ lang::TraditionalChinese, "%s 任務選擇" },
		},
	},
	{
		Msg::STRING181,
		{
			{ lang::Arabic, "Black Hole\n%ld" },
			{ lang::Czech, "Černá díra\n%ld" },
			{ lang::Danish, "Sort hul\n%ld" },
			{ lang::German, "Schwarzes Loch\n%ld" },
			{ lang::Greek, "Μαύρη τρύπα\n%ld" },
			{ lang::English, "Black Hole\n%ld" },
			{ lang::Spanish, "Agujero negro\n%ld" },
			{ lang::Finnish, "Musta aukko\n%ld" },
			{ lang::French, "Trou noir\n%ld" },
			{ lang::Hebrew, "Black Hole\n%ld" },
			{ lang::Hungarian, "Fekete lyuk\n%ld" },
			{ lang::Italian, "Buco nero\n%ld" },
			{ lang::Japanese, "ブラック ホール!\n%ld" },
			{ lang::Korean, "블랙홀\n%ld" },
			{ lang::Norwegian, "Svart hull\n%ld" },
			{ lang::Dutch, "Zwart gat\n%ld" },
			{ lang::Polish, "Czarna dziura\n%ld" },
			{ lang::BrazilianPortuguese, "Buraco negro\n%ld" },
			{ lang::Portuguese, "Buraco negro\n%ld" },
			{ lang::Russian, "Черная Дыра\n%ld" },
			{ lang::Swedish, "Svart hål\n%ld" },
			{ lang::Turkish, "Kara Delik\n%ld" },
			{ lang::SimplifiedChinese, "黑洞\n%ld" },
			{ lang::TraditionalChinese, "黑洞\n%ld" },
		},
	},
	{
		Msg::STRING182,
		{
			{ lang::Arabic, "Gravity Normalized\n%ld" },
			{ lang::Czech, "Normální gravitace\n%ld" },
			{ lang::Danish, "Tyngdekraft normaliseret\n%ld" },
			{ lang::German, "Schwerkraft normal\n%ld" },
			{ lang::Greek, "Βαρύτητα κανονική\n%ld" },
			{ lang::English, "Gravity Normalized\n%ld" },
			{ lang::Spanish, "Gravedad normalizada\n%ld" },
			{ lang::Finnish, "Gravitaatio normalisoitu\n%ld" },
			{ lang::French, "Gravité normale\n%ld" },
			{ lang::Hebrew, "Gravity Normalized\n%ld" },
			{ lang::Hungarian, "Gravitáció normalizálva\n%ld" },
			{ lang::Italian, "Gravità normalizzata\n%ld" },
			{ lang::Japanese, "グラビティ正常化\n%ld" },
			{ lang::Korean, "중력 정상화\n%ld" },
			{ lang::Norwegian, "Normalisert tyngdekraft\n%ld" },
			{ lang::Dutch, "Normale zwaartekracht\n%ld" },
			{ lang::Polish, "Grawitacja normalna\n%ld" },
			{ lang::BrazilianPortuguese, "Gravidade normalizada\n%ld" },
			{ lang::Portuguese, "Gravidade normalizada\n%ld" },
			{ lang::Russian, "Гравитация Нормализованна\n%ld" },
			{ lang::Swedish, "Normal gravitation\n%ld" },
			{ lang::Turkish, "Yerçekimi Normal\n%ld" },
			{ lang::SimplifiedChinese, "正常引力\n%ld" },
			{ lang::TraditionalChinese, "重力常態化\n%ld" },
		},
	},
	{
		Msg::STRING183,
		{
			{ lang::Arabic, "Gravity Well\n%ld" },
			{ lang::Czech, "Zvýšená gravitace\n%ld" },
			{ lang::Danish, "Tyngdebrønd\n%ld" },
			{ lang::German, "Schwerkraftzone\n%ld" },
			{ lang::Greek, "Βαρυτικό πεδίο\n%ld" },
			{ lang::English, "Gravity Well\n%ld" },
			{ lang::Spanish, "Pozo gravitatorio\n%ld" },
			{ lang::Finnish, "Gravitaatiokuoppa\n%ld" },
			{ lang::French, "Centre de gravité\n%ld" },
			{ lang::Hebrew, "Gravity Well\n%ld" },
			{ lang::Hungarian, "Gravitációs csapda\n%ld" },
			{ lang::Italian, "Pozzo di gravità\n%ld" },
			{ lang::Japanese, "グラビティ ウェル\n%ld" },
			{ lang::Korean, "중력의 중심\n%ld" },
			{ lang::Norwegian, "Tyngdekraftsbrønn\n%ld" },
			{ lang::Dutch, "Gravity-put\n%ld" },
			{ lang::Polish, "Studnia grawitacyjna\n%ld" },
			{ lang::BrazilianPortuguese, "Poço de gravidade\n%ld" },
			{ lang::Portuguese, "Poço gravitacional\n%ld" },
			{ lang::Russian, "Гравитационный Колодец\n%ld" },
			{ lang::Swedish, "Gravitationshål\n%ld" },
			{ lang::Turkish, "Yerçekimi Kuyusu\n%ld" },
			{ lang::SimplifiedChinese, "引力井\n%ld" },
			{ lang::TraditionalChinese, "重力井\n%ld" },
		},
	},
	{
		Msg::STRING184,
		{
			{ lang::Arabic, "الترقية إلى %s" },
			{ lang::Czech, "Povýšení na hodnost %s" },
			{ lang::Danish, "Forfremmelse til %s" },
			{ lang::German, "Zum %s befördert" },
			{ lang::Greek, "Προαγωγή σε %s" },
			{ lang::English, "Promotion to %s" },
			{ lang::Spanish, "Ascenso a %s" },
			{ lang::Finnish, "Ylennetty arvo: %s" },
			{ lang::French, "Élévation au grade de %s" },
			{ lang::Hebrew, "Promotion to %s" },
			{ lang::Hungarian, "Előléptetés %s rangba" },
			{ lang::Italian, "Promozione a %s" },
			{ lang::Japanese, "%s に昇格" },
			{ lang::Korean, "%s(으)로 수준 올리기" },
			{ lang::Norwegian, "Forfremmelse til %s" },
			{ lang::Dutch, "Promotie naar %s" },
			{ lang::Polish, "Awans do stopnia: %s" },
			{ lang::BrazilianPortuguese, "Promovido a %s" },
			{ lang::Portuguese, "Ascender para %s" },
			{ lang::Russian, "Повышение до %s" },
			{ lang::Swedish, "Befordran till %s" },
			{ lang::Turkish, "%s Terfisi" },
			{ lang::SimplifiedChinese, "升级到 %s" },
			{ lang::TraditionalChinese, "提升 %s" },
		},
	},
	{
		Msg::STRING185,
		{
			{ lang::Arabic, "Cadet" },
			{ lang::Czech, "Kadet" },
			{ lang::Danish, "Kadet" },
			{ lang::German, "Kadetten" },
			{ lang::Greek, "Δόκιμος" },
			{ lang::English, "Cadet" },
			{ lang::Spanish, "Cadete" },
			{ lang::Finnish, "Kadetti" },
			{ lang::French, "Élève officier" },
			{ lang::Hebrew, "Cadet" },
			{ lang::Hungarian, "Tizedesi" },
			{ lang::Italian, "Cadetto" },
			{ lang::Japanese, "士官候補生" },
			{ lang::Korean, "후보생" },
			{ lang::Norwegian, "Kadett" },
			{ lang::Dutch, "Kadet" },
			{ lang::Polish, "Kadet" },
			{ lang::BrazilianPortuguese, "Cadete" },
			{ lang::Portuguese, "Cadete" },
			{ lang::Russian, "Кадет" },
			{ lang::Swedish, "Space Cadet" },
			{ lang::Turkish, "Cadet" },
			{ lang::SimplifiedChinese, "军校生" },
			{ lang::TraditionalChinese, "軍校生" },
		},
	},
	{
		Msg::STRING186,
		{
			{ lang::Arabic, "Ensign" },
			{ lang::Czech, "Podporučík" },
			{ lang::Danish, "Sekondløjtnant" },
			{ lang::German, "Flagge" },
			{ lang::Greek, "Ανθυποπλοίαρχος" },
			{ lang::English, "Ensign" },
			{ lang::Spanish, "Alférez" },
			{ lang::Finnish, "Aliluutnantti" },
			{ lang::French, "Enseigne de vaisseau" },
			{ lang::Hebrew, "Ensign" },
			{ lang::Hungarian, "Szakaszvezetői" },
			{ lang::Italian, "Alfiere" },
			{ lang::Japanese, "少尉" },
			{ lang::Korean, "소위" },
			{ lang::Norwegian, "Fenrik" },
			{ lang::Dutch, "Kornet" },
			{ lang::Polish, "Rekrut" },
			{ lang::BrazilianPortuguese, "Sargento" },
			{ lang::Portuguese, "Alferes" },
			{ lang::Russian, "Прапорщик" },
			{ lang::Swedish, "Furir" },
			{ lang::Turkish, "Ensign" },
			{ lang::SimplifiedChinese, "海军少尉" },
			{ lang::TraditionalChinese, "海軍少尉" },
		},
	},
	{
		Msg::STRING187,
		{
			{ lang::Arabic, "Lieutenant" },
			{ lang::Czech, "Poručík" },
			{ lang::Danish, "Løjtnant" },
			{ lang::German, "Leutnant" },
			{ lang::Greek, "Υποπλοίαρχος" },
			{ lang::English, "Lieutenant" },
			{ lang::Spanish, "Teniente" },
			{ lang::Finnish, "Luutnantti" },
			{ lang::French, "Lieutenant de vaisseau" },
			{ lang::Hebrew, "Lieutenant" },
			{ lang::Hungarian, "Őrmesteri" },
			{ lang::Italian, "Tenente" },
			{ lang::Japanese, "中尉" },
			{ lang::Korean, "중위" },
			{ lang::Norwegian, "Løytnant" },
			{ lang::Dutch, "Luitenant" },
			{ lang::Polish, "Porucznik" },
			{ lang::BrazilianPortuguese, "Tenente" },
			{ lang::Portuguese, "Tenente" },
			{ lang::Russian, "Лейтенант" },
			{ lang::Swedish, "Sergeant" },
			{ lang::Turkish, "Teğmen" },
			{ lang::SimplifiedChinese, "海军上尉" },
			{ lang::TraditionalChinese, "海軍中尉" },
		},
	},
	{
		Msg::STRING188,
		{
			{ lang::Arabic, "Captain" },
			{ lang::Czech, "Nadporučík" },
			{ lang::Danish, "Kaptajn" },
			{ lang::German, "Kapitän" },
			{ lang::Greek, "Κυβερνήτης" },
			{ lang::English, "Captain" },
			{ lang::Spanish, "Capitán" },
			{ lang::Finnish, "Kapteeni" },
			{ lang::French, "Capitaine de corvette" },
			{ lang::Hebrew, "Captain" },
			{ lang::Hungarian, "Főtörzsőrmesteri" },
			{ lang::Italian, "Capitano" },
			{ lang::Japanese, "大尉" },
			{ lang::Korean, "대위" },
			{ lang::Norwegian, "Kapteinløytnant" },
			{ lang::Dutch, "Kapitein" },
			{ lang::Polish, "Kapitan" },
			{ lang::BrazilianPortuguese, "Capitão" },
			{ lang::Portuguese, "Capitão" },
			{ lang::Russian, "Капитан" },
			{ lang::Swedish, "Fänrik" },
			{ lang::Turkish, "Yüzbaşı" },
			{ lang::SimplifiedChinese, "海军上校" },
			{ lang::TraditionalChinese, "海軍上尉" },
		},
	},
	{
		Msg::STRING189,
		{
			{ lang::Arabic, "Lt Commander" },
			{ lang::Czech, "Kapitán" },
			{ lang::Danish, "Kaptajnløjtnant" },
			{ lang::German, "Lt. Commander" },
			{ lang::Greek, "Αντιπλοίαρχος" },
			{ lang::English, "Lt Commander" },
			{ lang::Spanish, "Teniente comandante" },
			{ lang::Finnish, "Komentajakapteeni" },
			{ lang::French, "Capitaine de frégate" },
			{ lang::Hebrew, "Lt Commander" },
			{ lang::Hungarian, "Hadnagyi" },
			{ lang::Italian, "Capitano di corvetta" },
			{ lang::Japanese, "少佐" },
			{ lang::Korean, "소령" },
			{ lang::Norwegian, "Orlogskaptein" },
			{ lang::Dutch, "Luitenant-gezagvoerder" },
			{ lang::Polish, "Młodszy komandor" },
			{ lang::BrazilianPortuguese, "Subcomandante" },
			{ lang::Portuguese, "Tenente comandante" },
			{ lang::Russian, "Лейтенант-Коммандер" },
			{ lang::Swedish, "Löjtnant" },
			{ lang::Turkish, "Yrd Kumandan" },
			{ lang::SimplifiedChinese, "海军少校" },
			{ lang::TraditionalChinese, "海軍少校" },
		},
	},
	{
		Msg::STRING190,
		{
			{ lang::Arabic, "Commander" },
			{ lang::Czech, "Major" },
			{ lang::Danish, "Orlogskaptajn" },
			{ lang::German, "Kommandant" },
			{ lang::Greek, "Πλοίαρχος" },
			{ lang::English, "Commander" },
			{ lang::Spanish, "Comandante" },
			{ lang::Finnish, "Varakommodori" },
			{ lang::French, "Capitaine de vaisseau" },
			{ lang::Hebrew, "Commander" },
			{ lang::Hungarian, "Századosi" },
			{ lang::Italian, "Comandante" },
			{ lang::Japanese, "中佐" },
			{ lang::Korean, "중령" },
			{ lang::Norwegian, "Kommandørkaptein" },
			{ lang::Dutch, "Gezagvoerder" },
			{ lang::Polish, "Komandor" },
			{ lang::BrazilianPortuguese, "Comandante" },
			{ lang::Portuguese, "Comandante" },
			{ lang::Russian, "Коммандер" },
			{ lang::Swedish, "Kapten" },
			{ lang::Turkish, "Kumandan" },
			{ lang::SimplifiedChinese, "司令官" },
			{ lang::TraditionalChinese, "海軍中校" },
		},
	},
	{
		Msg::STRING191,
		{
			{ lang::Arabic, "Commodore" },
			{ lang::Czech, "Podplukovník" },
			{ lang::Danish, "Kommandør" },
			{ lang::German, "Kommodore" },
			{ lang::Greek, "Διοικητής" },
			{ lang::English, "Commodore" },
			{ lang::Spanish, "Comodoro" },
			{ lang::Finnish, "Kommodori" },
			{ lang::French, "Contre-amiral" },
			{ lang::Hebrew, "Commodore" },
			{ lang::Hungarian, "Őrnagyi" },
			{ lang::Italian, "Commodoro" },
			{ lang::Japanese, "准将" },
			{ lang::Korean, "부함장" },
			{ lang::Norwegian, "Kommandør" },
			{ lang::Dutch, "Commodore" },
			{ lang::Polish, "Komodor" },
			{ lang::BrazilianPortuguese, "Contra-almirante" },
			{ lang::Portuguese, "Comodoro" },
			{ lang::Russian, "Коммодор" },
			{ lang::Swedish, "Major" },
			{ lang::Turkish, "Reis" },
			{ lang::SimplifiedChinese, "海军准将" },
			{ lang::TraditionalChinese, "海軍准將" },
		},
	},
	{
		Msg::STRING192,
		{
			{ lang::Arabic, "Admiral" },
			{ lang::Czech, "Plukovník" },
			{ lang::Danish, "Admiral" },
			{ lang::German, "Admiral" },
			{ lang::Greek, "Ναύαρχος" },
			{ lang::English, "Admiral" },
			{ lang::Spanish, "Almirante" },
			{ lang::Finnish, "Vara-amiraali" },
			{ lang::French, "Vice-amiral" },
			{ lang::Hebrew, "Admiral" },
			{ lang::Hungarian, "Alezredesi" },
			{ lang::Italian, "Ammiraglio" },
			{ lang::Japanese, "大将" },
			{ lang::Korean, "함장" },
			{ lang::Norwegian, "Viseadmiral" },
			{ lang::Dutch, "Admiraal" },
			{ lang::Polish, "Admirał" },
			{ lang::BrazilianPortuguese, "Almirante" },
			{ lang::Portuguese, "Almirante" },
			{ lang::Russian, "Адмирал" },
			{ lang::Swedish, "Överste" },
			{ lang::Turkish, "Amiral" },
			{ lang::SimplifiedChinese, "海军上将" },
			{ lang::TraditionalChinese, "海軍上將" },
		},
	},
	{
		Msg::STRING193,
		{
			{ lang::Arabic, "Fleet Admiral" },
			{ lang::Czech, "Generál" },
			{ lang::Danish, "Storadmiral" },
			{ lang::German, "Flottenadmiral" },
			{ lang::Greek, "Στόλαρχος" },
			{ lang::English, "Fleet Admiral" },
			{ lang::Spanish, "Almirante de la flota" },
			{ lang::Finnish, "Amiraali" },
			{ lang::French, "Amiral" },
			{ lang::Hebrew, "Fleet Admiral" },
			{ lang::Hungarian, "Ezredesi" },
			{ lang::Italian, "Grande Ammiraglio" },
			{ lang::Japanese, "元帥" },
			{ lang::Korean, "제독" },
			{ lang::Norwegian, "Admiral" },
			{ lang::Dutch, "Vlootadmiraal" },
			{ lang::Polish, "Admirał floty" },
			{ lang::BrazilianPortuguese, "Almirante-de-fragata" },
			{ lang::Portuguese, "Almirante da esquadra" },
			{ lang::Russian, "Адмирал Флота" },
			{ lang::Swedish, "General" },
			{ lang::Turkish, "Filo Amirali" },
			{ lang::SimplifiedChinese, "海军五星上将" },
			{ lang::TraditionalChinese, "海軍一級上將" },
		},
	},
	{
		Msg::STRING194,
		{
			{ lang::Arabic, "Wormhole Opened" },
			{ lang::Czech, "Červí díra otevřena" },
			{ lang::Danish, "Ormehul åbent" },
			{ lang::German, "Wurmloch geöffnet" },
			{ lang::Greek, "Διαστημική σήραγγα ανοιχτή" },
			{ lang::English, "Wormhole Opened" },
			{ lang::Spanish, "Túnel espacial abierto" },
			{ lang::Finnish, "Madonreikä avattu" },
			{ lang::French, "Repaire du ver géant ouvert" },
			{ lang::Hebrew, "Wormhole Opened" },
			{ lang::Hungarian, "A Féreglyuk nyitva van" },
			{ lang::Italian, "Tunnel spaziale aperto" },
			{ lang::Japanese, "ワームホールが開いた!" },
			{ lang::Korean, "웜홀이 열림" },
			{ lang::Norwegian, "Åpnet ormebol" },
			{ lang::Dutch, "Wormhole geopend" },
			{ lang::Polish, "Tunel czasoprzestrzenny otwarty" },
			{ lang::BrazilianPortuguese, "Fenda espacial aberta" },
			{ lang::Portuguese, "Túnel espacial aberto" },
			{ lang::Russian, "Червоточина Открыта" },
			{ lang::Swedish, "Maskhålet är öppet" },
			{ lang::Turkish, "Solucan Deliği Açık" },
			{ lang::SimplifiedChinese, "打开旋涡式星体" },
			{ lang::TraditionalChinese, "蟲孔開啟" },
		},
	},
	{
		Msg::STRING195,
		{
			{ lang::Arabic, "Crash Bonus\n%ld" },
			{ lang::Czech, "Bonus za havárii\n%ld" },
			{ lang::Danish, "Nedstyrtningsbonus\n%ld" },
			{ lang::German, "Absturzbonus\n%ld" },
			{ lang::Greek, "Μπόνους συντριβής\n%ld" },
			{ lang::English, "Crash Bonus\n%ld" },
			{ lang::Spanish, "Bonificación de estallido\n%ld" },
			{ lang::Finnish, "Törmäysbonus\n%ld" },
			{ lang::French, "Bonus de crash\n%ld" },
			{ lang::Hebrew, "Crash Bonus\n%ld" },
			{ lang::Hungarian, "Zuhanás bónusz\n%ld" },
			{ lang::Italian, "Bonus\n%ld" },
			{ lang::Japanese, "クラッシュ ボーナス\n%ld" },
			{ lang::Korean, "추락 보너스\n%ld" },
			{ lang::Norwegian, "Krasjbonus\n%ld" },
			{ lang::Dutch, "Crashbonus\n%ld" },
			{ lang::Polish, "Premia za katastrofę\n%ld" },
			{ lang::BrazilianPortuguese, "Bônus:\n%ld" },
			{ lang::Portuguese, "Bónus de queda\n%ld" },
			{ lang::Russian, "Бонус за Крушение\n%ld" },
			{ lang::Swedish, "Slutbonus\n%ld" },
			{ lang::Turkish, "Çarpışma Ödülü\n%ld" },
			{ lang::SimplifiedChinese, "坠毁奖分\n%ld" },
			{ lang::TraditionalChinese, "粉碎紅利\n%ld" },
		},
	},
	{
		Msg::STRING196,
		{
			{ lang::Arabic, "Replay Ball" },
			{ lang::Czech, "Opakování míče" },
			{ lang::Danish, "Spil kugle igen" },
			{ lang::German, "Kugel wiederholen" },
			{ lang::Greek, "Επανάληψη μπίλιας" },
			{ lang::English, "Replay Ball" },
			{ lang::Spanish, "Bola extra" },
			{ lang::Finnish, "Pelaa pallo uudelleen" },
			{ lang::French, "Nouvelle bille" },
			{ lang::Hebrew, "Replay Ball" },
			{ lang::Hungarian, "Golyó újra" },
			{ lang::Italian, "Gioca pallina di nuovo" },
			{ lang::Japanese, "リプレイ ボール" },
			{ lang::Korean, "다시 쏘기" },
			{ lang::Norwegian, "Ekstraball" },
			{ lang::Dutch, "Replay Ball" },
			{ lang::Polish, "Rozgrywaj ponownie" },
			{ lang::BrazilianPortuguese, "Jogar a bola novamente" },
			{ lang::Portuguese, "Bola extra" },
			{ lang::Russian, "Реплей Шарика" },
			{ lang::Swedish, "Fortsätt spela..." },
			{ lang::Turkish, "Topu Yeniden Oyna" },
			{ lang::SimplifiedChinese, "重玩球" },
			{ lang::TraditionalChinese, "重新玩球" },
		},
	},
	{
		Msg::STRING197,
		{
			{ lang::Arabic, "Re-Deploy" },
			{ lang::Czech, "Nový míč" },
			{ lang::Danish, "Gentag affyring" },
			{ lang::German, "Neustart" },
			{ lang::Greek, "Επανάληψη εκτόξευσης" },
			{ lang::English, "Re-Deploy" },
			{ lang::Spanish, "Implementar de nuevo" },
			{ lang::Finnish, "Laukaise uudelleen" },
			{ lang::French, "Redéploiement" },
			{ lang::Hebrew, "Re-Deploy" },
			{ lang::Hungarian, "Újraindítás" },
			{ lang::Italian, "Rischieramento" },
			{ lang::Japanese, "再発射" },
			{ lang::Korean, "재배치" },
			{ lang::Norwegian, "Utstasjoner på nytt" },
			{ lang::Dutch, "Opnieuw lanceren" },
			{ lang::Polish, "Rozstawiaj ponownie" },
			{ lang::BrazilianPortuguese, "Relançamento" },
			{ lang::Portuguese, "Voltar a lançar a bola" },
			{ lang::Russian, "Повторное Развертывание" },
			{ lang::Swedish, "Omdistribuera" },
			{ lang::Turkish, "Yeniden Başlat" },
			{ lang::SimplifiedChinese, "重新部署" },
			{ lang::TraditionalChinese, "重新調配" },
		},
	},
	{
		Msg::STRING198,
		{
			{ lang::Arabic, "Player 1 Shoot Again" },
			{ lang::Czech, "Nový míč hráče 1" },
			{ lang::Danish, "Spiller 1 skyd igen" },
			{ lang::German, "Spieler 1 - Neue Kugel" },
			{ lang::Greek, "Παίκτης 1, επανάληψη" },
			{ lang::English, "Player 1 Shoot Again" },
			{ lang::Spanish, "Jugador 1 tira otra vez" },
			{ lang::Finnish, "Pelaaja 1, laukaise uudelleen" },
			{ lang::French, "Joueur 1, rejouez" },
			{ lang::Hebrew, "Player 1 Shoot Again" },
			{ lang::Hungarian, "1. játékos újra lő" },
			{ lang::Italian, "Giocatore 1, pronto al lancio!" },
			{ lang::Japanese, "プレーヤー 1 再度発射してください" },
			{ lang::Korean, "비행사 1 - 다시 쏘기" },
			{ lang::Norwegian, "Spiller 1 Skyt igjen" },
			{ lang::Dutch, "Speler 1 Shoot Again" },
			{ lang::Polish, "Gracz 1 rozgrywa ponownie" },
			{ lang::BrazilianPortuguese, "Jogador 1 lança novamente" },
			{ lang::Portuguese, "Jogador 1 volta a lançar a bola" },
			{ lang::Russian, "Игрок 1 Стреляет Снова" },
			{ lang::Swedish, "Spelare 1 - extraboll" },
			{ lang::Turkish, "1. Oyuncu Atışı Yinele" },
			{ lang::SimplifiedChinese, "玩家 1 再次射球" },
			{ lang::TraditionalChinese, "玩家 1 再射一次" },
		},
	},
	{
		Msg::STRING199,
		{
			{ lang::Arabic, "Player 2 Shoot Again" },
			{ lang::Czech, "Nový míč hráče 2" },
			{ lang::Danish, "Spiller 2 skyd igen" },
			{ lang::German, "Spieler 2 - Neue Kugel" },
			{ lang::Greek, "Παίκτης 2, επανάληψη" },
			{ lang::English, "Player 2 Shoot Again" },
			{ lang::Spanish, "Jugador 2 tira otra vez" },
			{ lang::Finnish, "Pelaaja 2, laukaise uudelleen" },
			{ lang::French, "Joueur 2, rejouez" },
			{ lang::Hebrew, "Player 2 Shoot Again" },
			{ lang::Hungarian, "2. játékos újra lő" },
			{ lang::Italian, "Giocatore 2, pronto al lancio!" },
			{ lang::Japanese, "プレーヤー 2 再度発射してください" },
			{ lang::Korean, "비행사 2 - 다시 쏘기" },
			{ lang::Norwegian, "Spiller 2 Skyt igjen" },
			{ lang::Dutch, "Speler 2 Shoot Again" },
			{ lang::Polish, "Gracz 2 rozgrywa ponownie" },
			{ lang::BrazilianPortuguese, "Jogador 2 lança novamente" },
			{ lang::Portuguese, "Jogador 2 volta a lançar a bola" },
			{ lang::Russian, "Игрок 2 Стреляет Снова" },
			{ lang::Swedish, "Spelare 2 - extraboll" },
			{ lang::Turkish, "2. Oyuncu Atışı Yinele" },
			{ lang::SimplifiedChinese, "玩家 2 再次射球" },
			{ lang::TraditionalChinese, "玩家 2 再射一次" },
		},
	},
	{
		Msg::STRING200,
		{
			{ lang::Arabic, "Player 3 Shoot Again" },
			{ lang::Czech, "Nový míč hráče 3" },
			{ lang::Danish, "Spiller 3 skyd igen" },
			{ lang::German, "Spieler 3 - Neue Kugel" },
			{ lang::Greek, "Παίκτης 3, επανάληψη" },
			{ lang::English, "Player 3 Shoot Again" },
			{ lang::Spanish, "Jugador 2 tira otra vez" },
			{ lang::Finnish, "Pelaaja 3, laukaise uudelleen" },
			{ lang::French, "Joueur 3, rejouez" },
			{ lang::Hebrew, "Player 3 Shoot Again" },
			{ lang::Hungarian, "3. játékos újra lő" },
			{ lang::Italian, "Giocatore 3, pronto al lancio!" },
			{ lang::Japanese, "プレーヤー 3 再度発射してください" },
			{ lang::Korean, "비행사 3 - 다시 쏘기" },
			{ lang::Norwegian, "Spiller 3 Skyt igjen" },
			{ lang::Dutch, "Speler 3 Shoot Again" },
			{ lang::Polish, "Gracz 3 rozgrywa ponownie" },
			{ lang::BrazilianPortuguese, "Jogador 3 lança novamente" },
			{ lang::Portuguese, "Jogador 3 volta a lançar a bola" },
			{ lang::Russian, "Игрок 3 Стреляет Снова" },
			{ lang::Swedish, "Spelare 3 - extraboll" },
			{ lang::Turkish, "3. Oyuncu Atışı Yinele" },
			{ lang::SimplifiedChinese, "玩家 3 再次射球" },
			{ lang::TraditionalChinese, "玩家 3 再射一次" },
		},
	},
	{
		Msg::STRING201,
		{
			{ lang::Arabic, "Player 4 Shoot Again" },
			{ lang::Czech, "Nový míč hráče 4" },
			{ lang::Danish, "Spiller 4 skyd igen" },
			{ lang::German, "Spieler 4 - Neue Kugel" },
			{ lang::Greek, "Παίκτης 4, επανάληψη" },
			{ lang::English, "Player 4 Shoot Again" },
			{ lang::Spanish, "Jugador 4 tira otra vez" },
			{ lang::Finnish, "Pelaaja 4, laukaise uudelleen" },
			{ lang::French, "Joueur 4, rejouez" },
			{ lang::Hebrew, "Player 4 Shoot Again" },
			{ lang::Hungarian, "4. játékos újra lő" },
			{ lang::Italian, "Giocatore 4, pronto al lancio!" },
			{ lang::Japanese, "プレーヤー 4 再度発射してください" },
			{ lang::Korean, "비행사 4 - 다시 쏘기" },
			{ lang::Norwegian, "Spiller 4 Skyt igjen" },
			{ lang::Dutch, "Speler 4 Shoot Again" },
			{ lang::Polish, "Gracz 4 rozgrywa ponownie" },
			{ lang::BrazilianPortuguese, "Jogador 4 lança novamente" },
			{ lang::Portuguese, "Jogador 4 volta a lançar a bola" },
			{ lang::Russian, "Игрок 4 Стреляет Снова" },
			{ lang::Swedish, "Spelare 4 - extraboll" },
			{ lang::Turkish, "4. Oyuncu Atışı Yinele" },
			{ lang::SimplifiedChinese, "玩家 4 再次射球" },
			{ lang::TraditionalChinese, "玩家 4 再射一次" },
		},
	},
	{
		Msg::STRING202,
		{
			{ lang::Arabic, "‏‏تم إنشاء ‎3D Pinball Table لصالح Microsoft من قبل Maxis.\nلمزيد من المعلومات اتصل بـ ‎(800)-336-2947\n(بالنسبة لعملاء الولايات المتحدة وكندا فقط)\nحقوق النشر (c) 1995 Maxis." },
			{ lang::Czech, "Hra 3D Pinball Table byla vytvořena pro Microsoft firmou Maxis.\nDalší informace na čísle (800)-336-2947\n(platí pro USA a Kanadu).\nCopyright (c) 1995 Maxis." },
			{ lang::Danish, "Dette 3D Pinball-bord er skabt til Microsoft af Maxis.\nYderligere oplysninger får du ved at ringe på telefonnummer (800)-336-2947\n(kun for brugere i USA og Canada).\nCopyright (c) 1995 Maxis." },
			{ lang::German, "3D-Pinball-Tisch wurde für Microsoft von Maxis entwickelt.\nCopyright (C) 1995 Maxis." },
			{ lang::Greek, "Το παιχνίδι 3D Pinball Table δημιουργήθηκε για τη Microsoft από τη Maxis.\nΓια περισσότερες πληροφορίες, τηλεφωνήστε στο (800)-336-2947\n(για πελάτες στις ΗΠΑ και στον Καναδά μόνο).\nΠνευματικά δικαιώματα (c) 1995 Maxis." },
			{ lang::English, "This 3D Pinball Table was created for Microsoft by Maxis.\nFor more information call (800)-336-2947\n(US and Canadian customers only).\nCopyright (c) 1995 Maxis." },
			{ lang::Spanish, "Esta mesa de 3D Pinball fue creada para Microsoft por Maxis.\nPara más información póngase en contacto con la\nsubsidiaria de Microsoft más cercana.\nCopyright (c) 1995 Maxis." },
			{ lang::Finnish, "Tämän 3D Pinball -pöydän on tehnyt Microsoftille Maxis.\nCopyright (c) 1995 Maxis." },
			{ lang::French, "Ce flipper Pinball 3D a été créé pour Microsoft par Maxis.\nPour obtenir plus d'informations, appelez le service Consommateurs\nd’Electronic Arts au 04 72 53 25 00 (France) ou de Maxis\nau (800)-336-2947 (États-Unis et Canada seulement).\nCopyright (c) 1995 Maxis." },
			{ lang::Hebrew, "‏‏שולחן Pinball תלת-מימדי זה נוצר עבור Microsoft על-ידי Maxis‏.\nלקבלת מידע נוסף, התקשר לטלפון ‎(800)-336-2947‏\n (לקוחות בארצות הברית וקנדה בלבד).\nCopyright (c) 1995 Maxis." },
			{ lang::Hungarian, "Ezt a 3D-flipper pályát a Maxis készítette a Microsoft számára.\nTovábbi információkért hívja a (800)-336-2947 telefonszámot\n(az Egyesült államokban és Kanadában).\nCopyright (c) 1995 Maxis." },
			{ lang::Italian, "3D Pinball è stato creato per Microsoft dalla Maxis.\nPer ulteriori informazioni contattare i seguenti numeri telefonici: (800)-336-2947 o (512)-343-190\n(Stati Uniti e Canada soltanto).\nCopyright (c) 1995 Maxis." },
			{ lang::Japanese, "この 3D ピンボール テーブルは、米国 Maxis 社が Microsoft 社のために作成しました。Copyright(C) 1995 Maxis." },
			{ lang::Korean, "3D Pinball Table은 Microsoft를 위해 Maxis가 개발했습니다.\n자세한 정보가 필요하면 (800)-336-2947로 문의하십시오.\n(미국 및 캐나다)\nCopyright (c) 1995-1996 Maxis." },
			{ lang::Norwegian, "Dette 3D Pinball-bordet ble laget for Microsoft av Maxis.\nDu får mer informasjon ved å ringe (800)-336-2947\n(bare kunder i USA og Canada.\nCopyright (c) 1995 Maxis." },
			{ lang::Dutch, "3D Pinball is ontwikkeld voor Microsoft door Maxis.\nCopyright (c) 1995 Maxis." },
			{ lang::Polish, "Ta gra 3D Pinball Table została opracowana dla firmy Microsoft przez firmę Maxis.\nWięcej informacji pod numerem tel. (800)-336-2947\n(tylko klienci z USA i Kanady).\nCopyright (c) 1995 Maxis." },
			{ lang::BrazilianPortuguese, "Esta máquina de Pinball 3D foi criada para a Microsoft pela Maxis.\nPara obter mais informações, ligue para (800)-336-2947\n(somente clientes nos EUA e Canadá).\nCopyright (C) 1996 Maxis." },
			{ lang::Portuguese, "Este jogo de Pinball 3D foi criado por Maxis para a Microsoft.\nPara obter mais informação pode ligar para (800)-336-2947\n(Apenas para clientes dos E.U.A. e Canadá).\nCopyright (c) 1995 Maxis." },
			{ lang::Russian, "Эта программа разработана MAXIS по заказу Microsoft.\n© 1995 Maxis." },
			{ lang::Swedish, "Denna spelplan har utvecklats för Microsoft av Maxis.\nCopyright (c) 1995 Maxis." },
			{ lang::Turkish, "This 3D Pinball Table was created for Microsoft by Maxis.\nFor more information call (800)-336-2947\n(US and Canadian customers only).\nCopyright (c) 1995 Maxis." },
			{ lang::SimplifiedChinese, "该“三维弹球”是由 Maxis 为 Microsoft 创建的。\n详细信息，请拨电话 (800)-336-2947\n(只适用于美国和加拿大的客户)。\n版权所有 (C) 1995 Maxis。" },
			{ lang::TraditionalChinese, "這個立體彈珠台桌是 Maxis 為 Microsoft 建立的。\n若需進一步的資訊，請電 (800)-336-2947\n(僅適用於美國和加拿大地區的客戶)。\nCopyright (c) 1995 Maxis." },
		},
	},
	{
		Msg::STRING203,
		{
			{ lang::Arabic, "‏‏تم إنشاء ‎3D Pinball Table لصالح Microsoft من قبل Maxis. حقوق النشر(c) ‏1995 ‎ Maxis." },
			{ lang::Czech, "Hra 3D Pinball Table byla vytvořena pro společnost Microsoft firmou Maxis. Copyright (c) 1995 Maxis." },
			{ lang::Danish, "3D Pinball-bord fremstillet til Microsoft af Maxis. Copyright (c) 1995 Maxis." },
			{ lang::German, "3D-Pinball-Tisch wurde für Microsoft von Maxis entwickelt. Copyright (C) 1995 Maxis." },
			{ lang::Greek, "Το παιχνίδι 3D Pinball Table δημιουργήθηκε για τη Microsoft από τη Maxis. Πνευματικά δικαιώματα (c) 1995 Maxis." },
			{ lang::English, "3D Pinball Table created for Microsoft by Maxis. Copyright (c) 1995 Maxis." },
			{ lang::Spanish, "3D Pinball Table creado para Microsoft por Maxis. Copyright (c) 1995 Maxis." },
			{ lang::Finnish, "3D Pinball -pöydän on tehnyt Microsoftille Maxis. Copyright (c) 1995 Maxis." },
			{ lang::French, "Pinball 3D a été créé pour Microsoft par Maxis. Copyright (c) 1995 Maxis." },
			{ lang::Hebrew, "‏‎3D Pinball Table נוצר עבור Microsoft על-ידי Maxis‏. Copyright (c) 1995 Maxis." },
			{ lang::Hungarian, "Ezt a 3D-flipper pályát a Maxis készítette a Microsoft számára. Copyright (c) 1995 Maxis." },
			{ lang::Italian, "3D Pinball è stato creato per Microsoft dalla Maxis. Copyright (c) 1995 Maxis." },
			{ lang::Japanese, "米国 Maxis 社が Microsoft 社のために作成した 3D ピンボール テーブル。Copyright(C) 1995 Maxis." },
			{ lang::Korean, "3D Pinball Table은 Microsoft를 위해 Maxis가 개발했습니다. Copyright (c) 1995-1996 Maxis." },
			{ lang::Norwegian, "3D Pinball-bord laget for Microsoft av Maxis. Copyright (c) 1995 Maxis." },
			{ lang::Dutch, "3D Pinball is ontwikkeld voor Microsoft door Maxis. Copyright (c) 1995 Maxis." },
			{ lang::Polish, "Gra 3D Pinball Table opracowana dla Microsoft przez firmę Maxis. Copyright (c) 1995 Maxis." },
			{ lang::BrazilianPortuguese, "Esta máquina de Pinball 3D foi criada para a Microsoft pela Maxis. Copyright (C) 1995 Maxis." },
			{ lang::Portuguese, "Este jogo de Pinball 3D foi criado por Maxis para a Microsoft. Copyright (c) 1995 Maxis." },
			{ lang::Russian, "Эта программа разработана MAXIS по заказу Microsoft. © 1995 Maxis." },
			{ lang::Swedish, "Denna 3D Pinball-spelplan har utvecklats för Microsoft av Maxis. Copyright (c) 1995 Maxis." },
			{ lang::Turkish, "3D Pinball Table created for Microsoft by Maxis. Copyright (c) 1995 Maxis." },
			{ lang::SimplifiedChinese, "该“三维弹球”是由 Maxis 为 Microsoft 创建的。版权所有(C) 1995 Maxis。" },
			{ lang::TraditionalChinese, "立體彈珠台桌是 Maxis 為 Microsoft 建立的。Copyright (c) 1995 Maxis." },
		},
	},
	{
		Msg::STRING204,
		{
			{ lang::Arabic, "حول ‎3D Pinball" },
			{ lang::Czech, "Co je hra 3D Pinball" },
			{ lang::Danish, "Om 3D Pinball" },
			{ lang::German, "Info" },
			{ lang::Greek, "Πληροφορίες για το Φλίπερ-3Δ" },
			{ lang::English, "About 3D Pinball" },
			{ lang::Spanish, "Acerca de 3D Pinball" },
			{ lang::Finnish, "Tietoja 3D Pinballista" },
			{ lang::French, "À propos de Pinball 3D" },
			{ lang::Hebrew, "אודות 3D Pinball" },
			{ lang::Hungarian, "3D-flipper névjegye" },
			{ lang::Italian, "Informazioni su 3D Pinball" },
			{ lang::Japanese, "バージョン情報" },
			{ lang::Korean, "3D 핀볼 정보" },
			{ lang::Norwegian, "Om 3D Pinball" },
			{ lang::Dutch, "Info" },
			{ lang::Polish, "3D Pinball - informacje" },
			{ lang::BrazilianPortuguese, "Sobre o Pinball 3D" },
			{ lang::Portuguese, "Acerca do 3D Pinball" },
			{ lang::Russian, "О программе" },
			{ lang::Swedish, "Om 3D Pinball" },
			{ lang::Turkish, "3B Pinball Hakkında" },
			{ lang::SimplifiedChinese, "关于三维弹球" },
			{ lang::TraditionalChinese, "立體彈珠台的相關資訊" },
		},
	},
	{
		Msg::STRING205,
		{
			{ lang::Arabic, "Hit Mission Targets To Select Mission" },
			{ lang::Czech, "Úkol vyberete trefou do cíle úkolu" },
			{ lang::Danish, "Ram missionsmål for at vælge mission" },
			{ lang::German, "Zur Auftragswahl Zielobjekte treffen" },
			{ lang::Greek, "Για να επιλέξετε αποστολή, σημαδέψτε τους στόχους αποστολών" },
			{ lang::English, "Hit Mission Targets To Select Mission" },
			{ lang::Spanish, "Tire a las dianas de misión para seleccionar misión" },
			{ lang::Finnish, "Valitse tehtävä osumalla tehtävätauluihin" },
			{ lang::French, "Visez les cibles pour choisir une mission" },
			{ lang::Hebrew, "Hit Mission Targets To Select Mission" },
			{ lang::Hungarian, "Küldetéséért lőjön a küldetési célokra" },
			{ lang::Italian, "Per selezionare la missione, colpire gli obiettivi della missione" },
			{ lang::Japanese, "ミッション ターゲットを狙ってミッションを選択せよ!" },
			{ lang::Korean, "임무 표적을 맞혀 임무 선택" },
			{ lang::Norwegian, "Treff mål for å velge oppdrag" },
			{ lang::Dutch, "Raak missiedoelen om een missie te selecteren" },
			{ lang::Polish, "Aby wybrać misję, celuj w tarcze misji" },
			{ lang::BrazilianPortuguese, "Acerte os alvos indicados por uma seta azul para selecionar uma missão" },
			{ lang::Portuguese, "Seleccione a missão acertando nos alvos" },
			{ lang::Russian, "Поразите Цели Миссии, Чтобы Выбрать Миссию" },
			{ lang::Swedish, "Välj uppdrag genom att träffa uppdragstavlor" },
			{ lang::Turkish, "Görev Seçmek için Görev Hedeflerini Vurun" },
			{ lang::SimplifiedChinese, "击中使命目标以选定使命" },
			{ lang::TraditionalChinese, "將任務目標對準選取的任務" },
		},
	},
	{
		Msg::STRING206,
		{
			{ lang::Arabic, "Re-Fuel Ship" },
			{ lang::Czech, "Doplnění paliva" },
			{ lang::Danish, "Tank skib op" },
			{ lang::German, "Auftanken" },
			{ lang::Greek, "Ανεφοδιάστε το σκάφος" },
			{ lang::English, "Re-Fuel Ship" },
			{ lang::Spanish, "Repostar nave" },
			{ lang::Finnish, "Tankkaa alus" },
			{ lang::French, "Réapprovisionnement du vaisseau" },
			{ lang::Hebrew, "Re-Fuel Ship" },
			{ lang::Hungarian, "Tankolja fel a hajót" },
			{ lang::Italian, "Rifornire di carburante la navicella" },
			{ lang::Japanese, "燃料を補給せよ!" },
			{ lang::Korean, "배에 연료 공급" },
			{ lang::Norwegian, "Bunkre skip på nytt" },
			{ lang::Dutch, "Schip bijtanken" },
			{ lang::Polish, "Uzupełnij paliwo" },
			{ lang::BrazilianPortuguese, "Reabasteça a nave" },
			{ lang::Portuguese, "Reabastecer a nave" },
			{ lang::Russian, "Заправьте Корабль" },
			{ lang::Swedish, "Tanka om skeppet" },
			{ lang::Turkish, "Gemiye Yakıt Al" },
			{ lang::SimplifiedChinese, "飞船补充燃料" },
			{ lang::TraditionalChinese, "船舶重新加油" },
		},
	},
	{
		Msg::STRING207,
		{
			{ lang::Arabic, "Launch Ramp To Accept %s Mission" },
			{ lang::Czech, "Vystřelením rampy přijmete úkol %s" },
			{ lang::Danish, "Affyringsrampe accepterer %ss-mission" },
			{ lang::German, "Auftrag %s durch Rampentreffer aktivieren" },
			{ lang::Greek, "Ράμπα εκτόξευσης για αποστολή %s" },
			{ lang::English, "Launch Ramp To Accept %s Mission" },
			{ lang::Spanish, "Rampa para aceptar misión %s" },
			{ lang::Finnish, "Hyväksy tehtävä %s osumalla ramppiin" },
			{ lang::French, "Rampe d'acceptation de la mission %s" },
			{ lang::Hebrew, "Launch Ramp To Accept %s Mission" },
			{ lang::Hungarian, "%s küldetés - menjen a kilövőállásra" },
			{ lang::Italian, "Rampa di lancio per accettare: %s" },
			{ lang::Japanese, "発射ランプを狙って %s ミッションを確定せよ!" },
			{ lang::Korean, "발사대를 맞혀 %s 임무 시작" },
			{ lang::Norwegian, "Skyt ut for å godta %s-oppdrag" },
			{ lang::Dutch, "Missie %s begint als bal op platform is" },
			{ lang::Polish, "Pomost ładowania akceptuje misję %s" },
			{ lang::BrazilianPortuguese, "Rampa de lançamento p/ missão %s" },
			{ lang::Portuguese, "Lançar p/ rampa para aceitar a missão %s" },
			{ lang::Russian, "Попадите в Рампу, Чтобы Принять Миссию %s" },
			{ lang::Swedish, "Acceptera uppdraget %s i rampen" },
			{ lang::Turkish, "%s Görevini Üstlenmek için Pistten Kalk" },
			{ lang::SimplifiedChinese, "进入发射坡道，接受 %s 使命" },
			{ lang::TraditionalChinese, "射入左斜坡道以接受%s任務" },
		},
	},
	{
		Msg::STRING208,
		{
			{ lang::Arabic, "Attack Bumpers Hits\nLeft: %d" },
			{ lang::Czech, "Trefa do útočných nárazníků\nZbývá: %d" },
			{ lang::Danish, "Ram angrebsbump\nTilbage: %d" },
			{ lang::German, "Rückstoßtreffer\nSoll: %d" },
			{ lang::Greek, "Βολές στους προσκρουστήρες\nΑπομένουν: %d" },
			{ lang::English, "Attack Bumpers Hits\nLeft: %d" },
			{ lang::Spanish, "Golpes a reboteadores de ataque\nRestantes: %d" },
			{ lang::Finnish, "Osumia hyökkäyspuskureihin\njäljellä: %d" },
			{ lang::French, "Tirs sur champignons d'attaque\nrestants : %d" },
			{ lang::Hebrew, "Attack Bumpers Hits\nLeft: %d" },
			{ lang::Hungarian, "Támadógomba találatok\nMaradt: %d" },
			{ lang::Italian, "Colpi ai respingenti\nRimasti: %d" },
			{ lang::Japanese, "アタック バンパー\nヒット\n残り: %d" },
			{ lang::Korean, "공격 범퍼 맞히기\n남은 횟수: %d" },
			{ lang::Norwegian, "Gjenstående\nangrepsbumpertreff: %d" },
			{ lang::Dutch, "Aanvalbumpertreffers\nResterend: %d" },
			{ lang::Polish, "Trafienia zderzaków ataku\nPozostało: %d" },
			{ lang::BrazilianPortuguese, "Batidas nos amortecedores de ataque\nrestantes: %d" },
			{ lang::Portuguese, "Batidas dos amortecedores de ataque\nRestante: %d" },
			{ lang::Russian, "Осталось Попаданий по Бамперам Атаки: %d" },
			{ lang::Swedish, "Träffa höghöjds-bumpers\n%d träffar kvar" },
			{ lang::Turkish, "Vuruş Tamponlar Vuruşu\nSol: %d" },
			{ lang::SimplifiedChinese, "攻击缓冲器击中\n剩余：%d" },
			{ lang::TraditionalChinese, "攻擊緩衝器的打擊\n剩餘：%d" },
		},
	},
	{
		Msg::STRING209,
		{
			{ lang::Arabic, "Target Training Passed" },
			{ lang::Czech, "Nácvik míření dokončen" },
			{ lang::Danish, "Måltræning bestået" },
			{ lang::German, "Zielübungen absolviert" },
			{ lang::Greek, "Εξάσκηση σκοποβολής: επιτυχής" },
			{ lang::English, "Target Training Passed" },
			{ lang::Spanish, "Aprobado el entrenamiento de dianas" },
			{ lang::Finnish, "Maalitauluharjoitus suoritettu" },
			{ lang::French, "Essais de tir réussis" },
			{ lang::Hebrew, "Target Training Passed" },
			{ lang::Hungarian, "Lőgyakorlat teljesítve" },
			{ lang::Italian, "Esercitazione di tiro superata" },
			{ lang::Japanese, "ターゲット訓練修了!" },
			{ lang::Korean, "사격 훈련 통과" },
			{ lang::Norwegian, "Skyteøvelse bestått" },
			{ lang::Dutch, "Schietoefeningen voltooid" },
			{ lang::Polish, "Test celności zdany" },
			{ lang::BrazilianPortuguese, "Passou no teste de tiro ao alvo" },
			{ lang::Portuguese, "Aprovado o treino da reentrada" },
			{ lang::Russian, "Стрельба по Мишеням Пройдена" },
			{ lang::Swedish, "Bumper-träning genomförd" },
			{ lang::Turkish, "Hedef Eğitimi Başarılı" },
			{ lang::SimplifiedChinese, "通过目标培训" },
			{ lang::TraditionalChinese, "通過目標訓練" },
		},
	},
	{
		Msg::STRING210,
		{
			{ lang::Arabic, "Mission Aborted" },
			{ lang::Czech, "Úkol zrušen" },
			{ lang::Danish, "Mission afbrudt" },
			{ lang::German, "Auftrag abgebrochen" },
			{ lang::Greek, "Ματαίωση αποστολής" },
			{ lang::English, "Mission Aborted" },
			{ lang::Spanish, "Misión cancelada" },
			{ lang::Finnish, "Tehtävä keskeytetty" },
			{ lang::French, "Mission abandonnée" },
			{ lang::Hebrew, "Mission Aborted" },
			{ lang::Hungarian, "A küldetés félbeszakítva" },
			{ lang::Italian, "Missione interrotta" },
			{ lang::Japanese, "ミッション中止" },
			{ lang::Korean, "임무 취소" },
			{ lang::Norwegian, "Oppdrag avbrutt" },
			{ lang::Dutch, "Missie afgebroken" },
			{ lang::Polish, "Misja przerwana" },
			{ lang::BrazilianPortuguese, "Missão cancelada" },
			{ lang::Portuguese, "Missão abortada" },
			{ lang::Russian, "Миссия Прервана" },
			{ lang::Swedish, "Uppdraget avbrutet" },
			{ lang::Turkish, "Görev İptal" },
			{ lang::SimplifiedChinese, "放弃使命" },
			{ lang::TraditionalChinese, "中止任務" },
		},
	},
	{
		Msg::STRING211,
		{
			{ lang::Arabic, "Launches Left: %d" },
			{ lang::Czech, "Zbývá odpálení: %d" },
			{ lang::Danish, "Affyringer tilbage: %d" },
			{ lang::German, "Verbleibende Starts: %d" },
			{ lang::Greek, "Απομένουσες εκτοξεύσεις: %d" },
			{ lang::English, "Launches Left: %d" },
			{ lang::Spanish, "Lanzamientos restantes: %d" },
			{ lang::Finnish, "Lähtöjä jäljellä: %d" },
			{ lang::French, "Tirs restants : %d" },
			{ lang::Hebrew, "Launches Left: %d" },
			{ lang::Hungarian, "%d fellövés van még hátra" },
			{ lang::Italian, "Lanci rimasti: %d" },
			{ lang::Japanese, "発射ランプ\n残り: %d" },
			{ lang::Korean, "남은 발사 횟수: %d" },
			{ lang::Norwegian, "Gjenstående utskytinger: %d" },
			{ lang::Dutch, "Resterende lanceringen: %d" },
			{ lang::Polish, "Pozostało ładowań: %d" },
			{ lang::BrazilianPortuguese, "Lançamentos restantes: %d" },
			{ lang::Portuguese, "Restantes lançamentos: %d" },
			{ lang::Russian, "Запусков Осталось: %d" },
			{ lang::Swedish, "%d rampträffar kvar" },
			{ lang::Turkish, "Kalan Kalkış: %d" },
			{ lang::SimplifiedChinese, "剩余发射次数：%d" },
			{ lang::TraditionalChinese, "啟動次數剩餘：%d" },
		},
	},
	{
		Msg::STRING212,
		{
			{ lang::Arabic, "Launch Training Passed" },
			{ lang::Czech, "Nácvik odpálení dokončen" },
			{ lang::Danish, "Affyringstræning bestået" },
			{ lang::German, "Startübungen absolviert" },
			{ lang::Greek, "Εξάσκηση εκτόξευσης: επιτυχής" },
			{ lang::English, "Launch Training Passed" },
			{ lang::Spanish, "Aprobado el entrenamiento de lanzamiento" },
			{ lang::Finnish, "Lähtöharjoitus suoritettu" },
			{ lang::French, "Essais de tir réussis" },
			{ lang::Hebrew, "Launch Training Passed" },
			{ lang::Hungarian, "Fellövési gyakorlat teljesítve" },
			{ lang::Italian, "Esercitazione di lancio superata" },
			{ lang::Japanese, "発射訓練修了!" },
			{ lang::Korean, "발사 훈련 통과" },
			{ lang::Norwegian, "Utskytingstrening bestått" },
			{ lang::Dutch, "Lanceertraining voltooid" },
			{ lang::Polish, "Test ładowania zdany" },
			{ lang::BrazilianPortuguese, "Passou no treinamento de lançamento" },
			{ lang::Portuguese, "Treino de lançamento aprovado" },
			{ lang::Russian, "Тренировка по Запуску Пройдена" },
			{ lang::Swedish, "Rampträning genomförd" },
			{ lang::Turkish, "Kalkış Eğitimi Başarılı" },
			{ lang::SimplifiedChinese, "通过了发射训练" },
			{ lang::TraditionalChinese, "通過啟動訓練" },
		},
	},
	{
		Msg::STRING213,
		{
			{ lang::Arabic, "Re-Entries Left: %d" },
			{ lang::Czech, "Zbývá návratů: %d" },
			{ lang::Danish, "Gentagelser tilbage: %d" },
			{ lang::German, "Verbleibende\nLandungen: %d" },
			{ lang::Greek, "Απομένουσες επαναφορές: %d" },
			{ lang::English, "Re-Entries Left: %d" },
			{ lang::Spanish, "Reentradas restantes: %d" },
			{ lang::Finnish, "Paluukertoja jäljellä: %d" },
			{ lang::French, "Rentrées restantes : %d" },
			{ lang::Hebrew, "Re-Entries Left: %d" },
			{ lang::Hungarian, "%d újrabelépést kell még teljesíteni" },
			{ lang::Italian, "Rientri rimasti: %d" },
			{ lang::Japanese, "再突入\n残り: %d" },
			{ lang::Korean, "남은 재돌입 횟수: %d" },
			{ lang::Norwegian, "Gjenstående tilbakekomster: %d" },
			{ lang::Dutch, "Terugkeertraining resterend: %d" },
			{ lang::Polish, "Pozostało ponownych wejść: %d" },
			{ lang::BrazilianPortuguese, "Reentradas restantes: %d" },
			{ lang::Portuguese, "Reentradas restantes: %d" },
			{ lang::Russian, "Возвращений Осталось: %d" },
			{ lang::Swedish, "Träffa höghöjdsgångar\n%d träffar kvar" },
			{ lang::Turkish, "Kalan Yeniden Giriş: %d" },
			{ lang::SimplifiedChinese, "所剩重新上场次数：%d" },
			{ lang::TraditionalChinese, "重新次數剩餘：%d" },
		},
	},
	{
		Msg::STRING214,
		{
			{ lang::Arabic, "Re-Entry Training Passed" },
			{ lang::Czech, "Nácvik návratu dokončen" },
			{ lang::Danish, "Gentagelsestræning bestået" },
			{ lang::German, "Landeübungen absolviert" },
			{ lang::Greek, "Εξάσκηση επαναφοράς: επιτυχής" },
			{ lang::English, "Re-Entry Training Passed" },
			{ lang::Spanish, "Aprobado el entrenamiento de reentrada" },
			{ lang::Finnish, "Paluuharjoitus suoritettu" },
			{ lang::French, "Essais de rentrée réussis" },
			{ lang::Hebrew, "Re-Entry Training Passed" },
			{ lang::Hungarian, "Újrabelépési gyakorlat teljesítve" },
			{ lang::Italian, "Esercitazione di rientro superata" },
			{ lang::Japanese, "再突入訓練修了!" },
			{ lang::Korean, "재돌입 훈련 통과" },
			{ lang::Norwegian, "Tilbakekomsttrening bestått" },
			{ lang::Dutch, "Terugkeertraining voltooid" },
			{ lang::Polish, "Test ponownych wejść zdany" },
			{ lang::BrazilianPortuguese, "Passou no treinamento de reentrada" },
			{ lang::Portuguese, "Treino de reentradas aprovado" },
			{ lang::Russian, "Тренировка по Возвращению Пройдена" },
			{ lang::Swedish, "Höghöjdsträning genomförd" },
			{ lang::Turkish, "Yeniden Giriş Eğitimi Başarılı" },
			{ lang::SimplifiedChinese, "通过了重新上场训练" },
			{ lang::TraditionalChinese, "通過重新輸入訓練" },
		},
	},
	{
		Msg::STRING215,
		{
			{ lang::Arabic, "Drop Targets\nLeft: %d" },
			{ lang::Czech, "Upuštění cílů\nZbývá: %d" },
			{ lang::Danish, "Dykkende mål\nTilbage: %d" },
			{ lang::German, "Zielkategorie 1\nSoll: %d" },
			{ lang::Greek, "Βυθιζόμενοι στόχοι\nΑπομένουν: %d" },
			{ lang::English, "Drop Targets\nLeft: %d" },
			{ lang::Spanish, "Dianas abatibles\nRestantes: %d" },
			{ lang::Finnish, "Maalitauluja\njäljellä: %d" },
			{ lang::French, "Cibles automatiques\nrestantes : %d" },
			{ lang::Hebrew, "Drop Targets\nLeft: %d" },
			{ lang::Hungarian, "Dominócélok kilövése\nMaradt: %d" },
			{ lang::Italian, "Obiettivi da abbattere\nRimasti: %d" },
			{ lang::Japanese, "ドロップ ターゲット\n残り: %d" },
			{ lang::Korean, "낙하 표적 수\n남은 개수: %d" },
			{ lang::Norwegian, "Gjenstående\nbombemål: %d" },
			{ lang::Dutch, "Drop targets \nResterend: %d" },
			{ lang::Polish, "Tarcze strącania\nPozostało: %d" },
			{ lang::BrazilianPortuguese, "Alvos tipo Drop\nrestantes: %d" },
			{ lang::Portuguese, "Alvos automáticos\nRestante: %d" },
			{ lang::Russian, "Осталось Падающих\nЦелей: %d" },
			{ lang::Swedish, "Träffa multi-, medalj- eller bonustavlor\n%d träffar kvar" },
			{ lang::Turkish, "Bırakılan Hedef\nSol: %d" },
			{ lang::SimplifiedChinese, "击落目标\n剩余：%d" },
			{ lang::TraditionalChinese, "放掉目標\n剩餘：%d" },
		},
	},
	{
		Msg::STRING216,
		{
			{ lang::Arabic, "Science Mission Completed" },
			{ lang::Czech, "Vědecký úkol dokončen" },
			{ lang::Danish, "Videnskabelig mission fuldført" },
			{ lang::German, "Forschungsauftrag beendet" },
			{ lang::Greek, "Ολοκληρώθηκε η Επιστημονική αποστολή" },
			{ lang::English, "Science Mission Completed" },
			{ lang::Spanish, "Misión científica cumplida" },
			{ lang::Finnish, "Tutkimustehtävä suoritettu" },
			{ lang::French, "Mission scientifique achevée" },
			{ lang::Hebrew, "Science Mission Completed" },
			{ lang::Hungarian, "A tudományos küldetés teljesítve" },
			{ lang::Italian, "Missione Scienza compiuta" },
			{ lang::Japanese, "サイエンス ミッション完了!" },
			{ lang::Korean, "과학 임무 완료" },
			{ lang::Norwegian, "Vitenskapelig oppdrag fullført" },
			{ lang::Dutch, "Wetenschapsmissie volbracht" },
			{ lang::Polish, "Misja naukowa ukończona" },
			{ lang::BrazilianPortuguese, "Missão científica concluída" },
			{ lang::Portuguese, "Missão científica concluída" },
			{ lang::Russian, "Научная Миссия Выполнена" },
			{ lang::Swedish, "Forskningsuppdrag genomfört" },
			{ lang::Turkish, "Bilimsel Görev Tamamlandı" },
			{ lang::SimplifiedChinese, "完成科学使命" },
			{ lang::TraditionalChinese, "完成科學任務" },
		},
	},
	{
		Msg::STRING217,
		{
			{ lang::Arabic, "Warning -- Low Fuel" },
			{ lang::Czech, "Pozor, nízký stav paliva" },
			{ lang::Danish, "Advarsel! Kun lidt brændstof tilbage" },
			{ lang::German, "Warnung -- Treibstoff wird knapp!" },
			{ lang::Greek, "Προσοχή -- τα καύσιμα τελειώνουν" },
			{ lang::English, "Warning -- Low Fuel" },
			{ lang::Spanish, "Atención: corto de combustible" },
			{ lang::Finnish, "Varoitus - polttoaine vähissä" },
			{ lang::French, "Avertissement -- Niveau de carburant bas" },
			{ lang::Hebrew, "Warning -- Low Fuel" },
			{ lang::Hungarian, "Figyelem -- kevés az üzemanyag" },
			{ lang::Italian, "Attenzione -- carburante in esaurimento" },
			{ lang::Japanese, "警告 -- 燃料が残りわずか!" },
			{ lang::Korean, "경고 - 연료가 거의 없음" },
			{ lang::Norwegian, "Advarsel!  Lite drivstoff." },
			{ lang::Dutch, "Waarschuwing: weinig brandstof" },
			{ lang::Polish, "Uwaga - niski stan paliwa" },
			{ lang::BrazilianPortuguese, "Aviso - Pouco combustível" },
			{ lang::Portuguese, "Aviso -- nível de combustível baixo" },
			{ lang::Russian, "Предупреждение - Низкий Уровень Топлива" },
			{ lang::Swedish, "Varning - lite bränsle" },
			{ lang::Turkish, "Dikkat -- Yakıt Bitiyor" },
			{ lang::SimplifiedChinese, "警告——燃料不足" },
			{ lang::TraditionalChinese, "警告——燃料不足" },
		},
	},
	{
		Msg::STRING218,
		{
			{ lang::Arabic, "Fill Right Hazard Banks" },
			{ lang::Czech, "Vyplňte pravé zásobníky stavu ohrožení" },
			{ lang::Danish, "Fyld højre risikodepoter" },
			{ lang::German, "Rechte Risikoobjekte aktivieren" },
			{ lang::Greek, "Πλήρωση δεξιάς ανάσχεσης" },
			{ lang::English, "Fill Right Hazard Banks" },
			{ lang::Spanish, "Llenar bancos de riesgo de la derecha" },
			{ lang::Finnish, "Täytä oikeanpuoleiset vaararivit" },
			{ lang::French, "Remplissez les bancs de détresse droits" },
			{ lang::Hebrew, "Fill Right Hazard Banks" },
			{ lang::Hungarian, "Lője ki a jobb vészkatapult céltáblát" },
			{ lang::Italian, "Riempimento energetico degli scudi a babordo" },
			{ lang::Japanese, "右ハザード バンクを点灯させよ!" },
			{ lang::Korean, "오른쪽 위험물 뱅크 채우기" },
			{ lang::Norwegian, "Fyll høyre farebanker" },
			{ lang::Dutch, "Rechterrisicolampjes activeren" },
			{ lang::Polish, "Wypełnij prawy bank ryzyka" },
			{ lang::BrazilianPortuguese, "Encher os bancos perigosos da direita" },
			{ lang::Portuguese, "Encher os bancos de risco da direita" },
			{ lang::Russian, "Заполните Правые Банки Опасностей" },
			{ lang::Swedish, "Träffa returtavlor till höger" },
			{ lang::Turkish, "Sağ Hasar Bantlarını Doldur" },
			{ lang::SimplifiedChinese, "添加右边危险材料库" },
			{ lang::TraditionalChinese, "填入右側危險帶" },
		},
	},
	{
		Msg::STRING219,
		{
			{ lang::Arabic, "Hyperspace Launch" },
			{ lang::Czech, "Odpálení do hyperprostoru" },
			{ lang::Danish, "Hyperspaceaffyring" },
			{ lang::German, "Hyperspace-Start" },
			{ lang::Greek, "Εκτόξευση στο υπερδιάστημα" },
			{ lang::English, "Hyperspace Launch" },
			{ lang::Spanish, "Lanzamiento al hiperespacio" },
			{ lang::Finnish, "Laukaisu hyperavaruuteen" },
			{ lang::French, "Lancement dans l'hyper-espace" },
			{ lang::Hebrew, "Hyperspace Launch" },
			{ lang::Hungarian, "Hipertér fellövés" },
			{ lang::Italian, "Lancio nell'iperspazio" },
			{ lang::Japanese, "ハイパースペースを狙え!" },
			{ lang::Korean, "하이퍼스페이스 작동" },
			{ lang::Norwegian, "Hyperrom-start" },
			{ lang::Dutch, "Hyperspacelancering" },
			{ lang::Polish, "Przejście w hiperprzestrzeń" },
			{ lang::BrazilianPortuguese, "Lançamento ao hiperespaço" },
			{ lang::Portuguese, "Lançamento para o hiperespaço" },
			{ lang::Russian, "Запуск В Гипер Пространство" },
			{ lang::Swedish, "Skjut upp kulan i hyperspace-hålan" },
			{ lang::Turkish, "Uzay Boşluğu Kalkışı" },
			{ lang::SimplifiedChinese, "超空发射" },
			{ lang::TraditionalChinese, "超空間啟動" },
		},
	},
	{
		Msg::STRING220,
		{
			{ lang::Arabic, "Comet Destroyed" },
			{ lang::Czech, "Kometa zničena" },
			{ lang::Danish, "Komet destrueret" },
			{ lang::German, "Komet abgewehrt" },
			{ lang::Greek, "Ο κομήτης καταστράφηκε" },
			{ lang::English, "Comet Destroyed" },
			{ lang::Spanish, "Cometa destruido" },
			{ lang::Finnish, "Komeetta tuhottu" },
			{ lang::French, "Comète détruite" },
			{ lang::Hebrew, "Comet Destroyed" },
			{ lang::Hungarian, "Az üstökös elpusztítva" },
			{ lang::Italian, "Cometa distrutta" },
			{ lang::Japanese, "遊星を粉砕!" },
			{ lang::Korean, "혜성 파괴" },
			{ lang::Norwegian, "Komet ødelagt" },
			{ lang::Dutch, "Komeet vernietigd" },
			{ lang::Polish, "Kometa zniszczona" },
			{ lang::BrazilianPortuguese, "Cometa destruído" },
			{ lang::Portuguese, "Cometa destruído" },
			{ lang::Russian, "Комета Уничтожена" },
			{ lang::Swedish, "Kometen oskadliggjord" },
			{ lang::Turkish, "Kuyruklu Yıldız Yok Edildi" },
			{ lang::SimplifiedChinese, "毁坏的彗星" },
			{ lang::TraditionalChinese, "彗星毀滅" },
		},
	},
	{
		Msg::STRING221,
		{
			{ lang::Arabic, "Enter Wormhole" },
			{ lang::Czech, "Vstupte do červí díry" },
			{ lang::Danish, "Ind i ormehul" },
			{ lang::German, "Wurmloch treffen" },
			{ lang::Greek, "Είσοδος στη διαστημική σήραγγα" },
			{ lang::English, "Enter Wormhole" },
			{ lang::Spanish, "Entrar en el túnel espacial" },
			{ lang::Finnish, "Laukaise madonreikään" },
			{ lang::French, "Entrez dans le repaire du ver géant" },
			{ lang::Hebrew, "Enter Wormhole" },
			{ lang::Hungarian, "Lépjen be a féreglyukba" },
			{ lang::Italian, "Entra nel tunnel spaziale" },
			{ lang::Japanese, "ワームホールへ突入!" },
			{ lang::Korean, "웜홀에 들어감" },
			{ lang::Norwegian, "Gå inn i ormebol" },
			{ lang::Dutch, "Wormhole ingaan" },
			{ lang::Polish, "Celuj w tunel czasoprzestrzenny" },
			{ lang::BrazilianPortuguese, "Entrar na fenda espacial" },
			{ lang::Portuguese, "Entrar no túnel espacial" },
			{ lang::Russian, "Войдите в Червоточину" },
			{ lang::Swedish, "Skjut in kulan i maskhål" },
			{ lang::Turkish, "Solucan Deliğine Gir" },
			{ lang::SimplifiedChinese, "进入旋涡式星体" },
			{ lang::TraditionalChinese, "進入蟲孔" },
		},
	},
	{
		Msg::STRING222,
		{
			{ lang::Arabic, "Radiation Eliminated" },
			{ lang::Czech, "Radiace omezena" },
			{ lang::Danish, "Stråling elimineret" },
			{ lang::German, "Strahlung beseitigt" },
			{ lang::Greek, "Η ακτινοβολία αντιμετωπίστηκε" },
			{ lang::English, "Radiation Eliminated" },
			{ lang::Spanish, "Radiación eliminada" },
			{ lang::Finnish, "Säteily torjuttu" },
			{ lang::French, "Rayonnement supprimé" },
			{ lang::Hebrew, "Radiation Eliminated" },
			{ lang::Hungarian, "Sugárzás közömbösítve" },
			{ lang::Italian, "Radiazione eliminata" },
			{ lang::Japanese, "放射線消滅!" },
			{ lang::Korean, "방사선 제거" },
			{ lang::Norwegian, "Eliminert stråling" },
			{ lang::Dutch, "Straling geëlimineerd" },
			{ lang::Polish, "Radiacja zlikwidowana" },
			{ lang::BrazilianPortuguese, "Radiação eliminada" },
			{ lang::Portuguese, "Radiação eliminada" },
			{ lang::Russian, "Излучение Устранено" },
			{ lang::Swedish, "Räddade från strålning" },
			{ lang::Turkish, "Radyasyon Etkisizleştirildi" },
			{ lang::SimplifiedChinese, "辐射清除" },
			{ lang::TraditionalChinese, "輻射消除" },
		},
	},
	{
		Msg::STRING223,
		{
			{ lang::Arabic, "Upgrade Launch Bumpers" },
			{ lang::Czech, "Vylepšete odpalovací nárazníky" },
			{ lang::Danish, "Opgrader affyringsbump" },
			{ lang::German, "Rückstoßelemente aufwerten" },
			{ lang::Greek, "Αναβάθμιση προσκρουστήρων ράμπας εκτόξευσης" },
			{ lang::English, "Upgrade Launch Bumpers" },
			{ lang::Spanish, "Potenciar reboteadores de lanzamiento" },
			{ lang::Finnish, "Uusi lähtöpuskurit" },
			{ lang::French, "Renforcement des champignons de tir" },
			{ lang::Hebrew, "Upgrade Launch Bumpers" },
			{ lang::Hungarian, "Korszerűsítse a fellövő gombákat" },
			{ lang::Italian, "Aggiorna i respingenti della rampa di lancio" },
			{ lang::Japanese, "エンジンをアップ\nグレードせよ!" },
			{ lang::Korean, "발사 범퍼 치기" },
			{ lang::Norwegian, "Oppgrader angrepsbumpere" },
			{ lang::Dutch, "Aanvalbumpers opwaarderen" },
			{ lang::Polish, "Wymień zderzaki ładowania" },
			{ lang::BrazilianPortuguese, "Atualizar os amortecedores de lançamento" },
			{ lang::Portuguese, "Reforço dos amortecedores de tiro" },
			{ lang::Russian, "Обновите Пусковые Бамперы" },
			{ lang::Swedish, "Uppgradera ramp-bumpers" },
			{ lang::Turkish, "Kalkış Tamponlarını Yenile" },
			{ lang::SimplifiedChinese, "升级发射缓冲器" },
			{ lang::TraditionalChinese, "改善啟動緩衝器" },
		},
	},
	{
		Msg::STRING224,
		{
			{ lang::Arabic, "Enter Black Hole" },
			{ lang::Czech, "Vstupte do černé díry" },
			{ lang::Danish, "Ind i det sorte hul" },
			{ lang::German, "Schwarzes Loch treffen" },
			{ lang::Greek, "Είσοδος στη μαύρη τρύπα" },
			{ lang::English, "Enter Black Hole" },
			{ lang::Spanish, "Entrar en el agujero negro" },
			{ lang::Finnish, "Siirry mustaan aukkoon" },
			{ lang::French, "Entrez dans le trou noir" },
			{ lang::Hebrew, "Enter Black Hole" },
			{ lang::Hungarian, "Lépjen be a fekete lyukba" },
			{ lang::Italian, "Entra nel buco nero" },
			{ lang::Japanese, "ブラック ホールへ突入!" },
			{ lang::Korean, "블랙홀에 들어감" },
			{ lang::Norwegian, "Gå inn i svart hull" },
			{ lang::Dutch, "Zwart gat ingaan" },
			{ lang::Polish, "Celuj w czarną dziurę" },
			{ lang::BrazilianPortuguese, "Entrar no buraco negro" },
			{ lang::Portuguese, "Entrar no buraco negro" },
			{ lang::Russian, "Войдите в Черную Дыру" },
			{ lang::Swedish, "Skjut in kulan i det svarta hålet" },
			{ lang::Turkish, "Kara Deliğe Gir" },
			{ lang::SimplifiedChinese, "进入黑洞" },
			{ lang::TraditionalChinese, "進入黑洞" },
		},
	},
	{
		Msg::STRING225,
		{
			{ lang::Arabic, "Black Hole Eliminated" },
			{ lang::Czech, "Černá díra zničena" },
			{ lang::Danish, "Sort hul elimineret" },
			{ lang::German, "Schwarzes Loch überwunden" },
			{ lang::Greek, "Η μαύρη τρύπα αντιμετωπίστηκε" },
			{ lang::English, "Black Hole Eliminated" },
			{ lang::Spanish, "Agujero negro eliminado" },
			{ lang::Finnish, "Musta aukko eliminoitu" },
			{ lang::French, "Trou noir supprimé" },
			{ lang::Hebrew, "Black Hole Eliminated" },
			{ lang::Hungarian, "Fekete lyuk közömbösítve" },
			{ lang::Italian, "Buco nero eliminato" },
			{ lang::Japanese, "ブラック ホール消滅!" },
			{ lang::Korean, "블랙홀 제거" },
			{ lang::Norwegian, "Svart hull er eliminert" },
			{ lang::Dutch, "Zwart gat geëlimineerd" },
			{ lang::Polish, "Czarna dziura zniszczona" },
			{ lang::BrazilianPortuguese, "Buraco negro destruído" },
			{ lang::Portuguese, "Buraco negro eliminado" },
			{ lang::Russian, "Черная Дыра Ликвидирована" },
			{ lang::Swedish, "Räddade från svart hål" },
			{ lang::Turkish, "Kara Delik Etkisizleştirildi" },
			{ lang::SimplifiedChinese, "消除的黑洞" },
			{ lang::TraditionalChinese, "黑洞消除" },
		},
	},
	{
		Msg::STRING226,
		{
			{ lang::Arabic, "Targets\nLeft: %d" },
			{ lang::Czech, "Cíle\nZbývá: %d" },
			{ lang::Danish, "Mål\nTilbage: %d" },
			{ lang::German, "Ziele\nSoll: %d" },
			{ lang::Greek, "Στόχοι\nΑπομένουν: %d" },
			{ lang::English, "Targets\nLeft: %d" },
			{ lang::Spanish, "Dianas\nRestantes: %d" },
			{ lang::Finnish, "Maalitauluja\njäljellä: %d" },
			{ lang::French, "Cibles\nrestantes : %d" },
			{ lang::Hebrew, "Targets\nLeft: %d" },
			{ lang::Hungarian, "Célpontok\nMaradt: %d" },
			{ lang::Italian, "Obiettivi\nRimasti: %d" },
			{ lang::Japanese, "ターゲット\n残り: %d" },
			{ lang::Korean, "표적\n남은 개수: %d" },
			{ lang::Norwegian, "Gjenstående\nmål: %d" },
			{ lang::Dutch, "Doelen\nresterend: %d" },
			{ lang::Polish, "Tarcze\nPozostało: %d" },
			{ lang::BrazilianPortuguese, "Alvos restantes:\n%d" },
			{ lang::Portuguese, "Alvos\nFaltam: %d" },
			{ lang::Russian, "Целей\nОсталось: %d" },
			{ lang::Swedish, "Träffa tavlor\n%d träffar kvar" },
			{ lang::Turkish, "Hedefler\nSol: %d" },
			{ lang::SimplifiedChinese, "目标\n剩余：%d" },
			{ lang::TraditionalChinese, "目標\n剩餘：%d" },
		},
	},
	{
		Msg::STRING227,
		{
			{ lang::Arabic, "Xenomorphs Destroyed" },
			{ lang::Czech, "Xenomorfové zničeni" },
			{ lang::Danish, "Xenomorfer destrueret" },
			{ lang::German, "Xenomorphe abgewehrt" },
			{ lang::Greek, "Καταστροφή των Xenomorphs" },
			{ lang::English, "Xenomorphs Destroyed" },
			{ lang::Spanish, "Xenomorfos destruidos" },
			{ lang::Finnish, "Xenomorphit tuhottu" },
			{ lang::French, "Xénomorphes détruits" },
			{ lang::Hebrew, "Xenomorphs Destroyed" },
			{ lang::Hungarian, "Idegen lények elpusztítva" },
			{ lang::Italian, "Distruzione di Xenomorphs" },
			{ lang::Japanese, "Xenomorphs を全滅!" },
			{ lang::Korean, "우주 괴물 격퇴" },
			{ lang::Norwegian, "Ødelagte fremmedformer" },
			{ lang::Dutch, "Xenomorfen vernietigd" },
			{ lang::Polish, "Ksenomorfy zniszczone" },
			{ lang::BrazilianPortuguese, "Xenomorfos destruídos" },
			{ lang::Portuguese, "Xenoformas destruídas" },
			{ lang::Russian, "Ксеноморфы уничтожены" },
			{ lang::Swedish, "Fredagstomtarna nedskjutna" },
			{ lang::Turkish, "Zenomorfs Yok Edildi" },
			{ lang::SimplifiedChinese, "Xenomorphs 被摧毁" },
			{ lang::TraditionalChinese, "變形損壞" },
		},
	},
	{
		Msg::STRING228,
		{
			{ lang::Arabic, "Upgrade Flags" },
			{ lang::Czech, "Vylepšete vlajky" },
			{ lang::Danish, "Opgrader flag" },
			{ lang::German, "Fahnen erneuern" },
			{ lang::Greek, "Αναβάθμιση σημαιών" },
			{ lang::English, "Upgrade Flags" },
			{ lang::Spanish, "Potenciar trampillas" },
			{ lang::Finnish, "Päivitä liput" },
			{ lang::French, "Mettre à niveau les indicateurs" },
			{ lang::Hebrew, "Upgrade Flags" },
			{ lang::Hungarian, "Korszerűsítse a zászlócélokat" },
			{ lang::Italian, "Aggiorna bandiere" },
			{ lang::Japanese, "フラグをアップグレードせよ!" },
			{ lang::Korean, "깃발 업그레이드" },
			{ lang::Norwegian, "Oppgraderte flagg" },
			{ lang::Dutch, "Poorten opwaarderen" },
			{ lang::Polish, "Wymień flagi" },
			{ lang::BrazilianPortuguese, "Atualizar as bandeiras" },
			{ lang::Portuguese, "Actualizar indicadores" },
			{ lang::Russian, "Улучшите Флаги" },
			{ lang::Swedish, "Uppgradera spinners" },
			{ lang::Turkish, "Fırıldakları Yenile" },
			{ lang::SimplifiedChinese, "升级旗帜" },
			{ lang::TraditionalChinese, "升級旗標" },
		},
	},
	{
		Msg::STRING229,
		{
			{ lang::Arabic, "Hyperspace Launch" },
			{ lang::Czech, "Odpálení do hyperprostoru" },
			{ lang::Danish, "Hyperspaceaffyring" },
			{ lang::German, "Hyperspace-Start" },
			{ lang::Greek, "Εκτόξευση στο υπερδιάστημα" },
			{ lang::English, "Hyperspace Launch" },
			{ lang::Spanish, "Lanzamiento al hiperespacio" },
			{ lang::Finnish, "Laukaisu hyperavaruuteen" },
			{ lang::French, "Lancement dans l'hyper-espace" },
			{ lang::Hebrew, "Hyperspace Launch" },
			{ lang::Hungarian, "Hipertér fellövés" },
			{ lang::Italian, "Lancio nell'iperspazio" },
			{ lang::Japanese, "ハイパースペースを狙え!" },
			{ lang::Korean, "하이퍼스페이스 작동" },
			{ lang::Norwegian, "Hyperrom-start" },
			{ lang::Dutch, "Hyperspacelancering" },
			{ lang::Polish, "Przejście w hiperprzestrzeń" },
			{ lang::BrazilianPortuguese, "Lançamento ao hiperespaço" },
			{ lang::Portuguese, "Lançamento para o hiperespaço" },
			{ lang::Russian, "Запуск в Гипер Пространство" },
			{ lang::Swedish, "Skjut upp kulan i hyperspace-hålan" },
			{ lang::Turkish, "Uzay Boşluğu Kalkışı" },
			{ lang::SimplifiedChinese, "超空发射" },
			{ lang::TraditionalChinese, "超空間啟動" },
		},
	},
	{
		Msg::STRING230,
		{
			{ lang::Arabic, "Survivors Rescued" },
			{ lang::Czech, "Trosečníci zachráněni" },
			{ lang::Danish, "Overlevende reddet" },
			{ lang::German, "Überlebende geborgen" },
			{ lang::Greek, "Οι επιζώντες διασώθηκαν" },
			{ lang::English, "Survivors Rescued" },
			{ lang::Spanish, "Supervivientes rescatados" },
			{ lang::Finnish, "Henkiinjääneet pelastettu" },
			{ lang::French, "Survivants" },
			{ lang::Hebrew, "Survivors Rescued" },
			{ lang::Hungarian, "A túlélők megmentve" },
			{ lang::Italian, "Sopravvissuti posti in salvo" },
			{ lang::Japanese, "生存者を救出!" },
			{ lang::Korean, "구출된 생존자" },
			{ lang::Norwegian, "Overlevende reddet" },
			{ lang::Dutch, "Overlevenden gered" },
			{ lang::Polish, "Rozbitkowie uratowani" },
			{ lang::BrazilianPortuguese, "Sobreviventes resgatados" },
			{ lang::Portuguese, "Sobreviventes salvos" },
			{ lang::Russian, "Выжившие Спасены" },
			{ lang::Swedish, "Överlevande räddade" },
			{ lang::Turkish, "Kazazedeler Kurtarıldı" },
			{ lang::SimplifiedChinese, "幸存者" },
			{ lang::TraditionalChinese, "解救生還者" },
		},
	},
	{
		Msg::STRING231,
		{
			{ lang::Arabic, "Aliens Repelled" },
			{ lang::Czech, "Vetřelci odpuzeni" },
			{ lang::Danish, "Fjender slået tilbage" },
			{ lang::German, "Fremdwesen abgewehrt" },
			{ lang::Greek, "Οι εξωγήινοι απωθήθηκαν" },
			{ lang::English, "Aliens Repelled" },
			{ lang::Spanish, "Amenaza exterior expulsada" },
			{ lang::Finnish, "Ufot torjuttu" },
			{ lang::French, "Extra-terrestres repoussés" },
			{ lang::Hebrew, "Aliens Repelled" },
			{ lang::Hungarian, "Az idegenek elűzve" },
			{ lang::Italian, "Alieni respinti" },
			{ lang::Japanese, "エイリアンを撃退!" },
			{ lang::Korean, "외계인 격퇴" },
			{ lang::Norwegian, "Romvesener slått tilbake" },
			{ lang::Dutch, "Aliens teruggedreven" },
			{ lang::Polish, "Obcy odstraszeni" },
			{ lang::BrazilianPortuguese, "Alienígenas expulsos" },
			{ lang::Portuguese, "Extraterrestres expulsos" },
			{ lang::Russian, "Инопланетяне Отбиты" },
			{ lang::Swedish, "No more pigs..." },
			{ lang::Turkish, "Yaratıklar Kovuldu" },
			{ lang::SimplifiedChinese, "驱逐外星人" },
			{ lang::TraditionalChinese, "驅逐外星人" },
		},
	},
	{
		Msg::STRING232,
		{
			{ lang::Arabic, "Hit Fuel Targets" },
			{ lang::Czech, "Trefte palivové cíle" },
			{ lang::Danish, "Ram brændstofmål" },
			{ lang::German, "Treibstoffobjekte treffen" },
			{ lang::Greek, "Σημαδέψτε τους στόχους καυσίμων" },
			{ lang::English, "Hit Fuel Targets" },
			{ lang::Spanish, "Golpear dianas de combustible" },
			{ lang::Finnish, "Osu polttoainekohteisiin" },
			{ lang::French, "Tirez sur les cibles de carburants" },
			{ lang::Hebrew, "Hit Fuel Targets" },
			{ lang::Hungarian, "Találja el az üzemanyag célpontokat" },
			{ lang::Italian, "Colpire il deposito di carburante" },
			{ lang::Japanese, "燃料ターゲットを狙え!" },
			{ lang::Korean, "연료 표적 맞히기" },
			{ lang::Norwegian, "Traff drivstoffmål" },
			{ lang::Dutch, "Raak brandstofdoelen" },
			{ lang::Polish, "Celuj w tarcze paliwa" },
			{ lang::BrazilianPortuguese, "Bater nos alvos de combustível" },
			{ lang::Portuguese, "Abater alvos de combustível" },
			{ lang::Russian, "Поражайте Топливные Цели" },
			{ lang::Swedish, "Träffa bränsletavlor" },
			{ lang::Turkish, "Yakıt Hedeflerini Vur" },
			{ lang::SimplifiedChinese, "击中燃料目标" },
			{ lang::TraditionalChinese, "命中燃料目標" },
		},
	},
	{
		Msg::STRING233,
		{
			{ lang::Arabic, "Remote Attack Bumper Hits\nLeft: %d" },
			{ lang::Czech, "Trefa do vzdálených útočných nárazníků\nZbývá: %d" },
			{ lang::Danish, "Træfninger af fjernangrebsbump\nTilbage: %d" },
			{ lang::German, "Rückstoßtreffer\nSoll: %d" },
			{ lang::Greek, "Βολές στους προσκρουστήρες πρώτης γραμμής\nΑπομένουν: %d" },
			{ lang::English, "Remote Attack Bumper Hits\nLeft: %d" },
			{ lang::Spanish, "Golpes en reboteadores de ataque remotos\nRestantes: %d" },
			{ lang::Finnish, "Osumia etähyökkäyspuskureihin\njäljellä: %d" },
			{ lang::French, "Tirs restants sur les champignons d'attaque\ndistants : %d" },
			{ lang::Hebrew, "Remote Attack Bumper Hits\nLeft: %d" },
			{ lang::Hungarian, "Támadógomba találatok\nMaradt: %d" },
			{ lang::Italian, "Colpi ai respingenti di prima linea\nRimasti: %d" },
			{ lang::Japanese, "リモート アタック バンパー ヒット\n残り: %d" },
			{ lang::Korean, "원거리 공격 범퍼 맞히기\n남은 횟수: %d" },
			{ lang::Norwegian, "Gjenstående fjernangreps-\nbumpertreff: %d" },
			{ lang::Dutch, "Treffers op afgelegen aanvalbumper\nresterend: %d" },
			{ lang::Polish, "Trafienia odległego zderzaka ataku\nPozostało: %d" },
			{ lang::BrazilianPortuguese, "Batidas nos amortecedores de ataque remotos\nrestantes: %d" },
			{ lang::Portuguese, "Tiros restantes nos amortecedores\nRestante: %d" },
			{ lang::Russian, "Осталось Попаданий по Дальним Бамперам Атаки: %d" },
			{ lang::Swedish, "Träffa höghöjds-bumpers\n%d träffar kvar" },
			{ lang::Turkish, "Uzaktan Vuruş Tamponları Vuruşu\nSol: %d" },
			{ lang::SimplifiedChinese, "远程攻击缓冲器击中\n剩余：%d" },
			{ lang::TraditionalChinese, "遙控攻擊緩衝器命中\n剩餘：%d" },
		},
	},
	{
		Msg::STRING234,
		{
			{ lang::Arabic, "Satellite Repaired" },
			{ lang::Czech, "Satelit opraven" },
			{ lang::Danish, "Satellit repareret" },
			{ lang::German, "Satellit repariert" },
			{ lang::Greek, "Ο δορυφόρος επισκευάστηκε" },
			{ lang::English, "Satellite Repaired" },
			{ lang::Spanish, "Satélite reparado" },
			{ lang::Finnish, "Satelliitti korjattu" },
			{ lang::French, "Satellite réparé" },
			{ lang::Hebrew, "Satellite Repaired" },
			{ lang::Hungarian, "A műhold kijavítva" },
			{ lang::Italian, "Satellite ripristinato" },
			{ lang::Japanese, "サテライトを修復!" },
			{ lang::Korean, "위성 복구" },
			{ lang::Norwegian, "Satellitt reparert" },
			{ lang::Dutch, "Satelliet is gerepareerd" },
			{ lang::Polish, "Satelita naprawiony" },
			{ lang::BrazilianPortuguese, "Satélite consertado" },
			{ lang::Portuguese, "Satélite reparado" },
			{ lang::Russian, "Спутник Отремонтирован" },
			{ lang::Swedish, "Satelliten reparerad" },
			{ lang::Turkish, "Uydu Onarıldı" },
			{ lang::SimplifiedChinese, "卫星已修好" },
			{ lang::TraditionalChinese, "人造衛星已修好" },
		},
	},
	{
		Msg::STRING235,
		{
			{ lang::Arabic, "Lane Passes\nLeft: %d" },
			{ lang::Czech, "Překročení pruhu\nZbývá: %d" },
			{ lang::Danish, "Banegennemløb\nTilbage: %d" },
			{ lang::German, "Bahndurchläufe\nSoll: %d" },
			{ lang::Greek, "Περάσματα από αεροδιάδρομο\nΑπομένουν: %d" },
			{ lang::English, "Lane Passes\nLeft: %d" },
			{ lang::Spanish, "Pasajes\nRestantes: %d" },
			{ lang::Finnish, "Osumia kaistoihin\njäljellä: %d" },
			{ lang::French, "Accès aux couloirs\nrestants : %d" },
			{ lang::Hebrew, "Lane Passes\nLeft: %d" },
			{ lang::Hungarian, "Folyosóátlépések\nMaradt: %d" },
			{ lang::Italian, "Fortezze del valico\nSinistra: %d" },
			{ lang::Japanese, "レーン通過\n残り: %d" },
			{ lang::Korean, "레인 통과 수\n남은 횟수: %d" },
			{ lang::Norwegian, "Gjenstående\nbanepasseringer: %d" },
			{ lang::Dutch, "Door baan spelen\nresterend: %d" },
			{ lang::Polish, "Przejścia po torach\nPozostało: %d" },
			{ lang::BrazilianPortuguese, "Passagens nas pistas\nrestantes: %d" },
			{ lang::Portuguese, "Acessos ao corredor\nRestante: %d" },
			{ lang::Russian, "Проходов Дорожек\nОсталось: %d" },
			{ lang::Swedish, "Träffa gångar\n%d träffar kvar" },
			{ lang::Turkish, "Kulvar Geçişleri\nSol: %d" },
			{ lang::SimplifiedChinese, "航道通行\n剩余次数：%d" },
			{ lang::TraditionalChinese, "巷道通行\n剩餘：%d" },
		},
	},
	{
		Msg::STRING236,
		{
			{ lang::Arabic, "Shoot Ball Up Fuel Chute" },
			{ lang::Czech, "Trefte míčkem palivovou klouzačku" },
			{ lang::Danish, "Skyd kugle op i brændstofslidske" },
			{ lang::German, "Kugel die Treibstofframpe hinaufschießen" },
			{ lang::Greek, "Στείλτε τη μπίλια στον αγωγό καυσίμων" },
			{ lang::English, "Shoot Ball Up Fuel Chute" },
			{ lang::Spanish, "Disparar la bola por el canal de combustible" },
			{ lang::Finnish, "Laukaise pallo polttoainekanavaan" },
			{ lang::French, "Tirez la bille dans la glissière de carburant" },
			{ lang::Hebrew, "Shoot Ball Up Fuel Chute" },
			{ lang::Hungarian, "Lője fel a golyót az üzemanyagcsatornán" },
			{ lang::Italian, "Lancia la pallina nell'iniettore del carburante" },
			{ lang::Japanese, "燃料シュートを狙え!" },
			{ lang::Korean, "연료 슈트에 구슬 집어넣기" },
			{ lang::Norwegian, "Skyt ball opp drivstoffsjakt" },
			{ lang::Dutch, "Bal de brandstofhelling op schieten" },
			{ lang::Polish, "Wprowadź kulkę w rynnę paliwa" },
			{ lang::BrazilianPortuguese, "Lançar a bola pela rampa de combustível" },
			{ lang::Portuguese, "Disparar a bola para o canal de combustível" },
			{ lang::Russian, "Запустите Шарик В Топливный Желоб" },
			{ lang::Swedish, "Skjut upp kulan i bränsledepån" },
			{ lang::Turkish, "Topu Yakıt Oluğuna Ateşle" },
			{ lang::SimplifiedChinese, "将球射到燃料斜槽" },
			{ lang::TraditionalChinese, "將球射上油道" },
		},
	},
	{
		Msg::STRING237,
		{
			{ lang::Arabic, "Survey Complete" },
			{ lang::Czech, "Průzkum dokončen" },
			{ lang::Danish, "Inspektion fuldført" },
			{ lang::German, "Studie abgeschlossen" },
			{ lang::Greek, "Η έρευνα ολοκληρώθηκε" },
			{ lang::English, "Survey Complete" },
			{ lang::Spanish, "Fin de supervisión" },
			{ lang::Finnish, "Tutkimus on valmis" },
			{ lang::French, "Inspection terminée" },
			{ lang::Hebrew, "Survey Complete" },
			{ lang::Hungarian, "A felmérés befejezve" },
			{ lang::Italian, "Verifica completa" },
			{ lang::Japanese, "調査完了!" },
			{ lang::Korean, "탐사 완료" },
			{ lang::Norwegian, "Undersøkelsen fullført" },
			{ lang::Dutch, "Onderzoek voltooid" },
			{ lang::Polish, "Przegląd zakończony" },
			{ lang::BrazilianPortuguese, "Pesquisa concluída" },
			{ lang::Portuguese, "Revisão concluída" },
			{ lang::Russian, "Обследование Завершено" },
			{ lang::Swedish, "Forskningsuppdraget genomfört" },
			{ lang::Turkish, "Araştırma Tamamlandı" },
			{ lang::SimplifiedChinese, "完成勘察" },
			{ lang::TraditionalChinese, "勘查完成" },
		},
	},
	{
		Msg::STRING238,
		{
			{ lang::Arabic, "Out Lane Passes\nLeft: %d" },
			{ lang::Czech, "Vystoupení z pruhu\nZbývá: %d" },
			{ lang::Danish, "Yderbanegennemløb\nTilbage: %d" },
			{ lang::German, "Ausbahndurchläufe\nSoll: %d" },
			{ lang::Greek, "Περάσματα σε εξωτερικό αεροδιάδρομο\nΑπομένουν: %d" },
			{ lang::English, "Out Lane Passes\nLeft: %d" },
			{ lang::Spanish, "Pasaje exterior\nRestantes: %d" },
			{ lang::Finnish, "Osumia ulkokaistoihin\njäljellä: %d" },
			{ lang::French, "Accès dans couloirs extérieurs\nrestants : %d" },
			{ lang::Hebrew, "Out Lane Passes\nLeft: %d" },
			{ lang::Hungarian, "Kilépő folyosóátlépések\nMaradt: %d" },
			{ lang::Italian, "Fortezze del valico esterno\nSinistra: %d" },
			{ lang::Japanese, "アウト レーン通過\n残り: %d" },
			{ lang::Korean, "외부 레인 통과\n남은 횟수: %d" },
			{ lang::Norwegian, "Gjenstående utbane-\npasseringer: %d" },
			{ lang::Dutch, "Door buitenbaan spelen\nresterend: %d" },
			{ lang::Polish, "Przejścia po torach zewn.\nPozostało: %d" },
			{ lang::BrazilianPortuguese, "Passagens pela pista de fora\nrestantes: %d" },
			{ lang::Portuguese, "Passagem exterior\nRestante: %d" },
			{ lang::Russian, "Проходов Внешних Дорожек Осталось: %d" },
			{ lang::Swedish, "Utgångar\n%d kvar" },
			{ lang::Turkish, "Dış Kulvar Geçişleri\nSol: %d" },
			{ lang::SimplifiedChinese, "出口航道通行\n剩余次数：%d" },
			{ lang::TraditionalChinese, "外巷道通行\n剩餘：%d" },
		},
	},
	{
		Msg::STRING239,
		{
			{ lang::Arabic, "Doomsday Machine Destroyed" },
			{ lang::Czech, "Stroj zkázy zničen" },
			{ lang::Danish, "Dommedagsmaskine destrueret" },
			{ lang::German, "Schwadron abgewehrt" },
			{ lang::Greek, "Η συσκευή ολοκληρωτικής καταστροφής απενεργοποιήθηκε" },
			{ lang::English, "Doomsday Machine Destroyed" },
			{ lang::Spanish, "Máquina catastrófica destruida" },
			{ lang::Finnish, "Helvetinkone tuhottu" },
			{ lang::French, "Machine de la fin du monde détruite" },
			{ lang::Hebrew, "Doomsday Machine Destroyed" },
			{ lang::Hungarian, "A gyilkológép elpusztítva" },
			{ lang::Italian, "Macchina della fine del mondo distrutta" },
			{ lang::Japanese, "ドゥームズデイ マシンを破壊!" },
			{ lang::Korean, "핵무기 파괴" },
			{ lang::Norwegian, "Helvetesmaskinen ødelagt" },
			{ lang::Dutch, "Doomsday Machine vernietigd" },
			{ lang::Polish, "Maszyna zagłady zniszczona" },
			{ lang::BrazilianPortuguese, "Máquina do Juízo Final destruída" },
			{ lang::Portuguese, "Máquina Apocalíptica destruída" },
			{ lang::Russian, "Машина Судного Дня Уничтожена" },
			{ lang::Swedish, "Domedagsmaskinen nedskjuten" },
			{ lang::Turkish, "Kıyamet Makinesi Yok Edildi" },
			{ lang::SimplifiedChinese, "摧毁了世界末日机器" },
			{ lang::TraditionalChinese, "世界末日機毀損" },
		},
	},
	{
		Msg::STRING240,
		{
			{ lang::Arabic, "Roll Flags: %d" },
			{ lang::Czech, "Spuštěné vlajky: %d" },
			{ lang::Danish, "Rulleflag: %d" },
			{ lang::German, "Drehfahnen: %d" },
			{ lang::Greek, "Σημαίες περιστροφής: %d" },
			{ lang::English, "Roll Flags: %d" },
			{ lang::Spanish, "Voltear trampillas: %d" },
			{ lang::Finnish, "Silmukan liput: %d" },
			{ lang::French, "Roulement des indicateurs : %d" },
			{ lang::Hebrew, "Roll Flags: %d" },
			{ lang::Hungarian, "%d pördítés" },
			{ lang::Italian, "Avvolgi bandiere: %d" },
			{ lang::Japanese, "ロール フラグ数: %d" },
			{ lang::Korean, "깃발 회전 수: %d" },
			{ lang::Norwegian, "Rulleflagg: %d" },
			{ lang::Dutch, "Poorten ronddraaien: %d" },
			{ lang::Polish, "Zwijanie flag: %d" },
			{ lang::BrazilianPortuguese, "Rolar as bandeiras: %d" },
			{ lang::Portuguese, "Rodar indicadores: %d" },
			{ lang::Russian, "Крутите Флаги: %d" },
			{ lang::Swedish, "Träffa spinners\n%d varv kvar" },
			{ lang::Turkish, "Fırıldak Dönüşü: %d" },
			{ lang::SimplifiedChinese, "滚动旗帜：%d" },
			{ lang::TraditionalChinese, "捲動旗標：%d" },
		},
	},
	{
		Msg::STRING241,
		{
			{ lang::Arabic, "Hit Space Warp Rollover" },
			{ lang::Czech, "Trefte převrácení vesmírného přesunu" },
			{ lang::Danish, "Ram rumforskydningsfornyelse" },
			{ lang::German, "Warpdreher treffen" },
			{ lang::Greek, "Βολή για χρονοστρέβλωση" },
			{ lang::English, "Hit Space Warp Rollover" },
			{ lang::Spanish, "Golpear luz de salto en el espacio" },
			{ lang::Finnish, "Osu avaruushyppykytkimeen" },
			{ lang::French, "Tirez sur le roulement de distorsion spatiale" },
			{ lang::Hebrew, "Hit Space Warp Rollover" },
			{ lang::Hungarian, "Guruljon át a térugró aknán" },
			{ lang::Italian, "Colpire la gondola di curvatura temporale" },
			{ lang::Japanese, "スペース ワープ ロールオーバーを狙え!" },
			{ lang::Korean, "공간 이동 통로 맞히기" },
			{ lang::Norwegian, "Traff rulle for Romsprang" },
			{ lang::Dutch, "Raak Space Warp-rollover" },
			{ lang::Polish, "Celuj w wywrotkę zakrzywienia przestrzeni" },
			{ lang::BrazilianPortuguese, "Acerte o Space Warp Rollover" },
			{ lang::Portuguese, "Acertar no rotativo de dobra espacial" },
			{ lang::Russian, "Попадите В Искривление Пространства" },
			{ lang::Swedish, "Träffa rymdsensor" },
			{ lang::Turkish, "Uzay Sıçrama Yuvarlağını Vur" },
			{ lang::SimplifiedChinese, "击中太空扭曲得分" },
			{ lang::TraditionalChinese, "命中空間扭曲滾轉" },
		},
	},
	{
		Msg::STRING242,
		{
			{ lang::Arabic, "Plague Eliminated" },
			{ lang::Czech, "Epidemie potlačena" },
			{ lang::Danish, "Pest udryddet" },
			{ lang::German, "Seuche eliminiert" },
			{ lang::Greek, "Η μάστιγα αντιμετωπίστηκε" },
			{ lang::English, "Plague Eliminated" },
			{ lang::Spanish, "Plaga eliminada" },
			{ lang::Finnish, "Rutto hävitetty" },
			{ lang::French, "Peste éliminée" },
			{ lang::Hebrew, "Plague Eliminated" },
			{ lang::Hungarian, "Pestis leküzdve" },
			{ lang::Italian, "Peste debellata" },
			{ lang::Japanese, "疫病は撲滅!" },
			{ lang::Korean, "우주 재앙 격퇴" },
			{ lang::Norwegian, "Pesten eliminert" },
			{ lang::Dutch, "Plaag geëlimineerd" },
			{ lang::Polish, "Plaga zażegnana" },
			{ lang::BrazilianPortuguese, "Peste eliminada" },
			{ lang::Portuguese, "Praga extinta" },
			{ lang::Russian, "Чума Ликвидирована" },
			{ lang::Swedish, "Räddade från pesten" },
			{ lang::Turkish, "Veba Atlatıldı" },
			{ lang::SimplifiedChinese, "消除灾难" },
			{ lang::TraditionalChinese, "消除災禍" },
		},
	},
	{
		Msg::STRING243,
		{
			{ lang::Arabic, "Hit Yellow Wormhole" },
			{ lang::Czech, "Trefte žlutou červí díru" },
			{ lang::Danish, "Ram gult ormehul" },
			{ lang::German, "Gelbes Wurmloch treffen" },
			{ lang::Greek, "Βολή στην κίτρινη διαστημική σήραγγα" },
			{ lang::English, "Hit Yellow Wormhole" },
			{ lang::Spanish, "Golpear el túnel espacial amarillo" },
			{ lang::Finnish, "Osu keltaiseen madonreikään" },
			{ lang::French, "Visez le repaire jaune du ver géant" },
			{ lang::Hebrew, "Hit Yellow Wormhole" },
			{ lang::Hungarian, "Cél a sárga féreglyuk" },
			{ lang::Italian, "Colpire il tunnel spaziale giallo" },
			{ lang::Japanese, "イエロー ワームホールを狙え!" },
			{ lang::Korean, "노란 웜홀 맞히기" },
			{ lang::Norwegian, "Traff gult ormebol" },
			{ lang::Dutch, "Raak geel wormhole" },
			{ lang::Polish, "Celuj w żółty tunel" },
			{ lang::BrazilianPortuguese, "Acerte a fenda espacial amarela" },
			{ lang::Portuguese, "Abater túnel espacial amarelo" },
			{ lang::Russian, "Попадание в Желтую червоточину" },
			{ lang::Swedish, "Skjut in kulan i gult maskhål" },
			{ lang::Turkish, "Sarı Solucan Deliğini Vur" },
			{ lang::SimplifiedChinese, "击中黄色旋涡式星体" },
			{ lang::TraditionalChinese, "命中黃色蟲孔" },
		},
	},
	{
		Msg::STRING244,
		{
			{ lang::Arabic, "Hit Red Wormhole" },
			{ lang::Czech, "Trefte červenou červí díru" },
			{ lang::Danish, "Ram rødt ormehul" },
			{ lang::German, "Rotes Wurmloch treffen" },
			{ lang::Greek, "Βολή στην κόκκινη διαστημική σήραγγα" },
			{ lang::English, "Hit Red Wormhole" },
			{ lang::Spanish, "Golpear el túnel espacial rojo" },
			{ lang::Finnish, "Osu punaiseen madonreikään" },
			{ lang::French, "Visez le repaire rouge du ver géant" },
			{ lang::Hebrew, "Hit Red Wormhole" },
			{ lang::Hungarian, "Cél a piros féreglyuk" },
			{ lang::Italian, "Colpire il tunnel spaziale rosso" },
			{ lang::Japanese, "レッド ワームホールを狙て!" },
			{ lang::Korean, "빨간 웜홀 맞히기" },
			{ lang::Norwegian, "Traff rødt ormebol" },
			{ lang::Dutch, "Raak rood wormhole" },
			{ lang::Polish, "Celuj w czerwony tunel" },
			{ lang::BrazilianPortuguese, "Acerte a fenda espacial vermelha" },
			{ lang::Portuguese, "Abater túnel espacial vermelho" },
			{ lang::Russian, "Попадание в Красную червоточину" },
			{ lang::Swedish, "Skjut in kulan i rött maskhål" },
			{ lang::Turkish, "Kırmızı Solucan Deliğini Vur" },
			{ lang::SimplifiedChinese, "击中红色旋涡式星体" },
			{ lang::TraditionalChinese, "命中紅色蟲孔" },
		},
	},
	{
		Msg::STRING245,
		{
			{ lang::Arabic, "Hit Green Wormhole" },
			{ lang::Czech, "Trefte zelenou červí díru" },
			{ lang::Danish, "Ram grønt ormehul" },
			{ lang::German, "Grünes Wurmloch treffen" },
			{ lang::Greek, "Βολή στην πράσινη διαστημική σήραγγα" },
			{ lang::English, "Hit Green Wormhole" },
			{ lang::Spanish, "Golpear el túnel espacial verde" },
			{ lang::Finnish, "Osu vihreään madonreikään" },
			{ lang::French, "Visez le repaire vert du ver géant" },
			{ lang::Hebrew, "Hit Green Wormhole" },
			{ lang::Hungarian, "Cél a zöld féreglyuk" },
			{ lang::Italian, "Colpire il tunnel spaziale verde" },
			{ lang::Japanese, "グリーン ワームホールを狙て!" },
			{ lang::Korean, "녹색 웜홀 맞히기" },
			{ lang::Norwegian, "Traff grønt ormebol" },
			{ lang::Dutch, "Raak groen wormhole" },
			{ lang::Polish, "Celuj w zielony tunel" },
			{ lang::BrazilianPortuguese, "Acerte a fenda espacial verde" },
			{ lang::Portuguese, "Abater túnel espacial verde" },
			{ lang::Russian, "Попадание в Зеленую червоточину" },
			{ lang::Swedish, "Skjut in kulan i grönt maskhål" },
			{ lang::Turkish, "Yeşil Solucan Deliğini Vur" },
			{ lang::SimplifiedChinese, "击中绿色旋涡式星体" },
			{ lang::TraditionalChinese, "命中綠色蟲孔" },
		},
	},
	{
		Msg::STRING246,
		{
			{ lang::Arabic, "Plans Recovered" },
			{ lang::Czech, "Plány zachráněny" },
			{ lang::Danish, "Planer reddet" },
			{ lang::German, "Pläne geborgen" },
			{ lang::Greek, "Τα σχέδια ανακτήθηκαν" },
			{ lang::English, "Plans Recovered" },
			{ lang::Spanish, "Planes recuperados" },
			{ lang::Finnish, "Suunnitelmat saatu takaisin" },
			{ lang::French, "Plans récupérés" },
			{ lang::Hebrew, "Plans Recovered" },
			{ lang::Hungarian, "Sikerült a terveket visszaszerezni" },
			{ lang::Italian, "Piani recuperati" },
			{ lang::Japanese, "計画書奪回!" },
			{ lang::Korean, "설계도 복구" },
			{ lang::Norwegian, "Fant planer" },
			{ lang::Dutch, "Plannen teruggevonden" },
			{ lang::Polish, "Plany odzyskane" },
			{ lang::BrazilianPortuguese, "Planos recuperados" },
			{ lang::Portuguese, "Planos recuperados" },
			{ lang::Russian, "Проекты Восстановлены" },
			{ lang::Swedish, "Ritningarna räddade" },
			{ lang::Turkish, "Planlar Kurtarıldı" },
			{ lang::SimplifiedChinese, "计划已恢复" },
			{ lang::TraditionalChinese, "回復計劃" },
		},
	},
	{
		Msg::STRING247,
		{
			{ lang::Arabic, "Rebound Hits\nLeft: %d" },
			{ lang::Czech, "Odražené trefy\nZbývá: %d" },
			{ lang::Danish, "Rikochettræfninger\nTilbage: %d" },
			{ lang::German, "Abpralltreffer\nSoll: %d" },
			{ lang::Greek, "Αναπηδήσεις\nΑπομένουν: %d" },
			{ lang::English, "Rebound Hits\nLeft: %d" },
			{ lang::Spanish, "Golpes a las bandas de rebote\nRestantes: %d" },
			{ lang::Finnish, "Palautuslyöntejä\njäljellä: %d" },
			{ lang::French, "Tirs sur élastiques\nrestants : %d" },
			{ lang::Hebrew, "Rebound Hits\nLeft: %d" },
			{ lang::Hungarian, "Csúzlitalálatok\nMaradt: %d" },
			{ lang::Italian, "'Rebound Hits'\nRimasti: %d" },
			{ lang::Japanese, "リバウンド ヒット\n残り: %d" },
			{ lang::Korean, "리바운드 맞히기\n남은 횟수: %d" },
			{ lang::Norwegian, "Trampoline-\ntreff: %d" },
			{ lang::Dutch, "Reboundtreffers\nresterend: %d" },
			{ lang::Polish, "Trafienia odbicia\nPozostało: %d" },
			{ lang::BrazilianPortuguese, "Batidas de ricochete\nrestantes: %d" },
			{ lang::Portuguese, "Ricochetes\nRestante: %d" },
			{ lang::Russian, "Осталось Попаданий по Отскоку: %d" },
			{ lang::Swedish, "Träffa rebounds\n%d träffar kvar" },
			{ lang::Turkish, "Yay Vuruşları\nSol: %d" },
			{ lang::SimplifiedChinese, "弹回击中\n剩余次数：%d" },
			{ lang::TraditionalChinese, "彈回命中\n剩餘：%d" },
		},
	},
	{
		Msg::STRING248,
		{
			{ lang::Arabic, "Hit Hyperspace Chute or Launch Ramp" },
			{ lang::Czech, "Trefte hyperprostorovou klouzačku nebo odpalovací rampu" },
			{ lang::Danish, "Ram Hyperspaceslidske eller affyringsrampe" },
			{ lang::German, "Hyperspace- oder Startrampe treffen" },
			{ lang::Greek, "Βολή στον αγωγό υπερδιαστήματος ή στη ράμπα εκτόξευσης" },
			{ lang::English, "Hit Hyperspace Chute or Launch Ramp" },
			{ lang::Spanish, "Golpear el canal hiperespacial o la rampa de lanzamiento" },
			{ lang::Finnish, "Osu hyperavaruuteen tai laukaisurampille" },
			{ lang::French, "Visez le gouffre de l'hyper-espace ou la rampe de lancement" },
			{ lang::Hebrew, "Hit Hyperspace Chute or Launch Ramp" },
			{ lang::Hungarian, "Cél a hipertér csatorna és kilövőállás" },
			{ lang::Italian, "Colpire l'iniettore iperspaziale o la rampa di lancio" },
			{ lang::Japanese, "ハイパースペース シュートか発射ランプを狙え!" },
			{ lang::Korean, "하이퍼스페이스 슈트 또는 발사대 맞히기" },
			{ lang::Norwegian, "Traff Hyperromsjakt eller utskytingsrampe" },
			{ lang::Dutch, "Raak hyperspacehelling of lanceerplatform" },
			{ lang::Polish, "Celuj w rynnę hiperprzestrzeni lub pomost ładowania" },
			{ lang::BrazilianPortuguese, "Acerte a rampa de hiperespaço ou de lançamento" },
			{ lang::Portuguese, "Acertar no canal hiperespacial ou na rampa de lançamento" },
			{ lang::Russian, "Попадите в Гипер Пространственный Желоб или Стартовую Рампу" },
			{ lang::Swedish, "Skjut upp kulan i hyperspace-hålan eller i rampen" },
			{ lang::Turkish, "Uzay Boşluğu Oluğu ya da Kalkış Pistini Vur" },
			{ lang::SimplifiedChinese, "击中超空间斜槽或发射坡道" },
			{ lang::TraditionalChinese, "命中超空間滑道或啟動斜道" },
		},
	},
	{
		Msg::STRING249,
		{
			{ lang::Arabic, "Drop Target Hits\nLeft: %d" },
			{ lang::Czech, "Trefa zničení cíle\nZbývá: %d" },
			{ lang::Danish, "Dykkende måltræfninger\nTilbage: %d" },
			{ lang::German, "Treffer Zielkategorie 1\nSoll: %d" },
			{ lang::Greek, "Βολές σε βυθιζόμενους στόχους\nΑπομένουν: %d" },
			{ lang::English, "Drop Target Hits\nLeft: %d" },
			{ lang::Spanish, "Golpes a las dianas abatibles\nRestantes: %d" },
			{ lang::Finnish, "Osumia pudotusmaaleihin\njäljellä: %d" },
			{ lang::French, "Tirs sur cibles automatiques\nrestants : %d" },
			{ lang::Hebrew, "Drop Target Hits\nLeft: %d" },
			{ lang::Hungarian, "Dominócélok kilövése\nMaradt: %d" },
			{ lang::Italian, "Obiettivi da abbattere\nRimasti: %d" },
			{ lang::Japanese, "ドロップ ターゲット ヒット\n残り: %d" },
			{ lang::Korean, "낙하 표적 맞히기\n남은 횟수: %d" },
			{ lang::Norwegian, "Gjenstående trufne\nbombemål: %d" },
			{ lang::Dutch, "Treffers op drop targets\nresterend: %d" },
			{ lang::Polish, "Trafienia tarcz strącania\nPozostało: %d" },
			{ lang::BrazilianPortuguese, "Batidas nos alvos tipo Drop\nrestantes: %d" },
			{ lang::Portuguese, "Tiros nos alvos automáticos\nRestantes: %d" },
			{ lang::Russian, "Осталось Попаданий по Падающим Целям: %d" },
			{ lang::Swedish, "Träffa multi-, medalj-, bonus- eller uppdragstavlor\n%d träffar kvar" },
			{ lang::Turkish, "Hedef Bırakma Vuruşları\nSol: %d" },
			{ lang::SimplifiedChinese, "丢弃目标击中\n剩余次数：%d" },
			{ lang::TraditionalChinese, "命中棄置目標\n剩餘：%d" },
		},
	},
	{
		Msg::STRING250,
		{
			{ lang::Arabic, "Spot Target Hits\nLeft: %d" },
			{ lang::Czech, "Trefa zobrazeného cíle\nZbývá: %d" },
			{ lang::Danish, "Tilfældige måltræfninger\nTilbage: %d" },
			{ lang::German, "Treffer Zielkategorie 2\nSoll: %d" },
			{ lang::Greek, "Βολές σε σταθερούς στόχους\nΑπομένουν: %d" },
			{ lang::English, "Spot Target Hits\nLeft: %d" },
			{ lang::Spanish, "Golpes a las dianas puntuales\nRestantes: %d" },
			{ lang::Finnish, "Osumia täplämaaleihin\njäljellä: %d" },
			{ lang::French, "Tirs sur cibles de points\nrestants : %d" },
			{ lang::Hebrew, "Spot Target Hits\nLeft: %d" },
			{ lang::Hungarian, "Vegyes célpontok kilövése\nMaradt: %d" },
			{ lang::Italian, "Vedi obiettivi\nRimasti: %d" },
			{ lang::Japanese, "スポット ターゲット ヒット\n残り: %d" },
			{ lang::Korean, "지정한 표적 맞히기\n남은 횟수: %d" },
			{ lang::Norwegian, "Gjenstående\nblinkmåltreff: %d" },
			{ lang::Dutch, "Treffers op schietschijfdoelen\nresterend: %d" },
			{ lang::Polish, "Trafienia tarcz punktowych\nPozostało: %d" },
			{ lang::BrazilianPortuguese, "Batidas nos alvos tipo Spot\nrestantes: %d" },
			{ lang::Portuguese, "Tiros nos alvos de pontuação\nRestante: %d" },
			{ lang::Russian, "Осталось Попаданий по Точечным Целям: %d" },
			{ lang::Swedish, "Träffa returtavlor\n%d träffar kvar" },
			{ lang::Turkish, "Gösterme Hedef Vuruşları\nSol: %d" },
			{ lang::SimplifiedChinese, "发现目标击中\n剩余次数：%d" },
			{ lang::TraditionalChinese, "命中偵查目標\n剩餘：%d" },
		},
	},
	{
		Msg::STRING251,
		{
			{ lang::Arabic, "Lanes Passes\nLeft: %d" },
			{ lang::Czech, "Překročení pruhu\nZbývá: %d" },
			{ lang::Danish, "Baner gennemløbet\nTilbage: %d" },
			{ lang::German, "Bahndurchläufe\nSoll: %d" },
			{ lang::Greek, "Περάσματα από αεροδιάδρομο\nΑπομένουν: %d" },
			{ lang::English, "Lanes Passes\nLeft: %d" },
			{ lang::Spanish, "Pasajes\nRestantes: %d" },
			{ lang::Finnish, "Osumia kaistoihin\njäljellä: %d" },
			{ lang::French, "Accès dans couloirs\nrestants : %d" },
			{ lang::Hebrew, "Lanes Passes\nLeft: %d" },
			{ lang::Hungarian, "Belépés a folyosóba\nMaradt: %d" },
			{ lang::Italian, "Fortezze del valico\nSinistra: %d" },
			{ lang::Japanese, "レーン通過\n残り: %d" },
			{ lang::Korean, "레인 통과 수\n남은 개수: %d" },
			{ lang::Norwegian, "Gjenstående\nbanepasseringer: %d" },
			{ lang::Dutch, "Door banen spelen\nresterend: %d" },
			{ lang::Polish, "Przejścia po torach\nPozostało: %d" },
			{ lang::BrazilianPortuguese, "Passagens de pistas\nrestantes: %d" },
			{ lang::Portuguese, "Acessos ao corredor\nRestante: %d" },
			{ lang::Russian, "Проходов Дорожек Осталось: %d" },
			{ lang::Swedish, "Träffa gångar\n%d träffar kvar" },
			{ lang::Turkish, "Kulvar Geçişleri\nSol: %d" },
			{ lang::SimplifiedChinese, "航道通行\n剩余次数：%d" },
			{ lang::TraditionalChinese, "巷道通行\n剩餘：%d" },
		},
	},
	{
		Msg::STRING252,
		{
			{ lang::Arabic, "Shoot Ball Up Fuel Chute" },
			{ lang::Czech, "Trefte míčkem palivovou klouzačku" },
			{ lang::Danish, "Skyd kugle op i brændstofslidske" },
			{ lang::German, "Kugel die Treibstofframpe hinaufschießen" },
			{ lang::Greek, "Στείλτε τη μπίλια στον αγωγό καυσίμων" },
			{ lang::English, "Shoot Ball Up Fuel Chute" },
			{ lang::Spanish, "Disparar la bola por el canal de combustible" },
			{ lang::Finnish, "Laukaise pallo polttoainekanavaan" },
			{ lang::French, "Tirez la bille dans la glissière de carburant" },
			{ lang::Hebrew, "Shoot Ball Up Fuel Chute" },
			{ lang::Hungarian, "Lője fel a golyót az üzemanyagcsatornán" },
			{ lang::Italian, "Lancia la pallina nell'iniettore del carburante" },
			{ lang::Japanese, "燃料シュートを狙え!" },
			{ lang::Korean, "연료 슈트에 구슬 집어넣기" },
			{ lang::Norwegian, "Skyt ball opp drivstoffsjakt" },
			{ lang::Dutch, "Bal de brandstofhelling op schieten" },
			{ lang::Polish, "Wprowadź kulkę w rynnę paliwa" },
			{ lang::BrazilianPortuguese, "Lançar a bola pela rampa de combustível" },
			{ lang::Portuguese, "Disparar a bola para o canal de combustível" },
			{ lang::Russian, "Запустите Шарик В Топливный Желоб" },
			{ lang::Swedish, "Skjut upp kulan i bränsledepån" },
			{ lang::Turkish, "Topu Yakıt Oluğuna Ateşle" },
			{ lang::SimplifiedChinese, "将球射到燃料斜槽" },
			{ lang::TraditionalChinese, "將球射上油道" },
		},
	},
	{
		Msg::STRING253,
		{
			{ lang::Arabic, "Hit Launch Ramp" },
			{ lang::Czech, "Trefte odpalovací rampu" },
			{ lang::Danish, "Ram affyringsrampe" },
			{ lang::German, "Startrampe treffen" },
			{ lang::Greek, "Βολή στη ράμπα εκτόξευσης" },
			{ lang::English, "Hit Launch Ramp" },
			{ lang::Spanish, "Golpear la rampa de lanzamiento" },
			{ lang::Finnish, "Osu laukaisuramppiin" },
			{ lang::French, "Visez la rampe de lancement" },
			{ lang::Hebrew, "Hit Launch Ramp" },
			{ lang::Hungarian, "Találja el a kilövőállást" },
			{ lang::Italian, "Colpire la rampa di lancio" },
			{ lang::Japanese, "発射ランプを狙え!" },
			{ lang::Korean, "발사대 맞히기" },
			{ lang::Norwegian, "Truffet utskytingsrampe" },
			{ lang::Dutch, "Raak lanceerplatform" },
			{ lang::Polish, "Celuj w pomost ładowania" },
			{ lang::BrazilianPortuguese, "Acerte na rampa de lançamento" },
			{ lang::Portuguese, "Acertar na rampa de lançamento" },
			{ lang::Russian, "Попадите в Стартовую Рампу" },
			{ lang::Swedish, "Skjut upp kulan i rampen" },
			{ lang::Turkish, "Kalkış Pisti Vur" },
			{ lang::SimplifiedChinese, "击中发射坡道" },
			{ lang::TraditionalChinese, "命中啟動斜道" },
		},
	},
	{
		Msg::STRING254,
		{
			{ lang::Arabic, "Hit Flags" },
			{ lang::Czech, "Trefte vlajky" },
			{ lang::Danish, "Ram flag" },
			{ lang::German, "Fahnen treffen" },
			{ lang::Greek, "Βολή στις σημαίες" },
			{ lang::English, "Hit Flags" },
			{ lang::Spanish, "Golpear las trampillas" },
			{ lang::Finnish, "Osu lippuihin" },
			{ lang::French, "Tirez sur les drapeaux" },
			{ lang::Hebrew, "Hit Flags" },
			{ lang::Hungarian, "Találja el a zászlócélokat" },
			{ lang::Italian, "Colpire bandiere" },
			{ lang::Japanese, "フラグを狙え!" },
			{ lang::Korean, "깃발 맞히기" },
			{ lang::Norwegian, "Traff flagg" },
			{ lang::Dutch, "Raak poorten" },
			{ lang::Polish, "Celuj we flagi" },
			{ lang::BrazilianPortuguese, "Acerte nas bandeiras" },
			{ lang::Portuguese, "Acertar nas bandeiras" },
			{ lang::Russian, "Попадите в Флаги" },
			{ lang::Swedish, "Träffa spinners" },
			{ lang::Turkish, "Fırıldak Vur" },
			{ lang::SimplifiedChinese, "击中旗帜" },
			{ lang::TraditionalChinese, "命中旗標" },
		},
	},
	{
		Msg::STRING255,
		{
			{ lang::Arabic, "Hit Worm Hole" },
			{ lang::Czech, "Trefte červí díru" },
			{ lang::Danish, "Ram ormehul" },
			{ lang::German, "Wurmloch treffen" },
			{ lang::Greek, "Βολή στη διαστημική σήραγγα" },
			{ lang::English, "Hit Worm Hole" },
			{ lang::Spanish, "Golpear el túnel espacial" },
			{ lang::Finnish, "Osu madonreikään" },
			{ lang::French, "Visez le repaire du ver" },
			{ lang::Hebrew, "Hit Worm Hole" },
			{ lang::Hungarian, "Találjon el egy féreglyukat" },
			{ lang::Italian, "Colpire il tunnel spaziale" },
			{ lang::Japanese, "ワームホールを狙え!" },
			{ lang::Korean, "웜홀 맞히기" },
			{ lang::Norwegian, "Traff ormebol" },
			{ lang::Dutch, "Raak wormhole" },
			{ lang::Polish, "Celuj w tunel czasoprzestrzenny" },
			{ lang::BrazilianPortuguese, "Acerte na fenda espacial" },
			{ lang::Portuguese, "Acertar no túnel espacial" },
			{ lang::Russian, "Попадите в Червоточину" },
			{ lang::Swedish, "Skjut in kulan i ett maskhål" },
			{ lang::Turkish, "Solucan Deliği Vur" },
			{ lang::SimplifiedChinese, "击中虫孔" },
			{ lang::TraditionalChinese, "命中蟲孔" },
		},
	},
	{
		Msg::STRING256,
		{
			{ lang::Arabic, "Hyperspace Chute to end Maelstrom" },
			{ lang::Czech, "Hyperprostorová klouzačka, ukončující hvězdný vír" },
			{ lang::Danish, "Hyperspaceslidske for at stoppe hvirvelstrøm" },
			{ lang::German, "Maelstrom beenden mit Hyperspace-Rampe" },
			{ lang::Greek, "Αγωγός υπερδιαστήματος για έξοδο από δίνη" },
			{ lang::English, "Hyperspace Chute to end Maelstrom" },
			{ lang::Spanish, "Canal hiperespacial para terminar vorágine" },
			{ lang::Finnish, "Lopeta Maelstrom osumalla hyperavaruusreittiin" },
			{ lang::French, "Gouffre de l'hyper-espace pour terminer Maelström" },
			{ lang::Hebrew, "Hyperspace Chute to end Maelstrom" },
			{ lang::Hungarian, "Maelström megfékezéséhez fel a hipertér csatornán" },
			{ lang::Italian, "Iniettore iperspaziale per uscire dal vortice" },
			{ lang::Japanese, "メールストロームを消滅させるにはハイパー スペース シュートを狙え!" },
			{ lang::Korean, "하이퍼스페이스 슈트를 맞혀 소용돌이 제거" },
			{ lang::Norwegian, "Hyperromsjakt for å avslutte malstrøm" },
			{ lang::Dutch, "Hyperspacehelling om Maelstrom te beëindigen" },
			{ lang::Polish, "Rynna hiperprzestrzeni zamyka Wir" },
			{ lang::BrazilianPortuguese, "Rampa do hiperespaço para acabar com o redemoinho" },
			{ lang::Portuguese, "Canal hiperespacial para terminar o redemoinho" },
			{ lang::Russian, "Гипер Пространственный Желоб Закончит Водоворот" },
			{ lang::Swedish, "Avsluta uppdraget Maelstrom genom att skjuta upp kulan i hyperspace-hålan" },
			{ lang::Turkish, "Girdabı bitirmek için Uzay Boşluğu Oluğu" },
			{ lang::SimplifiedChinese, "进入超空间斜槽，结束大旋涡" },
			{ lang::TraditionalChinese, "超空間滑道以終止動亂" },
		},
	},
	{
		Msg::STRING257,
		{
			{ lang::Arabic, "pinball.mid" },
			{ lang::Czech, "pinball.mid" },
			{ lang::Danish, "pinball.mid" },
			{ lang::German, "pinball.mid" },
			{ lang::Greek, "pinball.mid" },
			{ lang::English, "pinball.mid" },
			{ lang::Spanish, "pinball.mid" },
			{ lang::Finnish, "pinball.mid" },
			{ lang::French, "pinball.mid" },
			{ lang::Hebrew, "pinball.mid" },
			{ lang::Hungarian, "pinball.mid" },
			{ lang::Italian, "pinball.mid" },
			{ lang::Japanese, "pinball.mid" },
			{ lang::Korean, "pinball.mid" },
			{ lang::Norwegian, "pinball.mid" },
			{ lang::Dutch, "pinball.mid" },
			{ lang::Polish, "pinball.mid" },
			{ lang::BrazilianPortuguese, "pinball.mid" },
			{ lang::Portuguese, "pinball.mid" },
			{ lang::Russian, "pinball.mid" },
			{ lang::Swedish, "pinball.mid" },
			{ lang::Turkish, "pinball.mid" },
			{ lang::SimplifiedChinese, "pinball.mid" },
			{ lang::TraditionalChinese, "pinball.mid" },
		},
	},
	{
		Msg::STRING258,
		{
			{ lang::Arabic, "1 UseBitmapFont" },
			{ lang::Czech, "0 UseBitmapFont" },
			{ lang::Danish, "0 UseBitmapFont" },
			{ lang::German, "0 UseBitmapFont" },
			{ lang::Greek, "0 UseBitmapFont" },
			{ lang::English, "1 UseBitmapFont" },
			{ lang::Spanish, "0 UseBitmapFont" },
			{ lang::Finnish, "0 UseBitmapFont" },
			{ lang::French, "0 UseBitmapFont" },
			{ lang::Hebrew, "1 UseBitmapFont" },
			{ lang::Hungarian, "0 UseBitmapFont" },
			{ lang::Italian, "0 UseBitmapFont" },
			{ lang::Japanese, "0 UseBitmapFont" },
			{ lang::Korean, "0 UseBitmapFont" },
			{ lang::Norwegian, "0 UseBitmapFont" },
			{ lang::Dutch, "0 UseBitmapFont" },
			{ lang::Polish, "0 UseBitmapFont" },
			{ lang::BrazilianPortuguese, "0 UseBitmapFont" },
			{ lang::Portuguese, "0 UseBitmapFont" },
			{ lang::Russian, "0 UseBitmapFont" },
			{ lang::Swedish, "0 UseBitmapFont" },
			{ lang::Turkish, "0 UseBitmapFont" },
			{ lang::SimplifiedChinese, "0 UseBitmapFont" },
			{ lang::TraditionalChinese, "0 UseBitmapFont" },
		},
	},
	{
		Msg::STRING259,
		{
			{ lang::Arabic, "90 Left Flipper Key" },
			{ lang::Czech, "83 Left Flipper Key" },
			{ lang::Danish, "90 Venstre flippertast" },
			{ lang::German, "89 Left Flipper Key" },
			{ lang::Greek, "88 Left Flipper Key" },
			{ lang::English, "90 Left Flipper Key" },
			{ lang::Spanish, "90 Tecla de impulsor izquierdo" },
			{ lang::Finnish, "90 Left Flipper Key" },
			{ lang::French, "65 tilt gauche du flipper" },
			{ lang::Hebrew, "90 Left Flipper Key" },
			{ lang::Hungarian, "83 Left Flipper Key" },
			{ lang::Italian, "88 Flipper sinistro" },
			{ lang::Japanese, "90 左フリッパー キー" },
			{ lang::Korean, "90 왼쪽 공격막대 키" },
			{ lang::Norwegian, "90 Venstre flippertast" },
			{ lang::Dutch, "90 Linkerflipper" },
			{ lang::Polish, "90 Left Flipper Key" },
			{ lang::BrazilianPortuguese, "90 tecla da palheta esquerda" },
			{ lang::Portuguese, "90 Left Flipper Key" },
			{ lang::Russian, "90 Left Flipper Key" },
			{ lang::Swedish, "90 Left Flipper Key" },
			{ lang::Turkish, "90 Left Flipper Key" },
			{ lang::SimplifiedChinese, "90 左挡板键" },
			{ lang::TraditionalChinese, "90 向左翻轉按鍵" },
		},
	},
	{
		Msg::STRING260,
		{
			{ lang::Arabic, "191 Right Flipper Key" },
			{ lang::Czech, "75 Right Flipper Key" },
			{ lang::Danish, "191 Højre flippertast" },
			{ lang::German, "77 Right Flipper Key" },
			{ lang::Greek, "78 Right Flipper Key" },
			{ lang::English, "191 Right Flipper Key" },
			{ lang::Spanish, "77 Tecla de impulsor derecho" },
			{ lang::Finnish, "191 Right Flipper Key" },
			{ lang::French, "80 tilt droit du flipper" },
			{ lang::Hebrew, "191 Right Flipper Key" },
			{ lang::Hungarian, "75 Right Flipper Key" },
			{ lang::Italian, "78 Flipper destro" },
			{ lang::Japanese, "191 右フリッパー キー" },
			{ lang::Korean, "191 오른쪽 공격막대 키" },
			{ lang::Norwegian, "45 Høyre flippertast" },
			{ lang::Dutch, "191 Rechterflipper" },
			{ lang::Polish, "191 Right Flipper Key" },
			{ lang::BrazilianPortuguese, "191 tecla da palheta direita" },
			{ lang::Portuguese, "77 Right Flipper Key" },
			{ lang::Russian, "191 Right Flipper Key" },
			{ lang::Swedish, "191 Right Flipper Key" },
			{ lang::Turkish, "46 Right Flipper Key" },
			{ lang::SimplifiedChinese, "191 右挡板键" },
			{ lang::TraditionalChinese, "191 向右翻轉按鍵" },
		},
	},
	{
		Msg::STRING261,
		{
			{ lang::Arabic, "32 Plunger Key" },
			{ lang::Czech, "32 Plunger Key" },
			{ lang::Danish, "32 Stempeltast" },
			{ lang::German, "32 Plunger Key" },
			{ lang::Greek, "32 Plunger Key" },
			{ lang::English, "32 Plunger Key" },
			{ lang::Spanish, "32 Tecla del pistón" },
			{ lang::Finnish, "32 Plunger Key" },
			{ lang::French, "32 Plunger Key" },
			{ lang::Hebrew, "32 Plunger Key" },
			{ lang::Hungarian, "32 Plunger Key" },
			{ lang::Italian, "32 Gioca pallina" },
			{ lang::Japanese, "32 プランジャー キー" },
			{ lang::Korean, "32 구슬 쏘기 키" },
			{ lang::Norwegian, "32 Utskytingstast" },
			{ lang::Dutch, "32 Lanceertoets" },
			{ lang::Polish, "32 Plunger Key" },
			{ lang::BrazilianPortuguese, "32 tecla do lançador" },
			{ lang::Portuguese, "32 Plunger Key" },
			{ lang::Russian, "32 Plunger Key" },
			{ lang::Swedish, "32 Plunger Key" },
			{ lang::Turkish, "32 Plunger Key" },
			{ lang::SimplifiedChinese, "32 撞针键" },
			{ lang::TraditionalChinese, "32 柱塞按鍵" },
		},
	},
	{
		Msg::STRING262,
		{
			{ lang::Arabic, "88 Bump Left Key" },
			{ lang::Czech, "65 Bump Left Key" },
			{ lang::Danish, "88 Venstre bumptast" },
			{ lang::German, "88 Bump Left Key" },
			{ lang::Greek, "90 Bump Left Key" },
			{ lang::English, "88 Bump Left Key" },
			{ lang::Spanish, "88 Tecla de golpe izquierdo" },
			{ lang::Finnish, "88 Bump Left Key" },
			{ lang::French, "88 Bump Left Key" },
			{ lang::Hebrew, "88 Bump Left Key" },
			{ lang::Hungarian, "65 Bump Left Key" },
			{ lang::Italian, "90 Spinta da sinistra" },
			{ lang::Japanese, "88 左バンプ キー" },
			{ lang::Korean, "88 왼쪽 흔들기 키" },
			{ lang::Norwegian, "88 Venstre dunketast" },
			{ lang::Dutch, "88 Toets voor duw naar rechts" },
			{ lang::Polish, "88 Bump Left Key" },
			{ lang::BrazilianPortuguese, "88 tecla do tapa à esquerda" },
			{ lang::Portuguese, "88 Bump Left Key" },
			{ lang::Russian, "88 Bump Left Key" },
			{ lang::Swedish, "88 Bump Left Key" },
			{ lang::Turkish, "88 Bump Left Key" },
			{ lang::SimplifiedChinese, "88 凸块左键" },
			{ lang::TraditionalChinese, "88 擊球桿左鍵" },
		},
	},
	{
		Msg::STRING263,
		{
			{ lang::Arabic, "190 Bump Right Key" },
			{ lang::Czech, "76 Bump Right Key" },
			{ lang::Danish, "190 Højre bumptast" },
			{ lang::German, "78 Bump Right Key" },
			{ lang::Greek, "77 Bump Right Key" },
			{ lang::English, "190 Bump Right Key" },
			{ lang::Spanish, "78 Tecla de golpe derecho" },
			{ lang::Finnish, "190 Bump Right Key" },
			{ lang::French, "79 secousse droite" },
			{ lang::Hebrew, "190 Bump Right Key" },
			{ lang::Hungarian, "76 Bump Right Key" },
			{ lang::Italian, "77 Spinta da destra" },
			{ lang::Japanese, "190 右バンプ キー" },
			{ lang::Korean, "190 오른쪽 흔들기 키" },
			{ lang::Norwegian, "46 Høyre dunketast" },
			{ lang::Dutch, "190 Toets voor duw naar links" },
			{ lang::Polish, "190 Bump Right Key" },
			{ lang::BrazilianPortuguese, "190 tecla do tapa à direita" },
			{ lang::Portuguese, "78 Bump Right Key" },
			{ lang::Russian, "190 Bump Right Key" },
			{ lang::Swedish, "190 Bump Right Key" },
			{ lang::Turkish, "190 Bump Right Key" },
			{ lang::SimplifiedChinese, "190 凸块右键" },
			{ lang::TraditionalChinese, "190 擊球桿右鍵" },
		},
	},
	{
		Msg::STRING264,
		{
			{ lang::Arabic, "38 Bump Bottom Key" },
			{ lang::Czech, "38 Bump Bottom Key" },
			{ lang::Danish, "38 Nederste bumptast" },
			{ lang::German, "38 Bump Bottom Key" },
			{ lang::Greek, "66 Bump Bottom Key" },
			{ lang::English, "38 Bump Bottom Key" },
			{ lang::Spanish, "38 Tecla de golpe de frente" },
			{ lang::Finnish, "38 Bump Bottom Key" },
			{ lang::French, "38 Bump Bottom Key" },
			{ lang::Hebrew, "38 Bump Bottom Key" },
			{ lang::Hungarian, "38 Bump Bottom Key" },
			{ lang::Italian, "66 Spinta dal basso" },
			{ lang::Japanese, "38 バンプ ボトム キー" },
			{ lang::Korean, "38 아래쪽 흔들기 키" },
			{ lang::Norwegian, "38 Dunk nede-tast" },
			{ lang::Dutch, "38 Toets voor duw van onderen" },
			{ lang::Polish, "38 Bump Bottom Key" },
			{ lang::BrazilianPortuguese, "38 tecla do tapa frontal" },
			{ lang::Portuguese, "86 Bump Bottom Key" },
			{ lang::Russian, "38 Bump Bottom Key" },
			{ lang::Swedish, "38 Bump Bottom Key" },
			{ lang::Turkish, "38 Bump Bottom Key" },
			{ lang::SimplifiedChinese, "38 凸块底键" },
			{ lang::TraditionalChinese, "38 擊球桿底鍵" },
		},
	},
	{
		Msg::STRING265,
		{
			{ lang::Arabic, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::Czech, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::Danish, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::German, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::Greek, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::English, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::Spanish, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::Finnish, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::French, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::Hebrew, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::Hungarian, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::Italian, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::Japanese, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::Korean, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::Norwegian, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::Dutch, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::Polish, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::BrazilianPortuguese, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::Portuguese, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::Russian, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::Swedish, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::Turkish, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::SimplifiedChinese, "Software\\Microsoft\\Plus!\\Pinball" },
			{ lang::TraditionalChinese, "Software\\Microsoft\\Plus!\\Pinball" },
		},
	},
	{
		Msg::STRING266,
		{
			{ lang::Arabic, "SpaceCadet" },
			{ lang::Czech, "SpaceCadet" },
			{ lang::Danish, "SpaceCadet" },
			{ lang::German, "SpaceCadet" },
			{ lang::Greek, "SpaceCadet" },
			{ lang::English, "SpaceCadet" },
			{ lang::Spanish, "SpaceCadet" },
			{ lang::Finnish, "SpaceCadet" },
			{ lang::French, "SpaceCadet" },
			{ lang::Hebrew, "SpaceCadet" },
			{ lang::Hungarian, "SpaceCadet" },
			{ lang::Italian, "SpaceCadet" },
			{ lang::Japanese, "SpaceCadet" },
			{ lang::Korean, "SpaceCadet" },
			{ lang::Norwegian, "SpaceCadet" },
			{ lang::Dutch, "SpaceCadet" },
			{ lang::Polish, "SpaceCadet" },
			{ lang::BrazilianPortuguese, "SpaceCadet" },
			{ lang::Portuguese, "SpaceCadet" },
			{ lang::Russian, "SpaceCadet" },
			{ lang::Swedish, "SpaceCadet" },
			{ lang::Turkish, "SpaceCadet" },
			{ lang::SimplifiedChinese, "SpaceCadet" },
			{ lang::TraditionalChinese, "SpaceCadet" },
		},
	},
	{
		Msg::STRING267,
		{
			{ lang::Arabic, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::Czech, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::Danish, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::German, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::Greek, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::English, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::Spanish, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::Finnish, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::French, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::Hebrew, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::Hungarian, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::Italian, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::Japanese, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::Korean, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::Norwegian, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::Dutch, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::Polish, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::BrazilianPortuguese, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::Portuguese, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::Russian, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::Swedish, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::Turkish, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::SimplifiedChinese, "1c7c22a0-9576-11ce-bf80-444553540000" },
			{ lang::TraditionalChinese, "1c7c22a0-9576-11ce-bf80-444553540000" },
		},
	},
	{
		Msg::STRING268,
		{
			{ lang::Arabic, "PINBALL.DAT" },
			{ lang::Czech, "PINBALL.DAT" },
			{ lang::Danish, "PINBALL.DAT" },
			{ lang::German, "PINBALL.DAT" },
			{ lang::Greek, "PINBALL.DAT" },
			{ lang::English, "PINBALL.DAT" },
			{ lang::Spanish, "PINBALL.DAT" },
			{ lang::Finnish, "PINBALL.DAT" },
			{ lang::French, "PINBALL.DAT" },
			{ lang::Hebrew, "PINBALL.DAT" },
			{ lang::Hungarian, "PINBALL.DAT" },
			{ lang::Italian, "PINBALL.DAT" },
			{ lang::Japanese, "PINBALL.DAT" },
			{ lang::Korean, "PINBALL.DAT" },
			{ lang::Norwegian, "PINBALL.DAT" },
			{ lang::Dutch, "PINBALL.DAT" },
			{ lang::Polish, "PINBALL.DAT" },
			{ lang::BrazilianPortuguese, "PINBALL.DAT" },
			{ lang::Portuguese, "PINBALL.DAT" },
			{ lang::Russian, "PINBALL.DAT" },
			{ lang::Swedish, "PINBALL.DAT" },
			{ lang::Turkish, "PINBALL.DAT" },
			{ lang::SimplifiedChinese, "PINBALL.DAT" },
			{ lang::TraditionalChinese, "PINBALL.DAT" },
		},
	},
	{
		Msg::STRING269,
		{
			{ lang::Arabic, "Space Cadet" },
			{ lang::Czech, "Space Cadet" },
			{ lang::Danish, "Space Cadet" },
			{ lang::German, "Space Cadet" },
			{ lang::Greek, "Space Cadet" },
			{ lang::English, "Space Cadet" },
			{ lang::Spanish, "Space Cadet" },
			{ lang::Finnish, "Space Cadet" },
			{ lang::French, "Cadet de l'espace" },
			{ lang::Hebrew, "Space Cadet" },
			{ lang::Hungarian, "Space Cadet" },
			{ lang::Italian, "Space Cadet" },
			{ lang::Japanese, "Space Cadet" },
			{ lang::Korean, "우주 비행 훈련" },
			{ lang::Norwegian, "Romkadett" },
			{ lang::Dutch, "Space Cadet" },
			{ lang::Polish, "Space Cadet" },
			{ lang::BrazilianPortuguese, "Space Cadet" },
			{ lang::Portuguese, "Cadete espacial" },
			{ lang::Russian, "Звездный юнга" },
			{ lang::Swedish, "Space Cadet" },
			{ lang::Turkish, "Space Cadet" },
			{ lang::SimplifiedChinese, "太空军校生" },
			{ lang::TraditionalChinese, "太空軍校生" },
		},
	},
	{
		Msg::STRING270,
		{
			{ lang::Arabic, "‏‏خطأ:" },
			{ lang::Czech, "Chyba:" },
			{ lang::Danish, "Fejl:" },
			{ lang::German, "Fehler:" },
			{ lang::Greek, "Σφάλμα:" },
			{ lang::English, "Error:" },
			{ lang::Spanish, "Error:" },
			{ lang::Finnish, "Virhe:" },
			{ lang::French, "Erreur :" },
			{ lang::Hebrew, "‏‏שגיאה:" },
			{ lang::Hungarian, "Hiba:" },
			{ lang::Italian, "Errore:" },
			{ lang::Japanese, "エラー:" },
			{ lang::Korean, "오류:" },
			{ lang::Norwegian, "Feil:" },
			{ lang::Dutch, "Fout:" },
			{ lang::Polish, "Błąd:" },
			{ lang::BrazilianPortuguese, "Erro:" },
			{ lang::Portuguese, "Erro:" },
			{ lang::Russian, "Ошибка:" },
			{ lang::Swedish, "Fel:" },
			{ lang::Turkish, "Hata:" },
			{ lang::SimplifiedChinese, "错误：" },
			{ lang::TraditionalChinese, "錯誤：" },
		},
	},
	{
		Msg::STRING271,
		{
			{ lang::Arabic, "‏‏لا يمكن العثور على طاولات أخرى." },
			{ lang::Czech, "Nelze nalézt další stoly." },
			{ lang::Danish, "Det er ikke muligt at finde andre borde." },
			{ lang::German, "Es wurde kein anderer Tisch gefunden." },
			{ lang::Greek, "Δεν είναι δυνατή η εύρεση άλλων πινάκων." },
			{ lang::English, "Unable to find other tables." },
			{ lang::Spanish, "No se pueden encontrar otras mesas." },
			{ lang::Finnish, "Muita pöytiä ei löytynyt." },
			{ lang::French, "Impossible de trouver d'autres flippers." },
			{ lang::Hebrew, "‏‏לא נמצאו שולחנות אחרים." },
			{ lang::Hungarian, "Nincs másik asztal." },
			{ lang::Italian, "Impossibile trovare altre tabelle." },
			{ lang::Japanese, "ほかのテーブルが見つかりません。" },
			{ lang::Korean, "다른 테이블을 찾을 수 없습니다." },
			{ lang::Norwegian, "Finner ikke andre bord." },
			{ lang::Dutch, "Kan geen andere kasten vinden." },
			{ lang::Polish, "Nie można odnaleźć innych stołów." },
			{ lang::BrazilianPortuguese, "Não é possível localizar outras máquinas." },
			{ lang::Portuguese, "Não é possível localizar outras tabelas." },
			{ lang::Russian, "Не удалось найти другие столы." },
			{ lang::Swedish, "Det går inte att hitta fler spelplaner." },
			{ lang::Turkish, "Başka masa bulunamadı." },
			{ lang::SimplifiedChinese, "无法找到其它桌面。" },
			{ lang::TraditionalChinese, "無法找到其他表格。" },
		},
	},
	{
		Msg::STRING272,
		{
			{ lang::Arabic, "‎3D Pinball\nSpace Cadet" },
			{ lang::Czech, "3D Pinball\nSpace Cadet" },
			{ lang::Danish, "3D Pinball\nSpace Cadet" },
			{ lang::German, "3D-Pinball\nSpace Cadet" },
			{ lang::Greek, "Φλίπερ-3Δ\nSpace Cadet" },
			{ lang::English, "3D Pinball\nSpace Cadet" },
			{ lang::Spanish, "3D Pinball\nCadete Espacial" },
			{ lang::Finnish, "3D Pinball\nSpace Cadet" },
			{ lang::French, "Pinball 3D\nSpace Cadet" },
			{ lang::Hebrew, "3D Pinball\nSpace Cadet" },
			{ lang::Hungarian, "3D-flipper\nSpace Cadet" },
			{ lang::Italian, "3D Pinball\nSpace Cadet" },
			{ lang::Japanese, "3D ピンボール\nSpace Cadet" },
			{ lang::Korean, "3D 핀볼\n우주 비행 훈련" },
			{ lang::Norwegian, "3D Pinball\nRomkadett" },
			{ lang::Dutch, "3D Pinball\nSpace Cadet" },
			{ lang::Polish, "3D Pinball\nSpace Cadet" },
			{ lang::BrazilianPortuguese, "Pinball 3D\nSpace Cadet" },
			{ lang::Portuguese, "3D Pinball\nCadete espacial" },
			{ lang::Russian, "3D Пинбол\nЗвездный юнга" },
			{ lang::Swedish, "3D Pinball\nSpace Cadet" },
			{ lang::Turkish, "3D Pinball\nSpace Cadet" },
			{ lang::SimplifiedChinese, "三维弹球\n太空军校生" },
			{ lang::TraditionalChinese, "立體彈珠台\n太空軍校生" },
		},
	},
	{
		Msg::STRING273,
		{
			{ lang::Arabic, "الترقية إلى %s" },
			{ lang::Czech, "Povýšení na hodnost %s" },
			{ lang::Danish, "Forfremmelse til %s" },
			{ lang::German, "Zum %s befördert" },
			{ lang::Greek, "Προαγωγή σε %s" },
			{ lang::English, "Promotion to %s" },
			{ lang::Spanish, "Ascenso a %s" },
			{ lang::Finnish, "Ylennetty arvo: %s" },
			{ lang::French, "Élévation au grade de %s" },
			{ lang::Hebrew, "Promotion to %s" },
			{ lang::Hungarian, "Előléptetés %s rangba" },
			{ lang::Italian, "Promozione a %s" },
			{ lang::Japanese, "%s に昇格" },
			{ lang::Korean, "%s(으)로 수준 올리기" },
			{ lang::Norwegian, "Forfremmelse til %s" },
			{ lang::Dutch, "Promotie naar %s" },
			{ lang::Polish, "Awans do stopnia: %s" },
			{ lang::BrazilianPortuguese, "Promovido a %s" },
			{ lang::Portuguese, "Ascender para %s" },
			{ lang::Russian, "Повышение в должности до %s" },
			{ lang::Swedish, "Befordran till %s" },
			{ lang::Turkish, "%s Terfisi" },
			{ lang::SimplifiedChinese, "升级到 %s" },
			{ lang::TraditionalChinese, "提升到 %s" },
		},
	},
	{
		Msg::STRING274,
		{
			{ lang::Arabic, "خفض الرتبة إلى %s" },
			{ lang::Czech, "Degradování na hodnost %s" },
			{ lang::Danish, "Degradering til %s" },
			{ lang::German, "Zum %s degradiert" },
			{ lang::Greek, "Υποβιβασμός σε %s" },
			{ lang::English, "Demotion to %s" },
			{ lang::Spanish, "Descenso a %s" },
			{ lang::Finnish, "Alennettu arvo: %s" },
			{ lang::French, "Rétrogradé vers %s" },
			{ lang::Hebrew, "Demotion to %s" },
			{ lang::Hungarian, "Lefokozás %s rangba" },
			{ lang::Italian, "Degradato a %s" },
			{ lang::Japanese, "%s に降格" },
			{ lang::Korean, "%s로 강등" },
			{ lang::Norwegian, "Degradering til %s" },
			{ lang::Dutch, "Degradatie naar %s" },
			{ lang::Polish, "Degradacja do stopnia: %s" },
			{ lang::BrazilianPortuguese, "Rebaixado a %s" },
			{ lang::Portuguese, "Descender para %s" },
			{ lang::Russian, "Понижение в должности до %s" },
			{ lang::Swedish, "Degradering till %s" },
			{ lang::Turkish, "İndirme yeri: %s" },
			{ lang::SimplifiedChinese, "降级到 %s" },
			{ lang::TraditionalChinese, "降低到 %s" },
		},
	},
	{
		Msg::STRING275,
		{
			{ lang::Arabic, "Upgrade Attack Bumpers" },
			{ lang::Czech, "Vylepšení útočných nárazníků" },
			{ lang::Danish, "Opgrader angrebsbump" },
			{ lang::German, "Rückstoßelemente aufwerten" },
			{ lang::Greek, "Αναβάθμιση προσκρουστήρων πρώτης γραμμής" },
			{ lang::English, "Upgrade Attack Bumpers" },
			{ lang::Spanish, "Actualizar reboteadores de ataque" },
			{ lang::Finnish, "Päivitä hyökkäyspuskurit" },
			{ lang::French, "Renforcement des champignons d'attaque" },
			{ lang::Hebrew, "Upgrade Attack Bumpers" },
			{ lang::Hungarian, "Korszerűsítse a támadógombákat" },
			{ lang::Italian, "Potenzia respingenti di prima linea" },
			{ lang::Japanese, "武器をアップグレードせよ!" },
			{ lang::Korean, "공격 범퍼 치기" },
			{ lang::Norwegian, "Oppgrader angrepsbumpere" },
			{ lang::Dutch, "Aanvalbumpers opwaarderen" },
			{ lang::Polish, "Wymień zderzaki ataku" },
			{ lang::BrazilianPortuguese, "Atualizar os amortecedores de ataque" },
			{ lang::Portuguese, "Reforço dos amortecedores de ataque" },
			{ lang::Russian, "Улучшите Бамперы Атаки" },
			{ lang::Swedish, "Uppgradera höghöjds-bumpers" },
			{ lang::Turkish, "Vuruş Tamponarını Yenile" },
			{ lang::SimplifiedChinese, "升级攻击缓冲器" },
			{ lang::TraditionalChinese, "改善攻擊緩衝器" },
		},
	},
	{
		Msg::STRING276,
		{
			{ lang::Arabic, "Fill Left Hazard Banks" },
			{ lang::Czech, "Vyplňte levé zásobníky stavu ohrožení" },
			{ lang::Danish, "Fyld venstre risikodepoter" },
			{ lang::German, "Linke Risikoobjekte aktivieren" },
			{ lang::Greek, "Πλήρωση αριστερής ανάσχεσης" },
			{ lang::English, "Fill Left Hazard Banks" },
			{ lang::Spanish, "Llenar bancos de riesgo de la izquierda" },
			{ lang::Finnish, "Täytä vasemmanpuoleiset vaararivit" },
			{ lang::French, "Remplissez les bancs de détresse gauches" },
			{ lang::Hebrew, "Fill Left Hazard Banks" },
			{ lang::Hungarian, "Lője ki a bal vészkatapult céltáblát" },
			{ lang::Italian, "Riempimento energetico degli scudi a tribordo" },
			{ lang::Japanese, "左ハザード バンクを点灯させよ!" },
			{ lang::Korean, "왼쪽 위험물 뱅크 채우기" },
			{ lang::Norwegian, "Fyll venstre farebanker" },
			{ lang::Dutch, "Linkerrisicolampjes activeren" },
			{ lang::Polish, "Wypełnij lewy bank ryzyka" },
			{ lang::BrazilianPortuguese, "Encher os bancos perigosos da esquerda" },
			{ lang::Portuguese, "Encher os bancos de risco da esquerda" },
			{ lang::Russian, "Заполните Левые Банки Опасностей" },
			{ lang::Swedish, "Träffa returtavlor till vänster" },
			{ lang::Turkish, "Sol Hasar Bantlarını Doldur" },
			{ lang::SimplifiedChinese, "添加左边危险材料库" },
			{ lang::TraditionalChinese, "填入左側障礙帶" },
		},
	},
	{
		Msg::STRING277,
		{
			{ lang::Arabic, "HIGH SCORE" },
			{ lang::Czech, "HIGH SCORE" },
			{ lang::Danish, "BEDSTE RESULTATER" },
			{ lang::German, "Bestenliste" },
			{ lang::Greek, "ΚΑΛΥΤΕΡΟΣ ΠΑΙΚΤΗΣ" },
			{ lang::English, "HIGH SCORE" },
			{ lang::Spanish, "ALTA PUNTUACIÓN" },
			{ lang::Finnish, "HYVÄ TULOS" },
			{ lang::French, "Meilleurs scores" },
			{ lang::Hebrew, "HIGH SCORE" },
			{ lang::Hungarian, "FELKERÜLT AZ EREDMÉNYJELZŐRE" },
			{ lang::Italian, "PUNTEGGIO MIGLIORE" },
			{ lang::Japanese, "ハイスコア" },
			{ lang::Korean, "고득점" },
			{ lang::Norwegian, "BESTE RESULTATER" },
			{ lang::Dutch, "TOPSCORE" },
			{ lang::Polish, "NAJLEPSZY WYNIK" },
			{ lang::BrazilianPortuguese, "RECORDE" },
			{ lang::Portuguese, "Pontuação máxima" },
			{ lang::Russian, "НОВЫЙ РЕКОРД" },
			{ lang::Swedish, "POÄNGREKORD" },
			{ lang::Turkish, "YÜKSEK PUAN" },
			{ lang::SimplifiedChinese, "高分" },
			{ lang::TraditionalChinese, "高分" },
		},
	},
	{
		Msg::STRING278,
		{
			{ lang::Arabic, "pinball.chm" },
			{ lang::Czech, "pinball.chm" },
			{ lang::Danish, "pinball.chm" },
			{ lang::German, "pinball.chm" },
			{ lang::Greek, "pinball.chm" },
			{ lang::English, "pinball.chm" },
			{ lang::Spanish, "pinball.chm" },
			{ lang::Finnish, "pinball.chm" },
			{ lang::French, "pinball.chm" },
			{ lang::Hebrew, "pinball.chm" },
			{ lang::Hungarian, "pinball.chm" },
			{ lang::Italian, "pinball.chm" },
			{ lang::Japanese, "pinball.chm" },
			{ lang::Korean, "pinball.chm" },
			{ lang::Norwegian, "pinball.chm" },
			{ lang::Dutch, "pinball.chm" },
			{ lang::Polish, "pinball.chm" },
			{ lang::BrazilianPortuguese, "pinball.chm" },
			{ lang::Portuguese, "pinball.chm" },
			{ lang::Russian, "pinball.chm" },
			{ lang::Swedish, "pinball.chm" },
			{ lang::Turkish, "pinball.chm" },
			{ lang::SimplifiedChinese, "pinball.chm" },
			{ lang::TraditionalChinese, "pinball.chm" },
		},
	},
	{
		Msg::STRING279,
		{
			{ lang::Arabic, "‏‏لا توجد ذاكرة كافية لتشغيل ‎3D Pinball." },
			{ lang::Czech, "Ke spuštění hry 3D Pinball není dostatek paměti." },
			{ lang::Danish, "Der er ikke tilstrækkelig hukommelse til at køre 3D Pinball." },
			{ lang::German, "Für 3D-Pinball ist nicht genügend Arbeitsspeicher verfügbar." },
			{ lang::Greek, "Η μνήμη δεν επαρκεί για την εκτέλεση του Φλίπερ-3Δ." },
			{ lang::English, "Not enough memory to run 3D Pinball." },
			{ lang::Spanish, "Memoria insuficiente para ejecutar 3D Pinball." },
			{ lang::Finnish, "Liian vähän muistia 3D Pinballin suorittamiseen." },
			{ lang::French, "Mémoire insuffisante pour exécuter Pinball 3D." },
			{ lang::Hebrew, "‏‏אין די זיכרון להפעלת Pinball תלת-מימדי." },
			{ lang::Hungarian, "Nincs elég memória a 3D-flipper futtatásához." },
			{ lang::Italian, "Memoria insufficiente per eseguire 3D Pinball." },
			{ lang::Japanese, "メモリ不足のため 3D ピンボールを起動できません" },
			{ lang::Korean, "메모리가 부족하여 3D 핀볼을 실행할 수 없습니다." },
			{ lang::Norwegian, "Ikke nok minne til å kjøre 3D Pinball." },
			{ lang::Dutch, "Er is onvoldoende geheugen om 3D Pinball uit te kunnen voeren." },
			{ lang::Polish, "Za mało pamięci do uruchomienia gry 3D Pinball." },
			{ lang::BrazilianPortuguese, "Não há memória suficiente para executar o Pinball 3D." },
			{ lang::Portuguese, "Não existe memória suficiente para executar o 3D Pinball." },
			{ lang::Russian, "Недостаточно памяти для запуска 3D пинбола." },
			{ lang::Swedish, "Det finns inte tillräckligt med minne för att köra 3D Pinball." },
			{ lang::Turkish, "3D Pinball'ı çalıştırmak için bellek yetersiz." },
			{ lang::SimplifiedChinese, "内存不足，无法运行三维弹球游戏。" },
			{ lang::TraditionalChinese, "記憶體不足，無法執行立體彈珠台。" },
		},
	},
	{
		Msg::STRING280,
		{
			{ lang::Arabic, "نقاط تسجيل اللاعب 1\n%ld" },
			{ lang::Czech, "Skóre hráče 1\n%ld" },
			{ lang::Danish, "Spiller 1's point\n%ld" },
			{ lang::German, "Wertung Spieler 1\n%ld" },
			{ lang::Greek, "Βαθμολογία παίκτη 1\n%ld" },
			{ lang::English, "Player 1's Score\n%ld" },
			{ lang::Spanish, "Puntuación jugador 1\n%ld" },
			{ lang::Finnish, "Pelaaja 1\n%ld" },
			{ lang::French, "Score du joueur 1\n%ld" },
			{ lang::Hebrew, "Player 1's Score\n%ld" },
			{ lang::Hungarian, "1. játékos eredménye: \n%ld" },
			{ lang::Italian, "Punteggio giocatore 1\n%ld" },
			{ lang::Japanese, "プレーヤー 1 のスコア\n%ld" },
			{ lang::Korean, "비행사 1의 점수\n%ld" },
			{ lang::Norwegian, "Spiller 1s resultat\n%ld" },
			{ lang::Dutch, "Score speler 1\n%ld" },
			{ lang::Polish, "Wynik gracza 1\n%ld" },
			{ lang::BrazilianPortuguese, "Pontos do jogador 1:\n%ld" },
			{ lang::Portuguese, "Pontuação do jogador 1\n%ld" },
			{ lang::Russian, "Счет Игрока 1\n%ld" },
			{ lang::Swedish, "Spelare 1 - resultat\n%ld" },
			{ lang::Turkish, "1. Oyuncunun Skoru\n%ld" },
			{ lang::SimplifiedChinese, "玩家 1 的分数\n%ld" },
			{ lang::TraditionalChinese, "玩家 1 的分數\n%ld" },
		},
	},
	{
		Msg::STRING281,
		{
			{ lang::Arabic, "نقاط تسجيل اللاعب 2\n%ld" },
			{ lang::Czech, "Skóre hráče 2\n%ld" },
			{ lang::Danish, "Spiller 2's point\n%ld" },
			{ lang::German, "Wertung Spieler 2\n%ld" },
			{ lang::Greek, "Βαθμολογία παίκτη 2\n%ld" },
			{ lang::English, "Player 2's Score\n%ld" },
			{ lang::Spanish, "Puntuación jugador 2\n%ld" },
			{ lang::Finnish, "Pelaaja 2\n%ld" },
			{ lang::French, "Score du joueur 2\n%ld" },
			{ lang::Hebrew, "Player 2's Score\n%ld" },
			{ lang::Hungarian, "2. játékos eredménye: \n%ld" },
			{ lang::Italian, "Punteggio giocatore 2\n%ld" },
			{ lang::Japanese, "プレーヤー 2 のスコア\n%ld" },
			{ lang::Korean, "비행사 2의 점수\n%ld" },
			{ lang::Norwegian, "Spiller 2s resultat\n%ld" },
			{ lang::Dutch, "Score speler 2\n%ld" },
			{ lang::Polish, "Wynik gracza 2\n%ld" },
			{ lang::BrazilianPortuguese, "Pontos do jogador 2:\n%ld" },
			{ lang::Portuguese, "Pontuação do jogador 2\n%ld" },
			{ lang::Russian, "Счет Игрока 2\n%ld" },
			{ lang::Swedish, "Spelare 2 - resultat\n%ld" },
			{ lang::Turkish, "2. Oyuncunun Skoru\n%ld" },
			{ lang::SimplifiedChinese, "玩家 2 的分数\n%ld" },
			{ lang::TraditionalChinese, "玩家 2 的分數\n%ld" },
		},
	},
	{
		Msg::STRING282,
		{
			{ lang::Arabic, "نقاط تسجيل اللاعب 3\n%ld" },
			{ lang::Czech, "Skóre hráče 3\n%ld" },
			{ lang::Danish, "Spiller 3's point\n%ld" },
			{ lang::German, "Wertung Spieler 3\n%ld" },
			{ lang::Greek, "Βαθμολογία παίκτη 3\n%ld" },
			{ lang::English, "Player 3's Score\n%ld" },
			{ lang::Spanish, "Puntuación jugador 3\n%ld" },
			{ lang::Finnish, "Pelaaja 3\n%ld" },
			{ lang::French, "Score du joueur 3\n%ld" },
			{ lang::Hebrew, "Player 3's Score\n%ld" },
			{ lang::Hungarian, "3. játékos eredménye: \n%ld" },
			{ lang::Italian, "Punteggio giocatore 3\n%ld" },
			{ lang::Japanese, "プレーヤー 3 のスコア\n%ld" },
			{ lang::Korean, "비행사 3의 점수\n%ld" },
			{ lang::Norwegian, "Spiller 3s resultat\n%ld" },
			{ lang::Dutch, "Score speler 3\n%ld" },
			{ lang::Polish, "Wynik gracza 3\n%ld" },
			{ lang::BrazilianPortuguese, "Pontos do jogador 3:\n%ld" },
			{ lang::Portuguese, "Pontuação do jogador 3\n%ld" },
			{ lang::Russian, "Счет Игрока 3\n%ld" },
			{ lang::Swedish, "Spelare 3 - resultat\n%ld" },
			{ lang::Turkish, "3. Oyuncunun Skoru\n%ld" },
			{ lang::SimplifiedChinese, "玩家 3 的分数\n%ld" },
			{ lang::TraditionalChinese, "玩家 3 的分數\n%ld" },
		},
	},
	{
		Msg::STRING283,
		{
			{ lang::Arabic, "نقاط تسجيل اللاعب 4\n%ld" },
			{ lang::Czech, "Skóre hráče 4\n%ld" },
			{ lang::Danish, "Spiller 4's point\n%ld" },
			{ lang::German, "Wertung Spieler 4\n%ld" },
			{ lang::Greek, "Βαθμολογία παίκτη 4\n%ld" },
			{ lang::English, "Player 4's Score\n%ld" },
			{ lang::Spanish, "Puntuación jugador 4\n%ld" },
			{ lang::Finnish, "Pelaaja 4\n%ld" },
			{ lang::French, "Score du joueur 4\n%ld" },
			{ lang::Hebrew, "Player 4's Score\n%ld" },
			{ lang::Hungarian, "4. játékos eredménye: \n%ld" },
			{ lang::Italian, "Punteggio giocatore 4\n%ld" },
			{ lang::Japanese, "プレーヤー 4 のスコア\n%ld" },
			{ lang::Korean, "비행사 4의 점수\n%ld" },
			{ lang::Norwegian, "Spiller 4s resultat\n%ld" },
			{ lang::Dutch, "Score speler 4\n%ld" },
			{ lang::Polish, "Wynik gracza 4\n%ld" },
			{ lang::BrazilianPortuguese, "Pontos do jogador 4:\n%ld" },
			{ lang::Portuguese, "Pontuação do jogador 4\n%ld" },
			{ lang::Russian, "Счет Игрока 4\n%ld" },
			{ lang::Swedish, "Spelare 4 - resultat\n%ld" },
			{ lang::Turkish, "4. Oyuncunun Skoru\n%ld" },
			{ lang::SimplifiedChinese, "玩家 4 的分数\n%ld" },
			{ lang::TraditionalChinese, "玩家 4 的分數\n%ld" },
		},
	},
	{
		Msg::STRING284,
		{
			{ lang::Arabic, "أفضل النتائج 1\n%ld" },
			{ lang::Czech, "Nejlepší výsledek 1\n%ld" },
			{ lang::Danish, "Point 1\n%ld" },
			{ lang::German, "Bestwertung 1\n%ld" },
			{ lang::Greek, "Καλύτερη βαθμολογία 1\n%ld" },
			{ lang::English, "High Score 1\n%ld" },
			{ lang::Spanish, "Puntuación máxima 1\n%ld" },
			{ lang::Finnish, "1. sija\n%ld" },
			{ lang::French, "Meilleur score 1\n%ld" },
			{ lang::Hebrew, "High Score 1\n%ld" },
			{ lang::Hungarian, "1. helyezett:\n%ld" },
			{ lang::Italian, "Punteggi migliori 1\n%ld" },
			{ lang::Japanese, "ハイスコア 1\n%ld" },
			{ lang::Korean, "고득점 1\n%ld" },
			{ lang::Norwegian, "Beste resultat 1\n%ld" },
			{ lang::Dutch, "Topscore 1\n%ld" },
			{ lang::Polish, "Najlepszy wynik 1\n%ld" },
			{ lang::BrazilianPortuguese, "Recorde 1\n%ld" },
			{ lang::Portuguese, "Recorde 1\n%ld" },
			{ lang::Russian, "Рекорд 1\n%ld" },
			{ lang::Swedish, "Poängrekord 1\n%ld" },
			{ lang::Turkish, "1. Yüksek Skor\n%ld" },
			{ lang::SimplifiedChinese, "高分 1\n%ld" },
			{ lang::TraditionalChinese, "高分 1\n%ld" },
		},
	},
	{
		Msg::STRING285,
		{
			{ lang::Arabic, "أفضل النتائج 2\n%ld" },
			{ lang::Czech, "Nejlepší výsledek 2\n%ld" },
			{ lang::Danish, "Point 2\n%ld" },
			{ lang::German, "Bestwertung 2\n%ld" },
			{ lang::Greek, "Καλύτερη βαθμολογία 2\n%ld" },
			{ lang::English, "High Score 2\n%ld" },
			{ lang::Spanish, "Puntuación máxima 2\n%ld" },
			{ lang::Finnish, "2. sija\n%ld" },
			{ lang::French, "Meilleur score 2\n%ld" },
			{ lang::Hebrew, "High Score 2\n%ld" },
			{ lang::Hungarian, "2. helyezett:\n%ld" },
			{ lang::Italian, "Punteggi migliori 2\n%ld" },
			{ lang::Japanese, "ハイスコア 2\n%ld" },
			{ lang::Korean, "고득점 2\n%ld" },
			{ lang::Norwegian, "Beste resultat 2\n%ld" },
			{ lang::Dutch, "Topscore 2\n%ld" },
			{ lang::Polish, "Najlepszy wynik 2\n%ld" },
			{ lang::BrazilianPortuguese, "Recorde 2\n%ld" },
			{ lang::Portuguese, "Recorde 2\n%ld" },
			{ lang::Russian, "Рекорд 2\n%ld" },
			{ lang::Swedish, "Poängrekord 2\n%ld" },
			{ lang::Turkish, "2. Yüksek Skor\n%ld" },
			{ lang::SimplifiedChinese, "高分 2\n%ld" },
			{ lang::TraditionalChinese, "高分 2\n%ld" },
		},
	},
	{
		Msg::STRING286,
		{
			{ lang::Arabic, "أفضل النتائج 3\n%ld" },
			{ lang::Czech, "Nejlepší výsledek 3\n%ld" },
			{ lang::Danish, "Point 3\n%ld" },
			{ lang::German, "Bestwertung 3\n%ld" },
			{ lang::Greek, "Καλύτερη βαθμολογία 3\n%ld" },
			{ lang::English, "High Score 3\n%ld" },
			{ lang::Spanish, "Puntuación máxima 3\n%ld" },
			{ lang::Finnish, "3. sija\n%ld" },
			{ lang::French, "Meilleur score 3\n%ld" },
			{ lang::Hebrew, "High Score 3\n%ld" },
			{ lang::Hungarian, "3. helyezett:\n%ld" },
			{ lang::Italian, "Punteggi migliori 3\n%ld" },
			{ lang::Japanese, "ハイスコア 3\n%ld" },
			{ lang::Korean, "고득점 3\n%ld" },
			{ lang::Norwegian, "Beste resultat 3\n%ld" },
			{ lang::Dutch, "Topscore 3\n%ld" },
			{ lang::Polish, "Najlepszy wynik 3\n%ld" },
			{ lang::BrazilianPortuguese, "Recorde 3\n%ld" },
			{ lang::Portuguese, "Recorde 3\n%ld" },
			{ lang::Russian, "Рекорд 3\n%ld" },
			{ lang::Swedish, "Poängrekord 3\n%ld" },
			{ lang::Turkish, "3. Yüksek Skor\n%ld" },
			{ lang::SimplifiedChinese, "高分 3\n%ld" },
			{ lang::TraditionalChinese, "高分 3\n%ld" },
		},
	},
	{
		Msg::STRING287,
		{
			{ lang::Arabic, "أفضل النتائج 4\n%ld" },
			{ lang::Czech, "Nejlepší výsledek 4\n%ld" },
			{ lang::Danish, "Point 4\n%ld" },
			{ lang::German, "Bestwertung 4\n%ld" },
			{ lang::Greek, "Καλύτερη βαθμολογία 4\n%ld" },
			{ lang::English, "High Score 4\n%ld" },
			{ lang::Spanish, "Puntuación máxima 4\n%ld" },
			{ lang::Finnish, "4. sija\n%ld" },
			{ lang::French, "Meilleur score 4\n%ld" },
			{ lang::Hebrew, "High Score 4\n%ld" },
			{ lang::Hungarian, "4. helyezett:\n%ld" },
			{ lang::Italian, "Punteggi migliori 4\n%ld" },
			{ lang::Japanese, "ハイスコア 4\n%ld" },
			{ lang::Korean, "고득점 4\n%ld" },
			{ lang::Norwegian, "Beste resultat 4\n%ld" },
			{ lang::Dutch, "Topscore 4\n%ld" },
			{ lang::Polish, "Najlepszy wynik 4\n%ld" },
			{ lang::BrazilianPortuguese, "Recorde 4\n%ld" },
			{ lang::Portuguese, "Recorde 4\n%ld" },
			{ lang::Russian, "Рекорд 4\n%ld" },
			{ lang::Swedish, "Poängrekord 4\n%ld" },
			{ lang::Turkish, "4. Yüksek Skor\n%ld" },
			{ lang::SimplifiedChinese, "高分 4\n%ld" },
			{ lang::TraditionalChinese, "高分 4\n%ld" },
		},
	},
	{
		Msg::STRING288,
		{
			{ lang::Arabic, "أفضل النتائج 5\n%ld" },
			{ lang::Czech, "Nejlepší výsledek 5\n%ld" },
			{ lang::Danish, "Point 5\n%ld" },
			{ lang::German, "Bestwertung 5\n%ld" },
			{ lang::Greek, "Καλύτερη βαθμολογία 5\n%ld" },
			{ lang::English, "High Score 5\n%ld" },
			{ lang::Spanish, "Puntuación máxima 5\n%ld" },
			{ lang::Finnish, "5. sija\n%ld" },
			{ lang::French, "Meilleur score 5\n%ld" },
			{ lang::Hebrew, "High Score 5\n%ld" },
			{ lang::Hungarian, "5. helyezett:\n%ld" },
			{ lang::Italian, "Punteggi migliori 5\n%ld" },
			{ lang::Japanese, "ハイスコア 5\n%ld" },
			{ lang::Korean, "고득점 5\n%ld" },
			{ lang::Norwegian, "Beste resultat 5\n%ld" },
			{ lang::Dutch, "Topscore 5\n%ld" },
			{ lang::Polish, "Najlepszy wynik 5\n%ld" },
			{ lang::BrazilianPortuguese, "Recorde 5\n%ld" },
			{ lang::Portuguese, "Recorde 5\n%ld" },
			{ lang::Russian, "Рекорд 5\n%ld" },
			{ lang::Swedish, "Poängrekord 5\n%ld" },
			{ lang::Turkish, "5. Yüksek Skor\n%ld" },
			{ lang::SimplifiedChinese, "高分 5\n%ld" },
			{ lang::TraditionalChinese, "高分 5\n%ld" },
		},
	},
	{
		Msg::STRING289,
		{
			{ lang::Arabic, "255 255 255   (R G B لون الخط الافتراضي)" },
			{ lang::Czech, "128 128 255   (R G B default font color)" },
			{ lang::Danish, "255 255 255   (R G B standardskrifttypefarve)" },
			{ lang::German, "255 000 255   (R G B default font color)" },
			{ lang::Greek, "255 255 255   (R G B προεπιλεγμένο χρώμα)" },
			{ lang::English, "255 255 255   (R G B default font color)" },
			{ lang::Spanish, "255 255 255 (Color de fuente R G B predeterminado)" },
			{ lang::Finnish, "126 153 231   (R G B oletusfonttiväri)" },
			{ lang::French, "255 255 255   (Couleur RGB de la police par défaut)" },
			{ lang::Hebrew, "255 255 255   (R G B צבע גופן המשמש כברירת מחדל)" },
			{ lang::Hungarian, "255 255 255   (R G B alapértelmezett betűszín)" },
			{ lang::Italian, "255 255 255   (R G B colore predefinito)" },
			{ lang::Japanese, "148 204 244   (R G B 既定フォント カラー)" },
			{ lang::Korean, "255 255 255   (R G B 기본 글꼴 색)" },
			{ lang::Norwegian, "255 255 255   (R G B standard skriftfarge)" },
			{ lang::Dutch, "255 255 255   (R G B standaard lettertypekleur)" },
			{ lang::Polish, "255 255 255   (kolor R G B czcionki domyślnej)" },
			{ lang::BrazilianPortuguese, "255 255 255   (cor de fonte padrão R G B)" },
			{ lang::Portuguese, "255 255 255   (cor RGB predefinida para o tipo de letra)" },
			{ lang::Russian, "255 255 255   (R G B default font color)" },
			{ lang::Swedish, "255 255 255   (R G B default font color)" },
			{ lang::Turkish, "255 255 255   (R G B varsayılan yazı tipi rengi)" },
			{ lang::SimplifiedChinese, "255 255 255   (R G B 默认字体颜色)" },
			{ lang::TraditionalChinese, "255 255 255   (R G B 預設字型色彩)" },
		},
	},
	{
		Msg::HIGHSCORES_Caption,
		{
			{ lang::Arabic, "أفضل النتائج" },
			{ lang::Czech, "Nejlepší výsledky" },
			{ lang::Danish, "Point" },
			{ lang::German, "Bestenliste" },
			{ lang::Greek, "Καλύτεροι παίκτες" },
			{ lang::English, "High Scores" },
			{ lang::Spanish, "Puntuaciones más altas" },
			{ lang::Finnish, "Parhaat tulokset" },
			{ lang::French, "Meilleurs scores" },
			{ lang::Hebrew, "ניקוד גבוה" },
			{ lang::Hungarian, "Legjobb eredmények" },
			{ lang::Italian, "Punteggi migliori" },
			{ lang::Japanese, "ハイスコア" },
			{ lang::Korean, "고득점" },
			{ lang::Norwegian, "Beste resultater" },
			{ lang::Dutch, "Topscores" },
			{ lang::Polish, "Najlepsze wyniki" },
			{ lang::BrazilianPortuguese, "Recordes" },
			{ lang::Portuguese, "Pontuações máximas" },
			{ lang::Russian, "Чемпионы" },
			{ lang::Swedish, "Poängrekord" },
			{ lang::Turkish, "Yüksek Skorlar" },
			{ lang::SimplifiedChinese, "高分" },
			{ lang::TraditionalChinese, "高分記錄" },
		},
	},
	{
		Msg::HIGHSCORES_Ok,
		{
			{ lang::Arabic, "موافق" },
			{ lang::Czech, "OK" },
			{ lang::Danish, "OK" },
			{ lang::German, "OK" },
			{ lang::Greek, "OK" },
			{ lang::English, "OK" },
			{ lang::Spanish, "Aceptar" },
			{ lang::Finnish, "OK" },
			{ lang::French, "OK" },
			{ lang::Hebrew, "אישור" },
			{ lang::Hungarian, "OK" },
			{ lang::Italian, "OK" },
			{ lang::Japanese, "OK" },
			{ lang::Korean, "확인" },
			{ lang::Norwegian, "OK" },
			{ lang::Dutch, "OK" },
			{ lang::Polish, "OK" },
			{ lang::BrazilianPortuguese, "OK" },
			{ lang::Portuguese, "OK" },
			{ lang::Russian, "ОК" },
			{ lang::Swedish, "OK" },
			{ lang::Turkish, "Tamam" },
			{ lang::SimplifiedChinese, "确定" },
			{ lang::TraditionalChinese, "確定" },
		},
	},
	{
		Msg::HIGHSCORES_Cancel,
		{
			{ lang::Arabic, "إلغاء الأمر" },
			{ lang::Czech, "Storno" },
			{ lang::Danish, "Annuller" },
			{ lang::German, "Abbrechen" },
			{ lang::Greek, "Άκυρο" },
			{ lang::English, "Cancel" },
			{ lang::Spanish, "Cancelar" },
			{ lang::Finnish, "Peruuta" },
			{ lang::French, "Annuler" },
			{ lang::Hebrew, "ביטול" },
			{ lang::Hungarian, "Mégse" },
			{ lang::Italian, "Annulla" },
			{ lang::Japanese, "キャンセル" },
			{ lang::Korean, "취소" },
			{ lang::Norwegian, "Avbryt" },
			{ lang::Dutch, "Annuleren" },
			{ lang::Polish, "Anuluj" },
			{ lang::BrazilianPortuguese, "Cancelar" },
			{ lang::Portuguese, "Cancelar" },
			{ lang::Russian, "Отмена" },
			{ lang::Swedish, "Avbryt" },
			{ lang::Turkish, "İptal" },
			{ lang::SimplifiedChinese, "取消" },
			{ lang::TraditionalChinese, "取消" },
		},
	},
	{
		Msg::HIGHSCORES_Clear,
		{
			{ lang::Arabic, "مسح" },
			{ lang::Czech, "Vymazat" },
			{ lang::Danish, "Ryd" },
			{ lang::German, "Löschen" },
			{ lang::Greek, "Απαλοιφή" },
			{ lang::English, "Clear" },
			{ lang::Spanish, "Borrar" },
			{ lang::Finnish, "Tyhjennä" },
			{ lang::French, "Effacer" },
			{ lang::Hebrew, "נקה" },
			{ lang::Hungarian, "Törlés" },
			{ lang::Italian, "Cancella" },
			{ lang::Japanese, "クリア" },
			{ lang::Korean, "지우기" },
			{ lang::Norwegian, "Nullstill" },
			{ lang::Dutch, "Wissen" },
			{ lang::Polish, "Wyczyść" },
			{ lang::BrazilianPortuguese, "Limpar" },
			{ lang::Portuguese, "Limpar" },
			{ lang::Russian, "Очистить" },
			{ lang::Swedish, "Radera" },
			{ lang::Turkish, "Temizle" },
			{ lang::SimplifiedChinese, "清除" },
			{ lang::TraditionalChinese, "清除" },
		},
	},
	{
		Msg::HIGHSCORES_Name,
		{
			{ lang::Arabic, "الاسم" },
			{ lang::Czech, "Jméno" },
			{ lang::Danish, "Navn" },
			{ lang::German, "Name" },
			{ lang::Greek, "Όνομα" },
			{ lang::English, "Name" },
			{ lang::Spanish, "Nombre" },
			{ lang::Finnish, "Nimi" },
			{ lang::French, "Nom" },
			{ lang::Hebrew, "שם" },
			{ lang::Hungarian, "Név" },
			{ lang::Italian, "Nome" },
			{ lang::Japanese, "名前" },
			{ lang::Korean, "이름" },
			{ lang::Norwegian, "Navn" },
			{ lang::Dutch, "Naam" },
			{ lang::Polish, "Nazwa" },
			{ lang::BrazilianPortuguese, "Nome" },
			{ lang::Portuguese, "Nome" },
			{ lang::Russian, "Игрок" },
			{ lang::Swedish, "Namn" },
			{ lang::Turkish, "Adı" },
			{ lang::SimplifiedChinese, "姓名" },
			{ lang::TraditionalChinese, "姓名" },
		},
	},
	{
		Msg::HIGHSCORES_Score,
		{
			{ lang::Arabic, "النقاط" },
			{ lang::Czech, "Skóre" },
			{ lang::Danish, "Point" },
			{ lang::German, "Punkte" },
			{ lang::Greek, "Βαθμολογία" },
			{ lang::English, "Score" },
			{ lang::Spanish, "Puntuación" },
			{ lang::Finnish, "Tulos" },
			{ lang::French, "Score" },
			{ lang::Hebrew, "תוצאה" },
			{ lang::Hungarian, "Eredmény" },
			{ lang::Italian, "Punteggio" },
			{ lang::Japanese, "スコア" },
			{ lang::Korean, "점수" },
			{ lang::Norwegian, "Poeng" },
			{ lang::Dutch, "Score" },
			{ lang::Polish, "Wynik" },
			{ lang::BrazilianPortuguese, "Pontos" },
			{ lang::Portuguese, "Pontuação" },
			{ lang::Russian, "Счет" },
			{ lang::Swedish, "Poäng" },
			{ lang::Turkish, "Sonuç" },
			{ lang::SimplifiedChinese, "得分" },
			{ lang::TraditionalChinese, "分數" },
		},
	},
	{
		Msg::HIGHSCORES_Rank,
		{
			{ lang::Arabic, "المركز" },
			{ lang::Czech, "Pořadí" },
			{ lang::Danish, "Placering" },
			{ lang::German, "Rang" },
			{ lang::Greek, "Κατάταξη" },
			{ lang::English, "Rank" },
			{ lang::Spanish, "Clasificación" },
			{ lang::Finnish, "Järjestys" },
			{ lang::French, "Rang" },
			{ lang::Hebrew, "דירוג" },
			{ lang::Hungarian, "Sorrend" },
			{ lang::Italian, "Classifica" },
			{ lang::Japanese, "順位" },
			{ lang::Korean, "순위" },
			{ lang::Norwegian, "Plassering" },
			{ lang::Dutch, "Positie" },
			{ lang::Polish, "Klasyfikacja" },
			{ lang::BrazilianPortuguese, "Classificação" },
			{ lang::Portuguese, "Posição" },
			{ lang::Russian, "Место" },
			{ lang::Swedish, "Rang" },
			{ lang::Turkish, "Derece" },
			{ lang::SimplifiedChinese, "名次" },
			{ lang::TraditionalChinese, "排名" },
		},
	},
	{
		Msg::HIGHSCORES_Rank1,
		{
			{ lang::Arabic, "1" },
			{ lang::Czech, "1" },
			{ lang::Danish, "1" },
			{ lang::German, "1" },
			{ lang::Greek, "1" },
			{ lang::English, "1" },
			{ lang::Spanish, "1" },
			{ lang::Finnish, "1." },
			{ lang::French, "1" },
			{ lang::Hebrew, "1" },
			{ lang::Hungarian, "1" },
			{ lang::Italian, "1" },
			{ lang::Japanese, "1" },
			{ lang::Korean, "1" },
			{ lang::Norwegian, "1" },
			{ lang::Dutch, "1" },
			{ lang::Polish, "1" },
			{ lang::BrazilianPortuguese, "1" },
			{ lang::Portuguese, "1" },
			{ lang::Russian, "1" },
			{ lang::Swedish, "1" },
			{ lang::Turkish, "1" },
			{ lang::SimplifiedChinese, "1" },
			{ lang::TraditionalChinese, "1" },
		},
	},
	{
		Msg::HIGHSCORES_Rank2,
		{
			{ lang::Arabic, "2" },
			{ lang::Czech, "2" },
			{ lang::Danish, "2" },
			{ lang::German, "2" },
			{ lang::Greek, "2" },
			{ lang::English, "2" },
			{ lang::Spanish, "2" },
			{ lang::Finnish, "2." },
			{ lang::French, "2" },
			{ lang::Hebrew, "2" },
			{ lang::Hungarian, "2" },
			{ lang::Italian, "2" },
			{ lang::Japanese, "2" },
			{ lang::Korean, "2" },
			{ lang::Norwegian, "2" },
			{ lang::Dutch, "2" },
			{ lang::Polish, "2" },
			{ lang::BrazilianPortuguese, "2" },
			{ lang::Portuguese, "2" },
			{ lang::Russian, "2" },
			{ lang::Swedish, "2" },
			{ lang::Turkish, "2" },
			{ lang::SimplifiedChinese, "2" },
			{ lang::TraditionalChinese, "2" },
		},
	},
	{
		Msg::HIGHSCORES_Rank3,
		{
			{ lang::Arabic, "3" },
			{ lang::Czech, "3" },
			{ lang::Danish, "3" },
			{ lang::German, "3" },
			{ lang::Greek, "3" },
			{ lang::English, "3" },
			{ lang::Spanish, "3" },
			{ lang::Finnish, "3." },
			{ lang::French, "3" },
			{ lang::Hebrew, "3" },
			{ lang::Hungarian, "3" },
			{ lang::Italian, "3" },
			{ lang::Japanese, "3" },
			{ lang::Korean, "3" },
			{ lang::Norwegian, "3" },
			{ lang::Dutch, "3" },
			{ lang::Polish, "3" },
			{ lang::BrazilianPortuguese, "3" },
			{ lang::Portuguese, "3" },
			{ lang::Russian, "3" },
			{ lang::Swedish, "3" },
			{ lang::Turkish, "3" },
			{ lang::SimplifiedChinese, "3" },
			{ lang::TraditionalChinese, "3" },
		},
	},
	{
		Msg::HIGHSCORES_Rank4,
		{
			{ lang::Arabic, "4" },
			{ lang::Czech, "4" },
			{ lang::Danish, "4" },
			{ lang::German, "4" },
			{ lang::Greek, "4" },
			{ lang::English, "4" },
			{ lang::Spanish, "4" },
			{ lang::Finnish, "4." },
			{ lang::French, "4" },
			{ lang::Hebrew, "4" },
			{ lang::Hungarian, "4" },
			{ lang::Italian, "4" },
			{ lang::Japanese, "4" },
			{ lang::Korean, "4" },
			{ lang::Norwegian, "4" },
			{ lang::Dutch, "4" },
			{ lang::Polish, "4" },
			{ lang::BrazilianPortuguese, "4" },
			{ lang::Portuguese, "4" },
			{ lang::Russian, "4" },
			{ lang::Swedish, "4" },
			{ lang::Turkish, "4" },
			{ lang::SimplifiedChinese, "4" },
			{ lang::TraditionalChinese, "4" },
		},
	},
	{
		Msg::HIGHSCORES_Rank5,
		{
			{ lang::Arabic, "5" },
			{ lang::Czech, "5" },
			{ lang::Danish, "5" },
			{ lang::German, "5" },
			{ lang::Greek, "5" },
			{ lang::English, "5" },
			{ lang::Spanish, "5" },
			{ lang::Finnish, "5." },
			{ lang::French, "5" },
			{ lang::Hebrew, "5" },
			{ lang::Hungarian, "5" },
			{ lang::Italian, "5" },
			{ lang::Japanese, "5" },
			{ lang::Korean, "5" },
			{ lang::Norwegian, "5" },
			{ lang::Dutch, "5" },
			{ lang::Polish, "5" },
			{ lang::BrazilianPortuguese, "5" },
			{ lang::Portuguese, "5" },
			{ lang::Russian, "5" },
			{ lang::Swedish, "5" },
			{ lang::Turkish, "5" },
			{ lang::SimplifiedChinese, "5" },
			{ lang::TraditionalChinese, "5" },
		},
	},
	{
		Msg::KEYMAPPER_Caption,
		{
			{ lang::Arabic, "‎3D Pinball: عناصر تحكم اللاعب" },
			{ lang::Czech, "Ovládání hry 3D Pinball" },
			{ lang::Danish, "3D Pinball: Styreredskaber for spiller" },
			{ lang::German, "3D-Pinball: Bedienelemente" },
			{ lang::Greek, "Φλίπερ-3Δ: Στοιχεία ελέγχου του παίχτη" },
			{ lang::English, "3D Pinball: Player Controls" },
			{ lang::Spanish, "Controles 3D Pinball" },
			{ lang::Finnish, "3D Pinball: pelin ohjaimet" },
			{ lang::French, "Contrôles de jeu de Pinball 3D" },
			{ lang::Hebrew, "Pinball תלת-מימדי: מקשי משחק" },
			{ lang::Hungarian, "3D flipper: mozgató billentyűk" },
			{ lang::Italian, "3D Pinball: controlli giocatore" },
			{ lang::Japanese, "3D ピンボール: コントロールの設定" },
			{ lang::Korean, "3D 핀볼: 게임 진행키 설정" },
			{ lang::Norwegian, "3D Pinball - Spillkontroller" },
			{ lang::Dutch, "3D Pinball: spelfuncties" },
			{ lang::Polish, "3D Pinball: Sterowniki gracza" },
			{ lang::BrazilianPortuguese, "Pinball 3D: controles do jogador" },
			{ lang::Portuguese, "3D Pinball: controlos do jogador" },
			{ lang::Russian, "Пинбол: клавиши управления" },
			{ lang::Swedish, "3D Pinball: Spelkontroller" },
			{ lang::Turkish, "3D Pinball: Oyuncu Denetimleri" },
			{ lang::SimplifiedChinese, "三维弹球：玩家控制" },
			{ lang::TraditionalChinese, "立體彈珠台：玩家控制" },
		},
	},
	{
		Msg::KEYMAPPER_Ok,
		{
			{ lang::Arabic, "موافق" },
			{ lang::Czech, "OK" },
			{ lang::Danish, "OK" },
			{ lang::German, "OK" },
			{ lang::Greek, "OK" },
			{ lang::English, "OK" },
			{ lang::Spanish, "Aceptar" },
			{ lang::Finnish, "OK" },
			{ lang::French, "OK" },
			{ lang::Hebrew, "אישור" },
			{ lang::Hungarian, "OK" },
			{ lang::Italian, "OK" },
			{ lang::Japanese, "OK" },
			{ lang::Korean, "확인" },
			{ lang::Norwegian, "OK" },
			{ lang::Dutch, "OK" },
			{ lang::Polish, "OK" },
			{ lang::BrazilianPortuguese, "OK" },
			{ lang::Portuguese, "OK" },
			{ lang::Russian, "ОК" },
			{ lang::Swedish, "OK" },
			{ lang::Turkish, "Tamam" },
			{ lang::SimplifiedChinese, "确定" },
			{ lang::TraditionalChinese, "確定" },
		},
	},
	{
		Msg::KEYMAPPER_Cancel,
		{
			{ lang::Arabic, "إلغاء الأمر" },
			{ lang::Czech, "Storno" },
			{ lang::Danish, "Annuller" },
			{ lang::German, "Abbrechen" },
			{ lang::Greek, "Άκυρο" },
			{ lang::English, "Cancel" },
			{ lang::Spanish, "Cancelar" },
			{ lang::Finnish, "Peruuta" },
			{ lang::French, "Annuler" },
			{ lang::Hebrew, "ביטול" },
			{ lang::Hungarian, "Mégse" },
			{ lang::Italian, "Annulla" },
			{ lang::Japanese, "キャンセル" },
			{ lang::Korean, "취소" },
			{ lang::Norwegian, "Avbryt" },
			{ lang::Dutch, "Annuleren" },
			{ lang::Polish, "Anuluj" },
			{ lang::BrazilianPortuguese, "Cancelar" },
			{ lang::Portuguese, "Cancelar" },
			{ lang::Russian, "Отмена" },
			{ lang::Swedish, "Avbryt" },
			{ lang::Turkish, "İptal" },
			{ lang::SimplifiedChinese, "取消" },
			{ lang::TraditionalChinese, "取消" },
		},
	},
	{
		Msg::KEYMAPPER_FlipperL,
		{
			{ lang::Arabic, "المضرب الأيسر" },
			{ lang::Czech, "Levá páka" },
			{ lang::Danish, "Venstre flipper" },
			{ lang::German, "Linker Flipper" },
			{ lang::Greek, "Αριστερή ρακέτα" },
			{ lang::English, "Left Flipper" },
			{ lang::Spanish, "Impulsor izquierdo" },
			{ lang::Finnish, "Vasen siipi" },
			{ lang::French, "Flipper gauche" },
			{ lang::Hebrew, "פליפר שמאלי" },
			{ lang::Hungarian, "Bal oldali ütő" },
			{ lang::Italian, "Flipper sinistro" },
			{ lang::Japanese, "左フリッパー" },
			{ lang::Korean, "왼쪽 공격막대" },
			{ lang::Norwegian, "Venstre flipper" },
			{ lang::Dutch, "Linker-\nflipper" },
			{ lang::Polish, "Lewe ramię" },
			{ lang::BrazilianPortuguese, "Palheta esquerda" },
			{ lang::Portuguese, "Flipper esquerdo" },
			{ lang::Russian, "Левый флиппер" },
			{ lang::Swedish, "Vänster flipper" },
			{ lang::Turkish, "Sol Kol" },
			{ lang::SimplifiedChinese, "左挡板" },
			{ lang::TraditionalChinese, "左擋板" },
		},
	},
	{
		Msg::KEYMAPPER_FlipperR,
		{
			{ lang::Arabic, "المضرب الأيمن" },
			{ lang::Czech, "Pravá páka" },
			{ lang::Danish, "Højre flipper" },
			{ lang::German, "Rechter Flipper" },
			{ lang::Greek, "Δεξιά ρακέτα" },
			{ lang::English, "Right Flipper" },
			{ lang::Spanish, "Impulsor derecho" },
			{ lang::Finnish, "Oikea siipi" },
			{ lang::French, "Flipper droit" },
			{ lang::Hebrew, "פליפר ימני" },
			{ lang::Hungarian, "Jobb oldali ütő" },
			{ lang::Italian, "Flipper destro" },
			{ lang::Japanese, "右フリッパー" },
			{ lang::Korean, "오른쪽 공격막대" },
			{ lang::Norwegian, "Høyre flipper" },
			{ lang::Dutch, "Rechter-\nflipper" },
			{ lang::Polish, "Prawe ramię" },
			{ lang::BrazilianPortuguese, "Palheta direita" },
			{ lang::Portuguese, "Flipper direito" },
			{ lang::Russian, "Правый флиппер" },
			{ lang::Swedish, "Höger flipper" },
			{ lang::Turkish, "Sağ Kol" },
			{ lang::SimplifiedChinese, "右挡板" },
			{ lang::TraditionalChinese, "右擋板" },
		},
	},
	{
		Msg::KEYMAPPER_Plunger,
		{
			{ lang::Arabic, "الزناد" },
			{ lang::Czech, "Píst" },
			{ lang::Danish, "Stempel" },
			{ lang::German, "Abzug" },
			{ lang::Greek, "Ελατήριο" },
			{ lang::English, "Plunger" },
			{ lang::Spanish, "Pistón" },
			{ lang::Finnish, "Vetojousi" },
			{ lang::French, "Lanceur" },
			{ lang::Hebrew, "ידית הפעלה" },
			{ lang::Hungarian, "Dugattyú" },
			{ lang::Italian, "Lanciapalline" },
			{ lang::Japanese, "プランジャー" },
			{ lang::Korean, "구슬 쏘기" },
			{ lang::Norwegian, "Utskyter" },
			{ lang::Dutch, "Lanceerknop" },
			{ lang::Polish, "Wyrzutnia" },
			{ lang::BrazilianPortuguese, "Lançador" },
			{ lang::Portuguese, "Pistão" },
			{ lang::Russian, "Рычаг запуска" },
			{ lang::Swedish, "Avfyrning" },
			{ lang::Turkish, "Fırlatıcı" },
			{ lang::SimplifiedChinese, "撞针" },
			{ lang::TraditionalChinese, "發球桿" },
		},
	},
	{
		Msg::KEYMAPPER_BumpLeft,
		{
			{ lang::Arabic, "المصد الأيسر في الطاولة" },
			{ lang::Czech, "Levý nárazník" },
			{ lang::Danish, "Bump fra venstre" },
			{ lang::German, "Tischstoß links" },
			{ lang::Greek, "Αριστερό χτύπημα" },
			{ lang::English, "Left Table Bump" },
			{ lang::Spanish, "Golpear el lado izquierdo" },
			{ lang::Finnish, "Vasemman reunan tönäisy" },
			{ lang::French, "Bourrage à gauche" },
			{ lang::Hebrew, "דחיפת שולחן משמאל" },
			{ lang::Hungarian, "Asztalba rúgás balról" },
			{ lang::Italian, "Spinta da sinistra" },
			{ lang::Japanese, "左テーブル バンプ" },
			{ lang::Korean, "테이블 왼쪽 흔들기" },
			{ lang::Norwegian, "Dunk venstre bordkant" },
			{ lang::Dutch, "Duw naar rechts" },
			{ lang::Polish, "Uderzenie w stół z lewej strony" },
			{ lang::BrazilianPortuguese, "Tapa à esquerda da mesa" },
			{ lang::Portuguese, "Pancada do lado esquerdo" },
			{ lang::Russian, "Толчок стола слева" },
			{ lang::Swedish, "Vänsterstöt" },
			{ lang::Turkish, "Sol Masa Darbesi" },
			{ lang::SimplifiedChinese, "左桌凸块" },
			{ lang::TraditionalChinese, "左檯碰撞" },
		},
	},
	{
		Msg::KEYMAPPER_BumpRight,
		{
			{ lang::Arabic, "المصد الأيمن في الطاولة" },
			{ lang::Czech, "Pravý nárazník" },
			{ lang::Danish, "Bump fra højre" },
			{ lang::German, "Tischstoß rechts" },
			{ lang::Greek, "Δεξιό χτύπημα" },
			{ lang::English, "Right Table Bump" },
			{ lang::Spanish, "Golpear el lado derecho" },
			{ lang::Finnish, "Oikean reunan tönäisy" },
			{ lang::French, "Bourrage à droite" },
			{ lang::Hebrew, "דחיפת שולחן מימין" },
			{ lang::Hungarian, "Asztalba rúgás jobbról" },
			{ lang::Italian, "Spinta da destra" },
			{ lang::Japanese, "右テーブル バンプ" },
			{ lang::Korean, "테이블 오른쪽 흔들기" },
			{ lang::Norwegian, "Dunk høyre bordkant" },
			{ lang::Dutch, "Duw naar links" },
			{ lang::Polish, "Uderzenie w stół z prawej strony" },
			{ lang::BrazilianPortuguese, "Tapa à direita da mesa" },
			{ lang::Portuguese, "Pancada do lado direito" },
			{ lang::Russian, "Толчок стола справа" },
			{ lang::Swedish, "Högerstöt" },
			{ lang::Turkish, "Sağ Masa Darbesi" },
			{ lang::SimplifiedChinese, "右桌凸块" },
			{ lang::TraditionalChinese, "右檯碰撞" },
		},
	},
	{
		Msg::KEYMAPPER_BumpBottom,
		{
			{ lang::Arabic, "المصد السفلي في الطاولة" },
			{ lang::Czech, "Dolní nárazník" },
			{ lang::Danish, "Bump nedefra" },
			{ lang::German, "Tischstoß unten" },
			{ lang::Greek, "Χτύπημα από κάτω" },
			{ lang::English, "BottomTable Bump" },
			{ lang::Spanish, "Golpear de frente" },
			{ lang::Finnish, "Alareunan tönäisy" },
			{ lang::French, "Bourrage en bas" },
			{ lang::Hebrew, "דחיפת שולחן מלמטה" },
			{ lang::Hungarian, "Asztalba rúgás alulról" },
			{ lang::Italian, "Spinta dal basso" },
			{ lang::Japanese, "ボトムテーブル バンプ" },
			{ lang::Korean, "테이블 아래쪽 흔들기" },
			{ lang::Norwegian, "Dunk nedre kant" },
			{ lang::Dutch, "Duw van onderen" },
			{ lang::Polish, "Uderzenie w stół od dołu" },
			{ lang::BrazilianPortuguese, "Tapa frontal na mesa" },
			{ lang::Portuguese, "Pancada no fundo" },
			{ lang::Russian, "Толчок стола снизу" },
			{ lang::Swedish, "Uppåtstöt" },
			{ lang::Turkish, "Alt Masa Darbesi" },
			{ lang::SimplifiedChinese, "底桌凸块" },
			{ lang::TraditionalChinese, "底檯碰撞" },
		},
	},
	{
		Msg::KEYMAPPER_Default,
		{
			{ lang::Arabic, "الافتراضي" },
			{ lang::Czech, "Výchozí" },
			{ lang::Danish, "Standard" },
			{ lang::German, "Standard" },
			{ lang::Greek, "Προεπιλογή" },
			{ lang::English, "Default" },
			{ lang::Spanish, "Predeterminados" },
			{ lang::Finnish, "Oletus" },
			{ lang::French, "Par défaut" },
			{ lang::Hebrew, "ברירת מחדל" },
			{ lang::Hungarian, "Eredeti" },
			{ lang::Italian, "Predefiniti" },
			{ lang::Japanese, "既定" },
			{ lang::Korean, "기본값" },
			{ lang::Norwegian, "Standard" },
			{ lang::Dutch, "Standaard" },
			{ lang::Polish, "Domyślne" },
			{ lang::BrazilianPortuguese, "Padrão" },
			{ lang::Portuguese, "Predefinição" },
			{ lang::Russian, "По умолчанию" },
			{ lang::Swedish, "Standard" },
			{ lang::Turkish, "Varsayılan" },
			{ lang::SimplifiedChinese, "默认值" },
			{ lang::TraditionalChinese, "預設" },
		},
	},
	{
		Msg::KEYMAPPER_Help1,
		{
			{ lang::Arabic, "لتغيير عناصر التحكم باللعبة، حدد خيارات عناصر التحكم التي تريدها ثم انقر فوق أزرار الأسهم لتغيير مفاتيح محددة ثم اختر " },
			{ lang::Czech, "Ovládání hry změníte vybráním ovládacího prvku a klepnutím na tlačítka šipek, která mění ovládací klávesy. Pak klepněte na tlačítko OK." },
			{ lang::Danish, "Hvis du vil ændre styretaster, skal du markere de ønskede indstillinger, klikke på pilknapperne for at ændre tasterne og derefter klikke på OK." },
			{ lang::German, "Wählen Sie die gewünschten Optionen zum Ändern der Bedienelemente, und klicken Sie auf die Pfeile, um die Tastenbelegung zu ändern. Klicken Sie auf " },
			{ lang::Greek, "Για να αλλάξετε τα πλήκτρα ελέγχου, επιλέξτε το στοιχείο που θέλετε, χρησιμοποιήστε τα πλήκτρα βέλους για να αλλάξετε τα πλήκτρα και μετά επιλέξτε " },
			{ lang::English, "To change game controls, choose the control options you want, click the Arrow buttons to change specific keys, and then choose OK." },
			{ lang::Spanish, "Para cambiar los controles del juego, elija la opción de control deseada, haga clic en los botones de flecha y elija Aceptar." },
			{ lang::Finnish, "Muuta pelin ohjaimia valitsemalla haluamasi ohjainasetukset. Muuta näppäimistömäärityksiä nuolinäppäimillä ja valitse sitten OK." },
			{ lang::French, "Pour modifier les contrôles de jeu, choisissez les options de contrôle que vous désirez, cliquez sur les boutons de liste déroulante pour modifier des touches spécifiques et cliquez sur OK." },
			{ lang::Hebrew, "כדי לשנות את מקשי המשחק, בחר באפשרויות הבקרה הרצויות, לחץ על לחצני החיצים כדי לשנות מקשים ספציפיים ולאחר מכן לחץ על אישור." },
			{ lang::Hungarian, "Válassza ki a mozgató funkciót, a nyilak segítségével rendelje hozzá a kívánt billentyűt, és nyomja meg az OK gombot." },
			{ lang::Italian, "Per cambiare i controlli della partita, selezionare le opzioni desiderate, fare clic sulla freccia a destra della casella per cambiare specifici tasti, quindi scegliere OK." },
			{ lang::Japanese, "ゲームのコントロールを変更するには、変更したいコントロール オプションを選び、リスト ボックスの矢印ボタンをクリックして希望のキーに変えて、[OK] をクリックしてください。" },
			{ lang::Korean, "게임 진행키 설정을 변경하려면 원하는 키 설정을 선택하고 화살표 단추를 클릭하여 특정 키를 변경한 다음 [확인]을 클릭하십시오." },
			{ lang::Norwegian, "Hvis du vil endre spillkontrollene, velger du spillkontrollene du vil bruke og velger i rullegardinlisten hvilke taster som skal representere dem (du kan også bruke piltastene for å velge). Velg deretter OK." },
			{ lang::Dutch, "Als u een spelfunctie wilt wijzigen, dient u de gewenste functie te kiezen en met behulp van de pijltoetsen andere toetsen te selecteren. Klik vervolgens op OK." },
			{ lang::Polish, "Aby zmienić klawisze sterowania grą, wybierz opcję, którą chcesz zmienić, kliknij przycisk strzałki, wybierz żądany klawisz i kliknij przycisk OK." },
			{ lang::BrazilianPortuguese, "Para alterar os controles do jogo, selecione as opções desejadas, clique nas setas para alterar teclas específicas e clique em 'OK'." },
			{ lang::Portuguese, "Para alterar os controlos de jogo seleccione as opções que deseja, faça clique sobre os botões de setas para alterar as teclas específicas e, de seguida, seleccione 'OK'." },
			{ lang::Russian, "Для изменения клавиш управления выберите подходящие значения клавиш в раскрывающихся списках, а затем нажмите кнопку OK." },
			{ lang::Swedish, "Välj önskat kontrollalternativ och ange sedan tangent genom att klicka på pilknapparna. När du är klar väljer du OK." },
			{ lang::Turkish, "Oyun denetimlerini değiştirmek için, istediğiniz denetim seçeneğini seçip Ok tuşlarıyla dilediğiniz tuşu atadıktan sonra Tamam'a basın." },
			{ lang::SimplifiedChinese, "要改变游戏控制，请选择所需的控制选项，单击箭头按钮改变指定的键，然后选择“确定”。" },
			{ lang::TraditionalChinese, "若要變更遊戲控制，請選擇您要的控制選項，然後按方向按鈕來變更指定按鍵，之後選擇［確定］。" },
		},
	},
	{
		Msg::KEYMAPPER_Help2,
		{
			{ lang::Arabic, "لاستعادة ‎3D Pinball إلى الإعدادات الأصلية، اختر " },
			{ lang::Czech, "Původní nastavení hry 3D Pinball obnovíte klepnutím na tlačítko Výchozí a poté OK. Pokud chcete používat šipkové klávesy na numerické klávesnici, musí být indikátor Num Lock vypnutý." },
			{ lang::Danish, "Hvis du vil gendanne de oprindelige indstillinger for 3D Pinball, skal du klikke på Standard og derefter på OK. Hvis du vil bruge tasterne på det numeriske tastatur, skal NumLock være slået fra." },
			{ lang::German, "Klicken Sie auf " },
			{ lang::Greek, "Γι α να επαναφέρετε τις αρχικές ρυθμίσεις του Φλίπερ- 3Δ, επιλέξτε " },
			{ lang::English, "To restore 3D Pinball to its original settings, choose Default, and then choose OK. To use the Arrow keys on the numeric keypad, make sure NUMLOCK is off." },
			{ lang::Spanish, "Para recuperar la configuración original de 3D Pinball, elija Predeterminados y luego Aceptar. Cuando utilice las teclas de dirección en el teclado numérico, compruebe que Bloq Num está desactivado." },
			{ lang::Finnish, "Palauta 3D Pinballin alkuperäiset asetukset valitsemalla Oletus ja sitten OK. Käytä numeronäppäimistön nuolinäppäimiä ja varmista, että NUM LOCK ei ole käytössä." },
			{ lang::French, "Pour restaurer les paramètres d'origine de 3D Pinball, choisissez Par défaut et cliquez sur OK. Pour utiliser les flèches du pavé numérique, vérifiez que Verr. Num. est désactivé." },
			{ lang::Hebrew, "כדי לשחזר את ההגדרות המקוריות של Pinball תלת-מימדי, לחץ על ברירת מחדל ולאחר מכן לחץ על אישור. כדי להשתמש במקשי החיצים במקלדת הנומרית, ודא כי מקש NUMLOCK אינו פעיל." },
			{ lang::Hungarian, "Ha vissza kívánja állítani a 3D-flipper eredeti beállításait, kattintson az Eredeti, majd az OK gombra. A numerikus billentyűzet nyílbillentyűinek használatához a NUMLOCK-ot ki kell kapcsolni." },
			{ lang::Italian, "Per ripristinare i controlli originali di 3D Pinball, scegliere Predefiniti, quindi OK. Per usare i tasti di direzione sul tastierino numerico, assicurarsi che BLOC NUM sia disattivato." },
			{ lang::Japanese, "3D ピンボールを元の設定に戻すには、[既定]、[OK] の順にクリックしてください。テンキー上の方向キーを使う場合は、NumLock キーがオフになっていることを確かめてください。" },
			{ lang::Korean, "3D 핀볼의 원래 설정을 복원하려면 [기본값]을 선택한 다음 [확인]을 클릭하십시오. 숫자 키패드에서 화살표를 사용하려면 <Num Lock> 키가 꺼져 있는지 확인하십시오." },
			{ lang::Norwegian, "Velg Standard hvis du vil tilbakestille 3D Pinball til originalinnstillingene. Deretter velger du OK. Hvis du vil bruke pilene på det numeriske tastaturet, må Num Lock være deaktivert." },
			{ lang::Dutch, "Klik op Standaard en vervolgens op OK als u de oorspronkelijke instellingen wilt herstellen. Controleer of NUM LOCK is uitgeschakeld als u de pijltoetsen op het numerieke toetsenblok wilt gebruiken." },
			{ lang::Polish, "Aby przywrócić oryginalne ustawienia gry 3D Pinball, kliknij przycisk Domyślne, a następnie kliknij przycisk OK. Aby używać klawiszy strzałek na klawiaturze numerycznej upewnij się, że klawisz NUMLOCK jest wyłączony." },
			{ lang::BrazilianPortuguese, "Para restaurar as configurações originais do Pinball 3D, clique em 'Padrão' e em 'OK'. Para usar as teclas de direção do teclado numérico, certifique-se de que a tecla NUMLOCK está desativada." },
			{ lang::Portuguese, "Para restaurar as definições originais do 3D Pinball, seleccione 'Predefinições' e, em seguida, seleccione 'OK'. Para usar as teclas de setas no teclado numérico, certifique-se de que o NUMLOCK está desligado." },
			{ lang::Russian, "Для восстановления стандартных значений клавиш управления нажмите кнопку " },
			{ lang::Swedish, "Om du vill återställa de ursprungliga inställningarna för 3D Pinball väljer du Standard och sedan OK. Om du vill använda piltangenterna på det numeriska tangentbordet måste NUMLOCK vara av." },
			{ lang::Turkish, "3D Pinball" },
			{ lang::SimplifiedChinese, "要将“三维弹球”还原到其原设置，请选择 “默认值”，然后选择“确定”。要使用数字键盘上的箭头键，请确认 NUMLOCK 已关闭。" },
			{ lang::TraditionalChinese, "若要將立體彈珠台還原成原始設定，請選擇［預設］，然後選擇［確定］。請使用數字鍵台上的方向鍵，並確定 NUMLOCK 指示燈號在關閉狀態。" },
		},
	},
	{
		Msg::KEYMAPPER_Groupbox1,
		{
			{ lang::Arabic, "خيارات التحكم" },
			{ lang::Czech, "Možnosti ovládání" },
			{ lang::Danish, "Styreindstillinger" },
			{ lang::German, "Optionen" },
			{ lang::Greek, "Επιλογές στοιχείων ελέγχου" },
			{ lang::English, "Control Options" },
			{ lang::Spanish, "Opciones de control" },
			{ lang::Finnish, "Ohjaimien asetukset" },
			{ lang::French, "Options de contrôle" },
			{ lang::Hebrew, "אפשרויות בקרה" },
			{ lang::Hungarian, "Vezérlőműveletek" },
			{ lang::Italian, "Opzioni di controllo" },
			{ lang::Japanese, "コントロール オプション" },
			{ lang::Korean, "키 설정" },
			{ lang::Norwegian, "Kontrollalternativer" },
			{ lang::Dutch, "Besturingsopties" },
			{ lang::Polish, "Opcje sterowania" },
			{ lang::BrazilianPortuguese, "Opções de controle" },
			{ lang::Portuguese, "Opções de controlo" },
			{ lang::Russian, "Выбор клавиш управления" },
			{ lang::Swedish, "Alternativ för kontroller" },
			{ lang::Turkish, "Denetim Seçenekleri" },
			{ lang::SimplifiedChinese, "控制选项" },
			{ lang::TraditionalChinese, "控制選項" },
		},
	},
	{
		Msg::KEYMAPPER_Groupbox2,
		{
			{ lang::Arabic, "إرشادات" },
			{ lang::Czech, "Návod" },
			{ lang::Danish, "Vejledning" },
			{ lang::German, "Anweisungen" },
			{ lang::Greek, "Οδηγίες" },
			{ lang::English, "Instructions" },
			{ lang::Spanish, "Instrucciones" },
			{ lang::Finnish, "Ohjeet" },
			{ lang::French, "Instructions" },
			{ lang::Hebrew, "הוראות" },
			{ lang::Hungarian, "Útmutató" },
			{ lang::Italian, "Istruzioni" },
			{ lang::Japanese, "説明" },
			{ lang::Korean, "설명" },
			{ lang::Norwegian, "Instruksjoner" },
			{ lang::Dutch, "Instructies" },
			{ lang::Polish, "Instrukcje" },
			{ lang::BrazilianPortuguese, "Instruções" },
			{ lang::Portuguese, "Instruções" },
			{ lang::Russian, "Указания" },
			{ lang::Swedish, "Instruktioner" },
			{ lang::Turkish, "Yönergeler" },
			{ lang::SimplifiedChinese, "说明" },
			{ lang::TraditionalChinese, "指示" },
		},
	},
	{
		Msg::Menu1_New_Game,
		{
			{ lang::Arabic, "لعبة جديدة" },
			{ lang::Czech, "Nová hra" },
			{ lang::Danish, "Nyt spil" },
			{ lang::German, "Neues Spiel" },
			{ lang::Greek, "Νέο Παιχνίδι" },
			{ lang::English, "New Game" },
			{ lang::Spanish, "Nuevo juego" },
			{ lang::Finnish, "Uusi peli" },
			{ lang::French, "Nouvelle partie" },
			{ lang::Hebrew, "משחק חדש" },
			{ lang::Hungarian, "Új játék" },
			{ lang::Italian, "Nuova partita" },
			{ lang::Japanese, "スタート" },
			{ lang::Korean, "새 게임" },
			{ lang::Norwegian, "Nytt spill" },
			{ lang::Dutch, "Nieuw spel" },
			{ lang::Polish, "Nowa gra" },
			{ lang::BrazilianPortuguese, "Novo jogo" },
			{ lang::Portuguese, "Novo jogo" },
			{ lang::Russian, "Новая игра" },
			{ lang::Swedish, "Nytt spel" },
			{ lang::Turkish, "Yeni Oyun" },
			{ lang::SimplifiedChinese, "开局" },
			{ lang::TraditionalChinese, "新遊戲" },
		},
	},
	{
		Msg::Menu1_About_Pinball,
		{
			{ lang::Arabic, "حول Pinball" },
			{ lang::Czech, "O hře Pinball" },
			{ lang::Danish, "Om Pinball" },
			{ lang::German, "Info" },
			{ lang::Greek, "Πληροφορίες για το Φλίπερ" },
			{ lang::English, "About Pinball" },
			{ lang::Spanish, "Acerca de Pinball" },
			{ lang::Finnish, "Tietoja Pinballista" },
			{ lang::French, "À propos de Pinball 3D" },
			{ lang::Hebrew, "אודות Pinball" },
			{ lang::Hungarian, "Névjegy" },
			{ lang::Italian, "Informazioni su Pinball" },
			{ lang::Japanese, "バージョン情報" },
			{ lang::Korean, "핀볼 정보" },
			{ lang::Norwegian, "Om Pinball" },
			{ lang::Dutch, "Info" },
			{ lang::Polish, "Pinball - informacje" },
			{ lang::BrazilianPortuguese, "Sobre o Pinball" },
			{ lang::Portuguese, "Acerca do Pinball" },
			{ lang::Russian, "О программе" },
			{ lang::Swedish, "Om Pinball" },
			{ lang::Turkish, "Pinball Hakkında" },
			{ lang::SimplifiedChinese, "关于弹球" },
			{ lang::TraditionalChinese, "關於彈珠台" },
		},
	},
	{
		Msg::Menu1_High_Scores,
		{
			{ lang::Arabic, "أفضل النتائج..." },
			{ lang::Czech, "Nejlepší výsledky..." },
			{ lang::Danish, "Point..." },
			{ lang::German, "Bestenliste..." },
			{ lang::Greek, "Καλύτεροι παίκτες..." },
			{ lang::English, "High Scores..." },
			{ lang::Spanish, "Puntuaciones más altas..." },
			{ lang::Finnish, "Parhaat tulokset..." },
			{ lang::French, "Meilleurs scores..." },
			{ lang::Hebrew, "ניקוד גבוה..." },
			{ lang::Hungarian, "Legjobb eredmények..." },
			{ lang::Italian, "Punteggi migliori..." },
			{ lang::Japanese, "ハイスコア..." },
			{ lang::Korean, "고득점..." },
			{ lang::Norwegian, "Beste resultater..." },
			{ lang::Dutch, "Topscores..." },
			{ lang::Polish, "Najlepsze wyniki..." },
			{ lang::BrazilianPortuguese, "Recordes..." },
			{ lang::Portuguese, "Pontuações máximas..." },
			{ lang::Russian, "Чемпионы..." },
			{ lang::Swedish, "Poängrekord..." },
			{ lang::Turkish, "Yüksek Skorlar..." },
			{ lang::SimplifiedChinese, "高分..." },
			{ lang::TraditionalChinese, "高分記錄..." },
		},
	},
	{
		Msg::Menu1_Exit,
		{
			{ lang::Arabic, "إنهاء" },
			{ lang::Czech, "Konec" },
			{ lang::Danish, "Afslut" },
			{ lang::German, "Beenden" },
			{ lang::Greek, "Έξοδος" },
			{ lang::English, "Exit" },
			{ lang::Spanish, "Salir" },
			{ lang::Finnish, "Lopeta" },
			{ lang::French, "Quitter" },
			{ lang::Hebrew, "יציאה" },
			{ lang::Hungarian, "Kilépés" },
			{ lang::Italian, "Esci" },
			{ lang::Japanese, "3D ピンボールの終了" },
			{ lang::Korean, "끝내기" },
			{ lang::Norwegian, "Avslutt" },
			{ lang::Dutch, "Afsluiten" },
			{ lang::Polish, "Zakończ" },
			{ lang::BrazilianPortuguese, "Sair" },
			{ lang::Portuguese, "Sair" },
			{ lang::Russian, "Выход" },
			{ lang::Swedish, "Avsluta" },
			{ lang::Turkish, "Çıkış" },
			{ lang::SimplifiedChinese, "退出" },
			{ lang::TraditionalChinese, "結束" },
		},
	},
	{
		Msg::Menu1_Sounds,
		{
			{ lang::Arabic, "أصوات" },
			{ lang::Czech, "Zvuky" },
			{ lang::Danish, "Lyde" },
			{ lang::German, "Sounds" },
			{ lang::Greek, "Ήχοι" },
			{ lang::English, "Sounds" },
			{ lang::Spanish, "Sonidos" },
			{ lang::Finnish, "Äänet" },
			{ lang::French, "Sons" },
			{ lang::Hebrew, "צלילים" },
			{ lang::Hungarian, "Hang" },
			{ lang::Italian, "Effetti sonori" },
			{ lang::Japanese, "サウンド" },
			{ lang::Korean, "소리" },
			{ lang::Norwegian, "Lyder" },
			{ lang::Dutch, "Geluiden" },
			{ lang::Polish, "Dźwięki" },
			{ lang::BrazilianPortuguese, "Sons" },
			{ lang::Portuguese, "Sons" },
			{ lang::Russian, "Звуковые эффекты" },
			{ lang::Swedish, "Ljud" },
			{ lang::Turkish, "Ses Efekti" },
			{ lang::SimplifiedChinese, "声音" },
			{ lang::TraditionalChinese, "音效" },
		},
	},
	{
		Msg::Menu1_Music,
		{
			{ lang::Arabic, "موسيقى" },
			{ lang::Czech, "Hudba" },
			{ lang::Danish, "Musik" },
			{ lang::German, "Musik" },
			{ lang::Greek, "Μουσική" },
			{ lang::English, "Music" },
			{ lang::Spanish, "Música" },
			{ lang::Finnish, "Musiikki" },
			{ lang::French, "Musique" },
			{ lang::Hebrew, "מוסיקה" },
			{ lang::Hungarian, "Zene" },
			{ lang::Italian, "Musica" },
			{ lang::Japanese, "音楽" },
			{ lang::Korean, "음악" },
			{ lang::Norwegian, "Musikk" },
			{ lang::Dutch, "Muziek" },
			{ lang::Polish, "Muzyka" },
			{ lang::BrazilianPortuguese, "Música" },
			{ lang::Portuguese, "Música" },
			{ lang::Russian, "Музыка" },
			{ lang::Swedish, "Musik" },
			{ lang::Turkish, "Müzik" },
			{ lang::SimplifiedChinese, "音乐" },
			{ lang::TraditionalChinese, "音樂" },
		},
	},
	{
		Msg::Menu1_Help_Topics,
		{
			{ lang::Arabic, "مواضيع التعليمات" },
			{ lang::Czech, "Témata nápovědy" },
			{ lang::Danish, "Emner i Hjælp" },
			{ lang::German, "Hilfethemen" },
			{ lang::Greek, "Θέματα στη Βοήθεια" },
			{ lang::English, "Help Topics" },
			{ lang::Spanish, "Temas de Ayuda" },
			{ lang::Finnish, "Ohjeen aiheet" },
			{ lang::French, "Rubriques d'aide" },
			{ lang::Hebrew, "נושאי עזרה" },
			{ lang::Hungarian, "Témakörök" },
			{ lang::Italian, "Guida in linea" },
			{ lang::Japanese, "トピックの検索" },
			{ lang::Korean, "도움말 항목" },
			{ lang::Norwegian, "Emner i Hjelp" },
			{ lang::Dutch, "Help-onderwerpen" },
			{ lang::Polish, "Tematy Pomocy" },
			{ lang::BrazilianPortuguese, "Tópicos da Ajuda" },
			{ lang::Portuguese, "Tópicos da ajuda" },
			{ lang::Russian, "Вызов справки" },
			{ lang::Swedish, "Hjälpavsnitt" },
			{ lang::Turkish, "Yardım Konuları" },
			{ lang::SimplifiedChinese, "帮助主题" },
			{ lang::TraditionalChinese, "說明主題" },
		},
	},
	{
		Msg::Menu1_Launch_Ball,
		{
			{ lang::Arabic, "إطلاق الكرة" },
			{ lang::Czech, "Vystřelit kuličku" },
			{ lang::Danish, "Affyr kugle" },
			{ lang::German, "Kugel einschießen" },
			{ lang::Greek, "Εκτόξευση μπίλιας" },
			{ lang::English, "Launch Ball" },
			{ lang::Spanish, "Lanzar bola" },
			{ lang::Finnish, "Laukaise pallo" },
			{ lang::French, "Lancer la balle" },
			{ lang::Hebrew, "שגר כדור" },
			{ lang::Hungarian, "Golyó kilövése" },
			{ lang::Italian, "Gioca pallina" },
			{ lang::Japanese, "ボール発射" },
			{ lang::Korean, "구슬 쏘기" },
			{ lang::Norwegian, "Skyt ut ball" },
			{ lang::Dutch, "Bal in spel brengen" },
			{ lang::Polish, "Załaduj kulkę" },
			{ lang::BrazilianPortuguese, "Lançar bola" },
			{ lang::Portuguese, "Lançar a bola" },
			{ lang::Russian, "Запуск шарика" },
			{ lang::Swedish, "Skjut iväg kulan" },
			{ lang::Turkish, "Topu Fırlat" },
			{ lang::SimplifiedChinese, "发射球" },
			{ lang::TraditionalChinese, "發球" },
		},
	},
	{
		Msg::Menu1_Pause_Resume_Game,
		{
			{ lang::Arabic, "إيقاف مؤقت/استئناف اللعبة" },
			{ lang::Czech, "Pozastavit či pokračovat ve hře" },
			{ lang::Danish, "Afbryd/Fortsæt spil" },
			{ lang::German, "Spiel anhalten/fortsetzen" },
			{ lang::Greek, "Προσωρινή παύση/Συνέχιση παρτίδας" },
			{ lang::English, "Pause/Resume Game" },
			{ lang::Spanish, "Pausar o reanudar el juego" },
			{ lang::Finnish, "Pysäytä/jatka peliä" },
			{ lang::French, "Suspendre/Reprendre la partie" },
			{ lang::Hebrew, "השהה/חדש משחק" },
			{ lang::Hungarian, "Felfüggesztés/újraindítás" },
			{ lang::Italian, "Sospendi/Riprendi partita" },
			{ lang::Japanese, "一時停止/ゲーム再開" },
			{ lang::Korean, "게임 일시 중지/계속" },
			{ lang::Norwegian, "Pause/gjenoppta spill" },
			{ lang::Dutch, "Spel onderbreken/hervatten" },
			{ lang::Polish, "Wstrzymaj/wznów grę" },
			{ lang::BrazilianPortuguese, "Pausa/continuar jogo" },
			{ lang::Portuguese, "Parar/continuar jogo" },
			{ lang::Russian, "Пауза/возобновление игры" },
			{ lang::Swedish, "Pausa/fortsätt" },
			{ lang::Turkish, "Oyunu Duraklat/Sürdür" },
			{ lang::SimplifiedChinese, "暂停/继续游戏" },
			{ lang::TraditionalChinese, "暫停/繼續" },
		},
	},
	{
		Msg::Menu1_Full_Screen,
		{
			{ lang::Arabic, "ملء الشاشة" },
			{ lang::Czech, "Celá obrazovka" },
			{ lang::Danish, "Fuld skærm" },
			{ lang::German, "Vollbild" },
			{ lang::Greek, "Πλήρης οθόνη" },
			{ lang::English, "Full Screen" },
			{ lang::Spanish, "Pantalla completa" },
			{ lang::Finnish, "Koko näyttö" },
			{ lang::French, "Plein écran" },
			{ lang::Hebrew, "מסך מלא" },
			{ lang::Hungarian, "Teljes képernyő" },
			{ lang::Italian, "Schermo intero" },
			{ lang::Japanese, "全画面表示" },
			{ lang::Korean, "전체 화면" },
			{ lang::Norwegian, "Full skjerm" },
			{ lang::Dutch, "Volledig scherm" },
			{ lang::Polish, "Pełny ekran" },
			{ lang::BrazilianPortuguese, "Tela inteira" },
			{ lang::Portuguese, "Ecrã inteiro" },
			{ lang::Russian, "Во весь экран" },
			{ lang::Swedish, "Helskärm" },
			{ lang::Turkish, "Tam Ekran" },
			{ lang::SimplifiedChinese, "全屏显示" },
			{ lang::TraditionalChinese, "全螢幕" },
		},
	},
	{
		Msg::Menu1_Demo,
		{
			{ lang::Arabic, "عرض" },
			{ lang::Czech, "Ukázka" },
			{ lang::Danish, "Demo" },
			{ lang::German, "Demo" },
			{ lang::Greek, "Επίδειξη" },
			{ lang::English, "Demo" },
			{ lang::Spanish, "Demostración" },
			{ lang::Finnish, "Esittely" },
			{ lang::French, "Démonstration" },
			{ lang::Hebrew, "הדגמה" },
			{ lang::Hungarian, "Bemutató játék" },
			{ lang::Italian, "Dimostrazione" },
			{ lang::Japanese, "デモンストレーション" },
			{ lang::Korean, "데모" },
			{ lang::Norwegian, "Demonstrasjon" },
			{ lang::Dutch, "Demo" },
			{ lang::Polish, "Pokaz" },
			{ lang::BrazilianPortuguese, "Demonstração" },
			{ lang::Portuguese, "Demonstração" },
			{ lang::Russian, "Демонстрация" },
			{ lang::Swedish, "Demo" },
			{ lang::Turkish, "Gösteri" },
			{ lang::SimplifiedChinese, "演示" },
			{ lang::TraditionalChinese, "示範" },
		},
	},
	{
		Msg::Menu1_Select_Table,
		{
			{ lang::Arabic, "تحديد طاولة" },
			{ lang::Czech, "Vybrat stůl" },
			{ lang::Danish, "Vælg bord" },
			{ lang::German, "Tisch auswählen" },
			{ lang::Greek, "Επιλογή πίνακα" },
			{ lang::English, "Select Table" },
			{ lang::Spanish, "Seleccionar tabla" },
			{ lang::Finnish, "Valitse kenttä" },
			{ lang::French, "Sélectionner un tableau" },
			{ lang::Hebrew, "בחר שולחן" },
			{ lang::Hungarian, "Asztal választás" },
			{ lang::Italian, "Seleziona tabella" },
			{ lang::Japanese, "テーブルの選択" },
			{ lang::Korean, "테이블 선택" },
			{ lang::Norwegian, "Velg bord" },
			{ lang::Dutch, "Kast selecteren" },
			{ lang::Polish, "Wybierz stół" },
			{ lang::BrazilianPortuguese, "Selecionar tabela" },
			{ lang::Portuguese, "Seleccionar tabela" },
			{ lang::Russian, "Выбор стола" },
			{ lang::Swedish, "Välj flipperspel" },
			{ lang::Turkish, "Masa Seç" },
			{ lang::SimplifiedChinese, "选定桌面" },
			{ lang::TraditionalChinese, "選擇桌台" },
		},
	},
	{
		Msg::Menu1_Player_Controls,
		{
			{ lang::Arabic, "عناصر تحكم اللاعب..." },
			{ lang::Czech, "Ovládání hry..." },
			{ lang::Danish, "Styreredskaber for spiller..." },
			{ lang::German, "Bedienung..." },
			{ lang::Greek, "Στοιχεία ελέγχου του παίχτη..." },
			{ lang::English, "Player Controls..." },
			{ lang::Spanish, "Controles..." },
			{ lang::Finnish, "Pelin ohjaimet..." },
			{ lang::French, "Contrôles de jeu..." },
			{ lang::Hebrew, "מקשי משחק..." },
			{ lang::Hungarian, "Mozgató billentyűk..." },
			{ lang::Italian, "Controlli giocatore..." },
			{ lang::Japanese, "コントロールの設定..." },
			{ lang::Korean, "게임 진행키 설정..." },
			{ lang::Norwegian, "Spillkontroller..." },
			{ lang::Dutch, "Spelfuncties..." },
			{ lang::Polish, "Sterowniki gracza..." },
			{ lang::BrazilianPortuguese, "Controles do jogador..." },
			{ lang::Portuguese, "Controlos do jogador..." },
			{ lang::Russian, "Клавиши управления..." },
			{ lang::Swedish, "Spelkontroller..." },
			{ lang::Turkish, "Oyuncu Denetimleri..." },
			{ lang::SimplifiedChinese, "玩家控制..." },
			{ lang::TraditionalChinese, "玩家控制..." },
		},
	},
	{
		Msg::Menu1_1Player,
		{
			{ lang::Arabic, "لاعب واحد" },
			{ lang::Czech, "1 hráč" },
			{ lang::Danish, "1 spiller" },
			{ lang::German, "1 Spieler" },
			{ lang::Greek, "1 Παίκτης" },
			{ lang::English, "1 Player" },
			{ lang::Spanish, "1 jugador" },
			{ lang::Finnish, "1 pelaaja" },
			{ lang::French, "1 joueur" },
			{ lang::Hebrew, "שחקן אחד" },
			{ lang::Hungarian, "1 játékos" },
			{ lang::Italian, "1 giocatore" },
			{ lang::Japanese, "1 人" },
			{ lang::Korean, "1명" },
			{ lang::Norwegian, "1 spiller" },
			{ lang::Dutch, "1 speler" },
			{ lang::Polish, "1 gracz" },
			{ lang::BrazilianPortuguese, "1 jogador" },
			{ lang::Portuguese, "1 jogador" },
			{ lang::Russian, "1 игрок" },
			{ lang::Swedish, "1 spelare" },
			{ lang::Turkish, "1 Oyuncu" },
			{ lang::SimplifiedChinese, "1 个玩家" },
			{ lang::TraditionalChinese, "1 個玩家" },
		},
	},
	{
		Msg::Menu1_2Players,
		{
			{ lang::Arabic, "لاعبان" },
			{ lang::Czech, "2 hráči" },
			{ lang::Danish, "2 spillere" },
			{ lang::German, "2 Spieler" },
			{ lang::Greek, "2 Παίκτες" },
			{ lang::English, "2 Players" },
			{ lang::Spanish, "2 jugadores" },
			{ lang::Finnish, "2 pelaajaa" },
			{ lang::French, "2 joueurs" },
			{ lang::Hebrew, "שני שחקנים" },
			{ lang::Hungarian, "2 játékos" },
			{ lang::Italian, "2 giocatori" },
			{ lang::Japanese, "2 人" },
			{ lang::Korean, "2명" },
			{ lang::Norwegian, "2 spillere" },
			{ lang::Dutch, "2 spelers" },
			{ lang::Polish, "2 graczy" },
			{ lang::BrazilianPortuguese, "2 jogadores" },
			{ lang::Portuguese, "2 jogadores" },
			{ lang::Russian, "2 игрока" },
			{ lang::Swedish, "2 spelare" },
			{ lang::Turkish, "2 Oyuncu" },
			{ lang::SimplifiedChinese, "2 个玩家" },
			{ lang::TraditionalChinese, "2 個玩家" },
		},
	},
	{
		Msg::Menu1_3Players,
		{
			{ lang::Arabic, "ثلاثة لاعبين" },
			{ lang::Czech, "3 hráči" },
			{ lang::Danish, "3 spillere" },
			{ lang::German, "3 Spieler" },
			{ lang::Greek, "3 Παίκτες" },
			{ lang::English, "3 Players" },
			{ lang::Spanish, "3 jugadores" },
			{ lang::Finnish, "3 pelaajaa" },
			{ lang::French, "3 joueurs" },
			{ lang::Hebrew, "שלושה שחקנים" },
			{ lang::Hungarian, "3 játékos" },
			{ lang::Italian, "3 giocatori" },
			{ lang::Japanese, "3 人" },
			{ lang::Korean, "3명" },
			{ lang::Norwegian, "3 spillere" },
			{ lang::Dutch, "3 spelers" },
			{ lang::Polish, "3 graczy" },
			{ lang::BrazilianPortuguese, "3 jogadores" },
			{ lang::Portuguese, "3 jogadores" },
			{ lang::Russian, "3 игрока" },
			{ lang::Swedish, "3 spelare" },
			{ lang::Turkish, "3 Oyuncu" },
			{ lang::SimplifiedChinese, "3 个玩家" },
			{ lang::TraditionalChinese, "3 個玩家" },
		},
	},
	{
		Msg::Menu1_4Players,
		{
			{ lang::Arabic, "أربعة لاعبين" },
			{ lang::Czech, "4 hráči" },
			{ lang::Danish, "4 spillere" },
			{ lang::German, "4 Spieler" },
			{ lang::Greek, "4 Παίκτες" },
			{ lang::English, "4 Players" },
			{ lang::Spanish, "4 jugadores" },
			{ lang::Finnish, "4 pelaajaa" },
			{ lang::French, "4 joueurs" },
			{ lang::Hebrew, "ארבעה שחקנים" },
			{ lang::Hungarian, "4 játékos" },
			{ lang::Italian, "4 giocatori" },
			{ lang::Japanese, "4 人" },
			{ lang::Korean, "4명" },
			{ lang::Norwegian, "4 spillere" },
			{ lang::Dutch, "4 spelers" },
			{ lang::Polish, "4 graczy" },
			{ lang::BrazilianPortuguese, "4 jogadores" },
			{ lang::Portuguese, "4 jogadores" },
			{ lang::Russian, "4 игрока" },
			{ lang::Swedish, "4 spelare" },
			{ lang::Turkish, "4 Oyuncu" },
			{ lang::SimplifiedChinese, "4 个玩家" },
			{ lang::TraditionalChinese, "4 個玩家" },
		},
	},
	{
		Msg::Menu1_MaximumResolution,
		{
			{ lang::Arabic, "Use Maximum Resolution" },
			{ lang::Czech, "Use Maximum Resolution" },
			{ lang::Danish, "Use Maximum Resolution" },
			{ lang::German, "Use Maximum Resolution" },
			{ lang::Greek, "Use Maximum Resolution" },
			{ lang::English, "Use Maximum Resolution" },
			{ lang::Spanish, "Use Maximum Resolution" },
			{ lang::Finnish, "Use Maximum Resolution" },
			{ lang::French, "Use Maximum Resolution" },
			{ lang::Hebrew, "Use Maximum Resolution" },
			{ lang::Hungarian, "Use Maximum Resolution" },
			{ lang::Italian, "Use Maximum Resolution" },
			{ lang::Japanese, "Use Maximum Resolution" },
			{ lang::Korean, "Use Maximum Resolution" },
			{ lang::Norwegian, "Use Maximum Resolution" },
			{ lang::Dutch, "Use Maximum Resolution" },
			{ lang::Polish, "Use Maximum Resolution" },
			{ lang::BrazilianPortuguese, "Use Maximum Resolution" },
			{ lang::Portuguese, "Use Maximum Resolution" },
			{ lang::Russian, "Использовать Максимальное Разрешение" },
			{ lang::Swedish, "Use Maximum Resolution" },
			{ lang::Turkish, "Use Maximum Resolution" },
			{ lang::SimplifiedChinese, "使用最大分辨率" },
			{ lang::TraditionalChinese, "使用最大解析度" },
		},
	},
	{
		Msg::Menu1_640x480,
		{
			{ lang::Arabic, "640 x 480" },
			{ lang::Czech, "640 x 480" },
			{ lang::Danish, "640 x 480" },
			{ lang::German, "640 x 480" },
			{ lang::Greek, "640 x 480" },
			{ lang::English, "640 x 480" },
			{ lang::Spanish, "640 x 480" },
			{ lang::Finnish, "640 x 480" },
			{ lang::French, "640 x 480" },
			{ lang::Hebrew, "640 x 480" },
			{ lang::Hungarian, "640 x 480" },
			{ lang::Italian, "640 x 480" },
			{ lang::Japanese, "640 x 480" },
			{ lang::Korean, "640 x 480" },
			{ lang::Norwegian, "640 x 480" },
			{ lang::Dutch, "640 x 480" },
			{ lang::Polish, "640 x 480" },
			{ lang::BrazilianPortuguese, "640 x 480" },
			{ lang::Portuguese, "640 x 480" },
			{ lang::Russian, "640 x 480" },
			{ lang::Swedish, "640 x 480" },
			{ lang::Turkish, "640 x 480" },
			{ lang::SimplifiedChinese, "640 x 480" },
			{ lang::TraditionalChinese, "640 x 480" },
		},
	},
	{
		Msg::Menu1_800x600,
		{
			{ lang::Arabic, "800 x 600" },
			{ lang::Czech, "800 x 600" },
			{ lang::Danish, "800 x 600" },
			{ lang::German, "800 x 600" },
			{ lang::Greek, "800 x 600" },
			{ lang::English, "800 x 600" },
			{ lang::Spanish, "800 x 600" },
			{ lang::Finnish, "800 x 600" },
			{ lang::French, "800 x 600" },
			{ lang::Hebrew, "800 x 600" },
			{ lang::Hungarian, "800 x 600" },
			{ lang::Italian, "800 x 600" },
			{ lang::Japanese, "800 x 600" },
			{ lang::Korean, "800 x 600" },
			{ lang::Norwegian, "800 x 600" },
			{ lang::Dutch, "800 x 600" },
			{ lang::Polish, "800 x 600" },
			{ lang::BrazilianPortuguese, "800 x 600" },
			{ lang::Portuguese, "800 x 600" },
			{ lang::Russian, "800 x 600" },
			{ lang::Swedish, "800 x 600" },
			{ lang::Turkish, "800 x 600" },
			{ lang::SimplifiedChinese, "800 x 600" },
			{ lang::TraditionalChinese, "800 x 600" },
		},
	},
	{
		Msg::Menu1_1024x768,
		{
			{ lang::Arabic, "1024 x 768" },
			{ lang::Czech, "1024 x 768" },
			{ lang::Danish, "1024 x 768" },
			{ lang::German, "1024 x 768" },
			{ lang::Greek, "1024 x 768" },
			{ lang::English, "1024 x 768" },
			{ lang::Spanish, "1024 x 768" },
			{ lang::Finnish, "1024 x 768" },
			{ lang::French, "1024 x 768" },
			{ lang::Hebrew, "1024 x 768" },
			{ lang::Hungarian, "1024 x 768" },
			{ lang::Italian, "1024 x 768" },
			{ lang::Japanese, "1024 x 768" },
			{ lang::Korean, "1024 x 768" },
			{ lang::Norwegian, "1024 x 768" },
			{ lang::Dutch, "1024 x 768" },
			{ lang::Polish, "1024 x 768" },
			{ lang::BrazilianPortuguese, "1024 x 768" },
			{ lang::Portuguese, "1024 x 768" },
			{ lang::Russian, "1024 x 768" },
			{ lang::Swedish, "1024 x 768" },
			{ lang::Turkish, "1024 x 768" },
			{ lang::SimplifiedChinese, "1024 x 768" },
			{ lang::TraditionalChinese, "1024 x 768" },
		},
	},
	{
		Msg::Menu1_WindowUniformScale,
		{
			{ lang::Arabic, "Uniform Scaling" },
			{ lang::Czech, "Uniform Scaling" },
			{ lang::Danish, "Uniform Scaling" },
			{ lang::German, "Uniform Scaling" },
			{ lang::Greek, "Uniform Scaling" },
			{ lang::English, "Uniform Scaling" },
			{ lang::Spanish, "Uniform Scaling" },
			{ lang::Finnish, "Uniform Scaling" },
			{ lang::French, "Uniform Scaling" },
			{ lang::Hebrew, "Uniform Scaling" },
			{ lang::Hungarian, "Uniform Scaling" },
			{ lang::Italian, "Uniform Scaling" },
			{ lang::Japanese, "Uniform Scaling" },
			{ lang::Korean, "Uniform Scaling" },
			{ lang::Norwegian, "Uniform Scaling" },
			{ lang::Dutch, "Uniform Scaling" },
			{ lang::Polish, "Uniform Scaling" },
			{ lang::BrazilianPortuguese, "Uniform Scaling" },
			{ lang::Portuguese, "Uniform Scaling" },
			{ lang::Russian, "Сохранение Пропорций" },
			{ lang::Swedish, "Uniform Scaling" },
			{ lang::Turkish, "Uniform Scaling" },
			{ lang::SimplifiedChinese, "锁定宽高比缩放" },
			{ lang::TraditionalChinese, "鎖定寬高比縮放" },
		},
	},
	{
		Msg::Menu1_AlternativeRender,
		{
			{ lang::Arabic, "Alternative Rendering" },
			{ lang::Czech, "Alternative Rendering" },
			{ lang::Danish, "Alternative Rendering" },
			{ lang::German, "Alternative Rendering" },
			{ lang::Greek, "Alternative Rendering" },
			{ lang::English, "Alternative Rendering" },
			{ lang::Spanish, "Alternative Rendering" },
			{ lang::Finnish, "Alternative Rendering" },
			{ lang::French, "Alternative Rendering" },
			{ lang::Hebrew, "Alternative Rendering" },
			{ lang::Hungarian, "Alternative Rendering" },
			{ lang::Italian, "Alternative Rendering" },
			{ lang::Japanese, "Alternative Rendering" },
			{ lang::Korean, "Alternative Rendering" },
			{ lang::Norwegian, "Alternative Rendering" },
			{ lang::Dutch, "Alternative Rendering" },
			{ lang::Polish, "Alternative Rendering" },
			{ lang::BrazilianPortuguese, "Alternative Rendering" },
			{ lang::Portuguese, "Alternative Rendering" },
			{ lang::Russian, "Альтернативный Вывод" },
			{ lang::Swedish, "Alternative Rendering" },
			{ lang::Turkish, "Alternative Rendering" },
			{ lang::SimplifiedChinese, "使用替代方式渲染" },
			{ lang::TraditionalChinese, "使用替代方式渲染" },
		},
	},
	{
		Msg::Menu1_Game,
		{
			{ lang::Arabic, "لعبة" },
			{ lang::Czech, "Hra" },
			{ lang::Danish, "Spil" },
			{ lang::German, "Spiel" },
			{ lang::Greek, "Παρτίδα" },
			{ lang::English, "Game" },
			{ lang::Spanish, "Juego" },
			{ lang::Finnish, "Peli" },
			{ lang::French, "Partie" },
			{ lang::Hebrew, "משחק" },
			{ lang::Hungarian, "Játék" },
			{ lang::Italian, "Partita" },
			{ lang::Japanese, "ゲーム" },
			{ lang::Korean, "게임" },
			{ lang::Norwegian, "Spill" },
			{ lang::Dutch, "Spel" },
			{ lang::Polish, "Gra" },
			{ lang::BrazilianPortuguese, "Jogo" },
			{ lang::Portuguese, "Jogo" },
			{ lang::Russian, "Игра" },
			{ lang::Swedish, "Spel" },
			{ lang::Turkish, "Oyun" },
			{ lang::SimplifiedChinese, "游戏" },
			{ lang::TraditionalChinese, "遊戲" },
		},
	},
	{
		Msg::Menu1_Options,
		{
			{ lang::Arabic, "خيارات" },
			{ lang::Czech, "Možnosti" },
			{ lang::Danish, "Indstillinger" },
			{ lang::German, "Optionen" },
			{ lang::Greek, "Επιλογές" },
			{ lang::English, "Options" },
			{ lang::Spanish, "Opciones" },
			{ lang::Finnish, "Asetukset" },
			{ lang::French, "Options" },
			{ lang::Hebrew, "אפשרויות" },
			{ lang::Hungarian, "Beállítások" },
			{ lang::Italian, "Opzioni" },
			{ lang::Japanese, "オプション" },
			{ lang::Korean, "옵션" },
			{ lang::Norwegian, "Alternativer" },
			{ lang::Dutch, "Opties" },
			{ lang::Polish, "Opcje" },
			{ lang::BrazilianPortuguese, "Opções" },
			{ lang::Portuguese, "Opções" },
			{ lang::Russian, "Параметры" },
			{ lang::Swedish, "Alternativ" },
			{ lang::Turkish, "Seçenekler" },
			{ lang::SimplifiedChinese, "选项" },
			{ lang::TraditionalChinese, "選項" },
		},
	},
	{
		Msg::Menu1_Select_Players,
		{
			{ lang::Arabic, "تحديد اللاعبين" },
			{ lang::Czech, "Počet hráčů" },
			{ lang::Danish, "Vælg spillere" },
			{ lang::German, "Spieler auswählen" },
			{ lang::Greek, "Επιλογή παικτών" },
			{ lang::English, "Select Players" },
			{ lang::Spanish, "Seleccionar jugadores" },
			{ lang::Finnish, "Valitse pelaajat" },
			{ lang::French, "Choisir les joueurs" },
			{ lang::Hebrew, "בחר שחקנים" },
			{ lang::Hungarian, "Játékosok száma" },
			{ lang::Italian, "Seleziona giocatori" },
			{ lang::Japanese, "プレーヤーの選択" },
			{ lang::Korean, "게임 인원 선택" },
			{ lang::Norwegian, "Velg spillere" },
			{ lang::Dutch, "Spelers selecteren" },
			{ lang::Polish, "Wybierz graczy" },
			{ lang::BrazilianPortuguese, "Selecionar jogadores" },
			{ lang::Portuguese, "Seleccionar jogadores" },
			{ lang::Russian, "Выбор игроков" },
			{ lang::Swedish, "Antal spelare" },
			{ lang::Turkish, "Oyuncu Sayısını Seç" },
			{ lang::SimplifiedChinese, "选定玩家" },
			{ lang::TraditionalChinese, "選擇玩家" },
		},
	},
	{
		Msg::Menu1_Table_Resolution,
		{
			{ lang::Arabic, "Table Resolution" },
			{ lang::Czech, "Table Resolution" },
			{ lang::Danish, "Table Resolution" },
			{ lang::German, "Table Resolution" },
			{ lang::Greek, "Table Resolution" },
			{ lang::English, "Table Resolution" },
			{ lang::Spanish, "Table Resolution" },
			{ lang::Finnish, "Table Resolution" },
			{ lang::French, "Table Resolution" },
			{ lang::Hebrew, "Table Resolution" },
			{ lang::Hungarian, "Table Resolution" },
			{ lang::Italian, "Table Resolution" },
			{ lang::Japanese, "Table Resolution" },
			{ lang::Korean, "Table Resolution" },
			{ lang::Norwegian, "Table Resolution" },
			{ lang::Dutch, "Table Resolution" },
			{ lang::Polish, "Table Resolution" },
			{ lang::BrazilianPortuguese, "Table Resolution" },
			{ lang::Portuguese, "Table Resolution" },
			{ lang::Russian, "Разрешение Стола" },
			{ lang::Swedish, "Table Resolution" },
			{ lang::Turkish, "Table Resolution" },
			{ lang::SimplifiedChinese, "桌面分辨率" },
			{ lang::TraditionalChinese, "桌台解析度" },
		},
	},
	{
		Msg::Menu1_Window,
		{
			{ lang::Arabic, "Window" },
			{ lang::Czech, "Window" },
			{ lang::Danish, "Window" },
			{ lang::German, "Window" },
			{ lang::Greek, "Window" },
			{ lang::English, "Window" },
			{ lang::Spanish, "Window" },
			{ lang::Finnish, "Window" },
			{ lang::French, "Window" },
			{ lang::Hebrew, "Window" },
			{ lang::Hungarian, "Window" },
			{ lang::Italian, "Window" },
			{ lang::Japanese, "Window" },
			{ lang::Korean, "Window" },
			{ lang::Norwegian, "Window" },
			{ lang::Dutch, "Window" },
			{ lang::Polish, "Window" },
			{ lang::BrazilianPortuguese, "Window" },
			{ lang::Portuguese, "Window" },
			{ lang::Russian, "Окно" },
			{ lang::Swedish, "Window" },
			{ lang::Turkish, "Window" },
			{ lang::SimplifiedChinese, "窗口" },
			{ lang::TraditionalChinese, "視窗" },
		},
	},
	{
		Msg::Menu1_Help,
		{
			{ lang::Arabic, "تعليمات" },
			{ lang::Czech, "Nápověda" },
			{ lang::Danish, "Hjælp" },
			{ lang::German, "?" },
			{ lang::Greek, "Βοήθεια" },
			{ lang::English, "Help" },
			{ lang::Spanish, "Ayuda" },
			{ lang::Finnish, "Ohje" },
			{ lang::French, "?" },
			{ lang::Hebrew, "עזרה" },
			{ lang::Hungarian, "Súgó" },
			{ lang::Italian, "?" },
			{ lang::Japanese, "ヘルプ" },
			{ lang::Korean, "도움말" },
			{ lang::Norwegian, "Hjelp" },
			{ lang::Dutch, "Help" },
			{ lang::Polish, "Pomoc" },
			{ lang::BrazilianPortuguese, "Ajuda" },
			{ lang::Portuguese, "Ajuda" },
			{ lang::Russian, "Справка" },
			{ lang::Swedish, "Hjälp" },
			{ lang::Turkish, "Yardım" },
			{ lang::SimplifiedChinese, "帮助" },
			{ lang::TraditionalChinese, "說明" },
		},
	},
	{
		Msg::Menu1_UseMaxResolution_640x480,
		{
			{ lang::Arabic, "Use Maximum Resolution (640 x 480)" },
			{ lang::Czech, "Use Maximum Resolution (640 x 480)" },
			{ lang::Danish, "Use Maximum Resolution (640 x 480)" },
			{ lang::German, "Use Maximum Resolution (640 x 480)" },
			{ lang::Greek, "Use Maximum Resolution (640 x 480)" },
			{ lang::English, "Use Maximum Resolution (640 x 480)" },
			{ lang::Spanish, "Use Maximum Resolution (640 x 480)" },
			{ lang::Finnish, "Use Maximum Resolution (640 x 480)" },
			{ lang::French, "Use Maximum Resolution (640 x 480)" },
			{ lang::Hebrew, "Use Maximum Resolution (640 x 480)" },
			{ lang::Hungarian, "Use Maximum Resolution (640 x 480)" },
			{ lang::Italian, "Use Maximum Resolution (640 x 480)" },
			{ lang::Japanese, "Use Maximum Resolution (640 x 480)" },
			{ lang::Korean, "Use Maximum Resolution (640 x 480)" },
			{ lang::Norwegian, "Use Maximum Resolution (640 x 480)" },
			{ lang::Dutch, "Use Maximum Resolution (640 x 480)" },
			{ lang::Polish, "Use Maximum Resolution (640 x 480)" },
			{ lang::BrazilianPortuguese, "Use Maximum Resolution (640 x 480)" },
			{ lang::Portuguese, "Use Maximum Resolution (640 x 480)" },
			{ lang::Russian, "Использовать Максимальное Разрешение (640 x 480)" },
			{ lang::Swedish, "Use Maximum Resolution (640 x 480)" },
			{ lang::Turkish, "Use Maximum Resolution (640 x 480)" },
			{ lang::SimplifiedChinese, "使用最大分辨率 (640 x 480)" },
			{ lang::TraditionalChinese, "使用最大解析度 (640 x 480)" },
		},
	},
	{
		Msg::Menu1_UseMaxResolution_800x600,
		{
			{ lang::Arabic, "Use Maximum Resolution (800 x 600)" },
			{ lang::Czech, "Use Maximum Resolution (800 x 600)" },
			{ lang::Danish, "Use Maximum Resolution (800 x 600)" },
			{ lang::German, "Use Maximum Resolution (800 x 600)" },
			{ lang::Greek, "Use Maximum Resolution (800 x 600)" },
			{ lang::English, "Use Maximum Resolution (800 x 600)" },
			{ lang::Spanish, "Use Maximum Resolution (800 x 600)" },
			{ lang::Finnish, "Use Maximum Resolution (800 x 600)" },
			{ lang::French, "Use Maximum Resolution (800 x 600)" },
			{ lang::Hebrew, "Use Maximum Resolution (800 x 600)" },
			{ lang::Hungarian, "Use Maximum Resolution (800 x 600)" },
			{ lang::Italian, "Use Maximum Resolution (800 x 600)" },
			{ lang::Japanese, "Use Maximum Resolution (800 x 600)" },
			{ lang::Korean, "Use Maximum Resolution (800 x 600)" },
			{ lang::Norwegian, "Use Maximum Resolution (800 x 600)" },
			{ lang::Dutch, "Use Maximum Resolution (800 x 600)" },
			{ lang::Polish, "Use Maximum Resolution (800 x 600)" },
			{ lang::BrazilianPortuguese, "Use Maximum Resolution (800 x 600)" },
			{ lang::Portuguese, "Use Maximum Resolution (800 x 600)" },
			{ lang::Russian, "Использовать Максимальное Разрешение (800 x 600)" },
			{ lang::Swedish, "Use Maximum Resolution (800 x 600)" },
			{ lang::Turkish, "Use Maximum Resolution (800 x 600)" },
			{ lang::SimplifiedChinese, "使用最大分辨率 (800 x 600)" },
			{ lang::TraditionalChinese, "使用最大解析度 (800 x 600)" },
		},
	},
	{
		Msg::Menu1_UseMaxResolution_1024x768,
		{
			{ lang::Arabic, "Use Maximum Resolution (1024 x 768)" },
			{ lang::Czech, "Use Maximum Resolution (1024 x 768)" },
			{ lang::Danish, "Use Maximum Resolution (1024 x 768)" },
			{ lang::German, "Use Maximum Resolution (1024 x 768)" },
			{ lang::Greek, "Use Maximum Resolution (1024 x 768)" },
			{ lang::English, "Use Maximum Resolution (1024 x 768)" },
			{ lang::Spanish, "Use Maximum Resolution (1024 x 768)" },
			{ lang::Finnish, "Use Maximum Resolution (1024 x 768)" },
			{ lang::French, "Use Maximum Resolution (1024 x 768)" },
			{ lang::Hebrew, "Use Maximum Resolution (1024 x 768)" },
			{ lang::Hungarian, "Use Maximum Resolution (1024 x 768)" },
			{ lang::Italian, "Use Maximum Resolution (1024 x 768)" },
			{ lang::Japanese, "Use Maximum Resolution (1024 x 768)" },
			{ lang::Korean, "Use Maximum Resolution (1024 x 768)" },
			{ lang::Norwegian, "Use Maximum Resolution (1024 x 768)" },
			{ lang::Dutch, "Use Maximum Resolution (1024 x 768)" },
			{ lang::Polish, "Use Maximum Resolution (1024 x 768)" },
			{ lang::BrazilianPortuguese, "Use Maximum Resolution (1024 x 768)" },
			{ lang::Portuguese, "Use Maximum Resolution (1024 x 768)" },
			{ lang::Russian, "Использовать Максимальное Разрешение (1024 x 768)" },
			{ lang::Swedish, "Use Maximum Resolution (1024 x 768)" },
			{ lang::Turkish, "Use Maximum Resolution (1024 x 768)" },
			{ lang::SimplifiedChinese, "使用最大分辨率 (1024 x 768)" },
			{ lang::TraditionalChinese, "使用最大解析度 (1024 x 768)" },
		},
	},
};
